@@ -4,11 +4,11 @@
 //              Miscellaneous routines (File I/O, etc)
 //
 //  Part of:    Scid (Shane's Chess Information Database)
-//  Version:    3.0
+//  Version:    3.5
 //
-//  Notice:     Copyright (c) 2001  Shane Hudson.  All rights reserved.
+//  Notice:     Copyright (c) 2001-2003  Shane Hudson.  All rights reserved.
 //
-//  Author:     Shane Hudson (shane@cosc.canterbury.ac.nz)
+//  Author:     Shane Hudson (sgh@users.sourceforge.net)
 //
 //////////////////////////////////////////////////////////////////////
 
@@ -24,7 +24,7 @@
 
 // Table of direction between any two chessboard squares, initialised
 // in scid_Init():
-squareDirT sqDir[66][66];
+directionT sqDir[66][66];
 
 
 //////////////////////////////////////////////////////////////////////
@@ -45,8 +45,8 @@ scid_Init ()
 
     // Initialise the sqDir[][] array of directions between every pair
     // of squares.
-    register squareT i, j;
-    squareDirT dirArray[] = { UP, DOWN, LEFT, RIGHT, UP_LEFT, UP_RIGHT,
+    squareT i, j;
+    directionT dirArray[] = { UP, DOWN, LEFT, RIGHT, UP_LEFT, UP_RIGHT,
                               DOWN_LEFT, DOWN_RIGHT, NULL_DIR };
     // First, set everything to NULL_DIR:
     for (i=A1; i <= NS; i++) {
@@ -56,12 +56,12 @@ scid_Init ()
     }
     // Now fill in the valid directions:
     for (i=A1; i <= H8; i++) {
-        squareDirT * dirptr = dirArray;
+        directionT * dirptr = dirArray;
         while (*dirptr != NULL_DIR) {
-            j = sqMove[i][*dirptr];
+            j = square_Move (i, *dirptr);
             while (j != NS) {
                 sqDir[i][j] = *dirptr;
-                j = sqMove[j][*dirptr];
+                j = square_Move (j, *dirptr);
             }
             dirptr++;
         }
@@ -473,12 +473,15 @@ strStrip (char * str, char ch)
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 // strTrimLeft():
 //      Returns the pointer into the provided string where the first
-//      character that does NOT equal trimChar occurs.
+//      character that does NOT equal a trimChar occurs.
 const char *
-strTrimLeft (const char * target, char trimChar)
+strTrimLeft (const char * target, const char * trimChars)
 {
     const char * s = target;
-    while (*s != 0  &&  *s == trimChar) { s++; }
+    while (*s != 0) {
+        if (! strContainsChar (trimChars, *s)) { break; }
+        s++;
+    }
     return s;
 }
 
@@ -557,6 +560,50 @@ strTrimDate (char * str)
     }
 }
 
+//~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+// strTrimMarkCodes():
+//    Trims in-place all Scid-recognised board mark codes
+//    in a comment string, such as "[%mark ...]" and "[%arrow ...]"
+void
+strTrimMarkCodes (char * str)
+{
+    char * in = str;
+    char * out = str;
+    bool inCode = false;
+    char * startLocation = NULL;
+
+    while (1) {
+        char ch = *in;
+        if (inCode) {
+            // If we see end-of-string or code-starting '[', there is some
+            // error so go back to the start of this code and treat it
+            // normally.
+            if (ch == 0  ||  ch == '[') {
+                *out++ = *startLocation;
+                inCode = false;
+                in = startLocation;
+            } else if (ch == ']') {
+                // See a code-ending ']', so end the code.
+                inCode = false;
+            }
+            // For all other characters in a code, just ignore it.
+        } else {
+            // Stop at end-of-string:
+            if (ch == 0) { break; }
+            // Look for the start of a code that is to be stripped:
+            if (ch == '['  &&  in[1] == '%') {
+                inCode = true;
+                startLocation = in;
+            } else {
+                *out++ = ch;
+            }
+        }
+        in++;
+    }
+    // Terminate the modified string:
+    *out = 0;
+}
+
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 // strTrimMarkup():
 //    Trims in-place all HTML-like markup codes (<b>, </i>, etc)
@@ -807,6 +854,23 @@ strContains (const char * longStr, const char * keyStr)
     return false;
 }
 
+//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+// strContainsIndex():
+//      Returns the first index if longStr contains an occurence of keyStr,
+//      case-sensitive and NOT ignoring any characters such as spaces.
+//      Returns -1 if longStr does not contain keyStr
+int
+strContainsIndex (const char * longStr, const char * keyStr)
+{
+    int index = 0;
+    while (*longStr) {
+        if (strIsPrefix (keyStr, longStr)) { return index; }
+        longStr++;
+        index++;
+    }
+    return -1;
+}
+
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 // strAlphaContains():
 //      Returns true if longStr contains an occurence of keyStr,
@@ -828,26 +892,38 @@ strAlphaContains (const char * longStr, const char * keyStr)
 //      Extracts a boolean value from a string.
 //      True strings start with one of "TtYy1", false strings with
 //      one of "FfNn0".
-//      Now also accepts strings starting with "J" (Ja), "O" (Oui) and
-//      "S" (Si) as true.
 //      Returns false if the string does not contain a boolean value.
 bool
 strGetBoolean (const char * str)
 {
-    char c = *str;
-    switch (c) {
-    case 'T':  case 't':
-    case 'Y':  case 'y':
-    case 'J':  case 'j':
-    case 'O':  case 'o':
-    case 'S':  case 's':
-    case '1':
-        return true;
-    case 'F':  case 'f':
-    case 'N':  case 'n':
-    case '0':
-        return false;
+    static const char * sTrue[] = {
+        "true", "yes", "on", "1", "ja", "si", "oui", NULL
+    };
+    static const char * sFalse[] = {
+        "false", "no", "off", "0", NULL
+    };
+    if (str[0] == 0) { return false; }
+
+    bool matchedTrue = false;
+    bool matchedFalse = false;
+
+    const char ** next = sTrue;
+    while (*next != NULL) {
+        if (strIsCasePrefix (str, *next)  ||  strIsCasePrefix (*next, str)) {
+           matchedTrue = true;
+        }
+        next++;
     }
+    next = sFalse;
+    while (*next != NULL) {
+        if (strIsCasePrefix (str, *next)  ||  strIsCasePrefix (*next, str)) {
+           matchedFalse = true;
+        }
+        next++;
+    }
+    if (matchedTrue  &&  !matchedFalse) { return true; }
+    if (matchedFalse  &&  !matchedTrue) { return false; }
+
     // default: return false.
     return false;
 }
@@ -924,8 +1000,12 @@ strGetResult (const char * str)
 {
     switch (*str) {
     case '1':
-        if (str[2] == '2') { return RESULT_Draw; } else return RESULT_White;
-    case '=': return RESULT_Draw;;
+        // Check for "1/2"-style draw result:
+        if (str[1] == '/'  &&  str[2] == '2') {
+            return RESULT_Draw;
+        }
+        return RESULT_White;
+    case '=': return RESULT_Draw;
     case '0': return RESULT_Black;
     case '*': return RESULT_None;
     }
