@@ -4,11 +4,11 @@
 //              OpTable and OpLine class methods
 //
 //  Part of:    Scid (Shane's Chess Information Database)
-//  Version:    3.1
+//  Version:    3.5
 //
-//  Notice:     Copyright (c) 2001  Shane Hudson.  All rights reserved.
+//  Notice:     Copyright (c) 2001-2003  Shane Hudson.  All rights reserved.
 //
-//  Author:     Shane Hudson (shane@cosc.canterbury.ac.nz)
+//  Author:     Shane Hudson (sgh@users.sourceforge.net)
 //
 //////////////////////////////////////////////////////////////////////
 
@@ -99,13 +99,13 @@ OpLine::Init (void)
     for (uint i=0; i < OPLINE_MOVES; i++) {
         Move[i][0] = 0;
     }
-    for (uint t=0; t < NUM_OPTHEMES; t++) { Theme[t] = false; }
+    for (uint t=0; t < NUM_POSTHEMES; t++) { Theme[t] = 0; }
     EgTheme = NUM_EGTHEMES;
 }
 
 void
 OpLine::Init (Game * g, IndexEntry * ie, gameNumberT gameNum,
-              uint maxExtraMoves)
+              uint maxExtraMoves, uint maxThemeMoveNumber)
 {
     White = strDuplicate (g->GetWhiteStr());
     Black = strDuplicate (g->GetBlackStr());
@@ -118,6 +118,7 @@ OpLine::Init (Game * g, IndexEntry * ie, gameNumberT gameNum,
     Date = g->GetDate();
     Result = g->GetResult();
     NumMoves = (g->GetNumHalfMoves() + 1) / 2;
+    EcoCode = g->GetEco();
     WhiteElo = g->GetWhiteElo();
     BlackElo = g->GetBlackElo();
     AvgElo = g->GetAverageElo();
@@ -151,31 +152,6 @@ OpLine::Init (Game * g, IndexEntry * ie, gameNumberT gameNum,
         i++;
     }
 
-    // Now check for themes:
-    Position * p = g->GetCurrentPos();
-    Theme[OPTHEME_QueenSwap] = (p->PieceCount(WQ)==0 && p->PieceCount(BQ)==0);
-    squareT wk = p->GetKingPos (WHITE);
-    squareT bk = p->GetKingPos (BLACK);
-    fyleT wkf = square_Fyle (wk);
-    fyleT bkf = square_Fyle (bk);
-    Theme[OPTHEME_CastSame] =
-        ((wkf <= C_FYLE && bkf <= C_FYLE) || (wkf >= G_FYLE && bkf >= G_FYLE));
-    Theme[OPTHEME_CastOpp] =
-        ((wkf <= C_FYLE && bkf >= G_FYLE) || (wkf >= G_FYLE && bkf <= C_FYLE));
-    Theme[OPTHEME_CastNone] =
-        (wkf >= D_FYLE && wkf <= F_FYLE && bkf >= D_FYLE && bkf <= F_FYLE);
-    Theme[OPTHEME_IQP] = (posHasIQP (p, WHITE)  ||  posHasIQP (p, BLACK));
-    Theme[OPTHEME_WAdvPawn] = (posHasAdvancedPawn (p, WHITE));
-    Theme[OPTHEME_BAdvPawn] = (posHasAdvancedPawn (p, BLACK));
-    Theme[OPTHEME_Kstorm] = (posHasKPawnStorm (p, WHITE) ||
-                             posHasKPawnStorm (p, BLACK));
-    Theme [OPTHEME_OpenFyle] = (posHasOpenFyle (p, C_FYLE) ||
-                                posHasOpenFyle (p, D_FYLE)  ||
-                                posHasOpenFyle (p, E_FYLE));
-    bool wBPair = (p->PieceCount (WB) >= 2);
-    bool bBPair = (p->PieceCount (BB) >= 2);
-    Theme [OPTHEME_BPair] = ((wBPair && !bBPair)  ||  (!wBPair && bBPair));
-
     // Now read in all the extra note moves:
     while (i < maxLineMoves) {
         simpleMoveT * sm = g->GetCurrentMove();
@@ -193,6 +169,15 @@ OpLine::Init (Game * g, IndexEntry * ie, gameNumberT gameNum,
     }
     if (g->GetCurrentMove() == NULL) { ShortGame = true; }
 
+    // Now set positional themes:
+    uint maxThemePly = maxThemeMoveNumber * 2;
+    for (i=0; i < NUM_POSTHEMES; i++) { Theme[i] = 0; }
+    g->MoveToPly (0);
+    for (i=0; i < maxThemePly; i++) {
+        if (g->MoveForward() != OK) { break; }
+        SetPositionalThemes (g->GetCurrentPos());
+    }
+
     g->RestoreState();
 }
 
@@ -205,6 +190,51 @@ OpLine::Destroy (void)
     delete[] Site;
 }
 
+
+void
+OpLine::SetPositionalThemes (Position * pos)
+{
+    squareT wk = pos->GetKingSquare (WHITE);
+    squareT bk = pos->GetKingSquare (BLACK);
+    fyleT wkf = square_Fyle (wk);
+    fyleT bkf = square_Fyle (bk);
+
+    if ((wkf <= C_FYLE && bkf <= C_FYLE) || (wkf >= G_FYLE && bkf >= G_FYLE)) {
+        Theme[POSTHEME_CastSame]++;
+    }
+    if ((wkf <= C_FYLE && bkf >= G_FYLE) || (wkf >= G_FYLE && bkf <= C_FYLE)) {
+        Theme[POSTHEME_CastOpp]++;
+    }
+    if (pos->PieceCount(WQ) == 0  &&  pos->PieceCount(BQ) == 0) {
+        Theme[POSTHEME_QueenSwap]++;
+    }
+    bool wBPair = (pos->PieceCount (WB) >= 2);
+    bool bBPair = (pos->PieceCount (BB) >= 2);
+    if ((wBPair && !bBPair)  ||  (!wBPair && bBPair)) {
+        Theme[POSTHEME_OneBPair]++;
+    }
+    if (posHasKPawnStorm (pos, WHITE)  ||  posHasKPawnStorm (pos, BLACK)) {
+        Theme[POSTHEME_Kstorm]++;
+    }
+    if (posHasIQP (pos, WHITE)) {
+        Theme[POSTHEME_WIQP]++;
+    }
+    if (posHasIQP (pos, BLACK)) {
+        Theme[POSTHEME_BIQP]++;
+    }
+    if (posHasAdvancedPawn (pos, WHITE)) {
+        Theme[POSTHEME_WAdvPawn]++;
+    }
+    if (posHasAdvancedPawn (pos, BLACK)) {
+        Theme[POSTHEME_BAdvPawn]++;
+    }
+    if (posHasOpenFyle (pos, C_FYLE)  ||  posHasOpenFyle (pos, D_FYLE)
+          ||  posHasOpenFyle (pos, E_FYLE)) {
+        Theme[POSTHEME_OpenFyle]++;
+    }
+}
+
+
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 // OpLine::Insert:
 //    Inserts subline as a note of this line.
@@ -347,6 +377,9 @@ OpLine::PrintSummary (DString * dstr, uint format, bool fullDate, bool nmoves)
     if (format == OPTABLE_CText) {
         preName = "<darkblue>";
         postName = "</darkblue>";
+    } else if (format == OPTABLE_HTML) {
+        preName = "<span class=\"player\">";
+        postName = "</span>";
     }
 
     dstr->Append (" ", preName);
@@ -368,7 +401,8 @@ OpLine::PrintSummary (DString * dstr, uint format, bool fullDate, bool nmoves)
     if (format == OPTABLE_LaTeX) {
         preElo = " \\emph{";  postElo = "}"; sep = " -- ";
     } else if (format == OPTABLE_HTML) {
-        preElo = " <i>";  postElo = "</i>"; sep = " -- ";
+        preElo = " <span class=\"elo\">";  postElo = "</span>";
+        sep = " -- ";
     } else if (format == OPTABLE_CText) {
         preElo = " <green>"; postElo = "</green>";
     }
@@ -416,8 +450,9 @@ OpLine::PrintSummary (DString * dstr, uint format, bool fullDate, bool nmoves)
 
 
 void
-OpTable::Init (Game * g, PBook * ebook)
+OpTable::Init (const char * type, Game * g, PBook * ebook)
 {
+    Type = strDuplicate (type);
     TargetRows = OPTABLE_DEFAULT_ROWS;
     MaxTableLines = OPTABLE_MAX_TABLE_LINES;
     NumRows = 0;
@@ -438,7 +473,7 @@ OpTable::Init (Game * g, PBook * ebook)
     ExcludeMove[0] = 0;
 
     uint i;
-    for (i=0; i < NUM_OPTHEMES; i++) { ThemeCount[i] = 0; }
+    for (i=0; i < NUM_POSTHEMES; i++) { ThemeCount[i] = 0; }
 
     for (i=0; i < NUM_EGTHEMES; i++) {
         EndgameCount[OPTABLE_Line][i] = EndgameCount[OPTABLE_All][i] = 0;
@@ -608,8 +643,8 @@ OpTable::Add (OpLine * line)
         strStrip (line->Move[0], '-');
         strStrip (line->Move[0], '=');
     }
-    for (uint theme=0; theme < NUM_OPTHEMES; theme++) {
-        if (line->Theme[theme]) { ThemeCount[theme]++; }
+    for (uint theme=0; theme < NUM_POSTHEMES; theme++) {
+        if (line->Theme[theme] >= POSTHEME_THRESHOLD) { ThemeCount[theme]++; }
     }
     Results[line->Result]++;
     FilterCount++;
@@ -1016,7 +1051,7 @@ OpTable::PrintLaTeX (DString * dstr, const char * title, const char * comment)
                     case 100: dstr->Append ("+"); break;
                     case  50: dstr->Append ("="); break;
                     case   0: dstr->Append ("--"); break;
-                    } 
+                    }
                 } else {
                     dstr->Append (nscore, "\\%");
                 }
@@ -1067,7 +1102,7 @@ OpTable::PrintHTML (DString * dstr, const char * title, const char * comment)
     dstr->Append ("<table border=0 cellspacing=0 cellpadding=4>\n");
     dstr->Append ("<tr><th></th>");
     for (i=0; i < OPTABLE_COLUMNS; i++) {
-        dstr->Append ("<th align=left>", i + ((StartLength + 2) / 2), "</th>");
+        dstr->Append ("<th align=\"left\">", i + ((StartLength + 2) / 2), "</th>");
     }
     dstr->Append ("</tr>\n");
 
@@ -1086,7 +1121,8 @@ OpTable::PrintHTML (DString * dstr, const char * title, const char * comment)
 
             // Check for a footnote:
             if (HasNotes (Row[row], j)) {
-                dstr->Append ("<sup>", NumNotes, "</sup>");
+                dstr->Append ("<sup><a href=\"#note", NumNotes);
+                dstr->Append ("\">", NumNotes, "</a></sup>");
             }
             if (j % 2 != 0) { dstr->Append (" </td>\n"); }
         }
@@ -1120,14 +1156,16 @@ OpTable::PrintText (DString * dstr, const char * title, const char * comment,
     dstr->Append (title, "\n");
     if (ctext) { dstr->Append ("<tt>"); }
     dstr->Append (hrule, " ");
-    if (ctext) {
-        dstr->Append ("<darkblue><run importMoveList {");
-        PrintStemLine (dstr, OPTABLE_Text, false);
-        dstr->Append ("}>");
+    if (StartLength > 0) {
+        if (ctext) {
+            dstr->Append ("<darkblue><run importMoveList {");
+            PrintStemLine (dstr, OPTABLE_Text, false);
+            dstr->Append ("}>");
+        }
+        PrintStemLine (dstr, OPTABLE_Text, true);
+        if (ctext) { dstr->Append ("</run></darkblue>"); }
+        dstr->Append (":");
     }
-    PrintStemLine (dstr, OPTABLE_Text, true);
-    if (ctext) { dstr->Append ("</run></darkblue>"); }
-    dstr->Append (":");
     dstr->Append (" +", TheoryResults[RESULT_White]);
     dstr->Append (" =", TheoryResults[RESULT_Draw]);
     dstr->Append (" -", TheoryResults[RESULT_Black]);
@@ -1188,11 +1226,12 @@ OpTable::PrintText (DString * dstr, const char * title, const char * comment,
             if (HasNotes (Row[row], j)) {
                 if (ctext) {
                     dtemp->Append ("<red><go n", NumNotes, ">");
+                    dtemp->Append ("<N", NumNotes, ">");
                 }
                 uint oldwidth = dtemp->Length();
                 dtemp->Append ("[", NumNotes, "]");
                 width += dtemp->Length() - oldwidth;
-                if (ctext) { dtemp->Append ("</go></red>"); }
+                if (ctext) { dtemp->Append ("</N", NumNotes, "></go></red>"); }
             }
             // Pad width to full cell width:
             while (width < cellBytes) {
@@ -1288,7 +1327,7 @@ OpTable::NoteScore (uint note)
     uint score = 0;
     for (uint n = 0; n < NumTableLines; n++) {
         if (Line[n]->NoteNumber == note) {
-            count++; 
+            count++;
             score += RESULT_SCORE[Line[n]->Result];
         }
     }
@@ -1316,7 +1355,7 @@ OpTable::PrintNotes (DString * dstr, uint format)
         preNotesList = "\n\n<ol>\n";
         postNotesList = "</ol>\n";
         para = "<br>\n";  nextGame = ";\n";
-        endNote = "<p>\n";
+        endNote = "</a><p>\n";
     } else if (format == OPTABLE_CText) {
         nextGame = ";  ";
         endNote = "</tab>\n\n";
@@ -1329,12 +1368,12 @@ OpTable::PrintNotes (DString * dstr, uint format)
             dstr->Append ("\\notenum{", note, "}\n");
         } else if (format == OPTABLE_HTML) {
             //dstr->Append ("<li><b>", note, "</b> ");
-            dstr->Append ("<li> ");
+            dstr->Append ("<li><a name=\"note", note, "\"></a> ");
         } else if (format == OPTABLE_CText) {
-            dstr->Append ("<tab><red><run sc_optable select note ", note);
-            dstr->Append ("; updateStatsWin><n", note);
-            dstr->Append (">[", note, "]");
-            dstr->Append ("</n", note, "></run></red>  ");
+            dstr->Append ("<tab><red><go N", note, ">");
+            dstr->Append ("<n", note, ">");
+            dstr->Append ("[", note, "]");
+            dstr->Append ("</n", note, "></go></red>  ");
         } else {
             dstr->Append ("[*", note, "*]  ");
         }
@@ -1455,6 +1494,9 @@ OpTable::BestGames (DString * dstr, uint count, const char * rtype)
         if (Line[bestIndex]->NoteNumber != 0) {
             if (Format == OPTABLE_LaTeX) {
                 dstr->Append (" $^{", Line[bestIndex]->NoteNumber, "}$");
+            } else if (Format == OPTABLE_HTML) {
+                dstr->Append (" [<a href=\"#note", Line[bestIndex]->NoteNumber);
+                dstr->Append ("\">", Line[bestIndex]->NoteNumber, "</a>]");
             } else if (Format == OPTABLE_CText) {
                 dstr->Append (" <red><go n", Line[bestIndex]->NoteNumber);
                 dstr->Append (">[", Line[bestIndex]->NoteNumber,
@@ -1586,7 +1628,11 @@ OpTable::TopPlayers (DString * dstr, colorT c, uint count)
     const char * endNotes = "]";
 
     if (Format == OPTABLE_HTML) {
-        startTable = "<pre>\n"; endTable = "</pre>\n";
+        startTable = "<table border=0 cellspacing=0 cellpadding=4>\n";
+        endTable = "</table>\n";
+        startRow = "<tr><td align=\"right\">";  endRow = "</td></tr>\n";
+        nextCell = "</td><td>";
+        // startTable = "<pre>\n"; endTable = "</pre>\n";
     }
     if (Format == OPTABLE_CText) {
         startRow = "<tt>"; startName = "</tt>";
@@ -1695,6 +1741,115 @@ OpTable::TopPlayers (DString * dstr, colorT c, uint count)
     delete[] pf;
 }
 
+//~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+// OpTable::TopEcoCodes:
+//    Returns (through dstr) a list of the most frequent ECO code
+//    sections of the report games.
+//    This is generally only useful for a Player report.
+void
+OpTable::TopEcoCodes (DString * dstr, uint count)
+{
+    uint ecoCount [50];
+    uint ecoScore [50];
+    uint ecoSubCount[50][10];
+
+    for (uint ecoGroup=0; ecoGroup < 50; ecoGroup++) {
+        ecoCount[ecoGroup] = 0;
+        ecoScore[ecoGroup] = 0;
+        for (uint subCode = 0; subCode < 10; subCode++) {
+            ecoSubCount[ecoGroup][subCode] = 0;
+        }
+    }
+
+    // Fill in the ECO frequencies array:
+    for (uint i=0; i < NumLines; i++) {
+        int ecoClass = -1;
+        int ecoSubCode = -1;
+        ecoT ecoCode = Line[i]->EcoCode;
+        if (ecoCode != ECO_None) {
+            ecoStringT ecoStr;
+            eco_ToBasicString (ecoCode, ecoStr);
+            if (ecoStr[0] != 0) {
+                ecoClass = ((ecoStr[0] - 'A') * 10) + (ecoStr[1] - '0');
+                if (ecoClass < 0  ||  ecoClass >= 50) { ecoClass = -1; }
+                ecoSubCode = (ecoStr[2] - '0');
+            }
+        }
+        if (ecoClass >= 0) {
+            ecoCount[ecoClass]++;
+            ecoScore[ecoClass] += RESULT_SCORE[Line[i]->Result];
+            ecoSubCount[ecoClass][ecoSubCode]++;
+        }
+    }
+
+    const char * preNum = " ";
+    const char * postNum = ":";
+    const char * inRange = "-";
+    const char * percentStr = "%";
+    const char * startTable = "";
+    const char * endTable = "";
+    const char * startRow = "";
+    const char * endRow = "\n";
+    const char * nextCell = " ";
+
+    if (Format == OPTABLE_HTML) {
+        startTable = "<table border=0 cellspacing=0 cellpadding=4>\n";
+        endTable = "</table>\n";
+        startRow = "<tr><td align=\"right\">";  endRow = "</td></tr>\n";
+        nextCell = "</td><td align=\"right\">";
+        // startTable = "<pre>\n"; endTable = "</pre>\n";
+    }
+    if (Format == OPTABLE_CText) {
+        startTable = "<tt>"; endTable = "</tt>";
+    }
+    if (Format == OPTABLE_LaTeX) {
+        startTable = "\n\\begin{tabular}{rlrr}\n";
+        endTable = "\\end{tabular}\n";
+        startRow = "  ";      endRow = " \\\\ \n";
+        nextCell = " & ";     percentStr = "\\%";
+        preNum = "\\textbf{"; postNum = ":}";
+        inRange = "--";
+    }
+
+    dstr->Append (startTable);
+
+    // Now find the "count" most frequent ECO groups:
+    for (uint n=1; n <= count; n++) {
+        uint maxFreq = 0;
+        uint ecoClass = 0;
+        for (uint i=0; i < 50; i++) {
+            if (ecoCount[i] > maxFreq) {
+                ecoClass = i;
+                maxFreq = ecoCount[i];
+            }
+        }
+        if (maxFreq > 0) {
+            char ecoStr[4];
+            strCopy (ecoStr, "A00-E99");
+            ecoStr[0] = (ecoClass / 10) + 'A';
+            ecoStr[1] = (ecoClass % 10) + '0';
+            ecoStr[2] = '0';
+            ecoStr[3] = 0;
+
+            char tempStr [100];
+            sprintf (tempStr, "%2u", n);
+            dstr->Append (startRow, preNum, tempStr, postNum);
+            dstr->Append (nextCell, ecoStr);
+            ecoStr[2] = '9';
+            dstr->Append (inRange, ecoStr);
+            sprintf (tempStr, "%3u", maxFreq);
+            dstr->Append (nextCell, tempStr);
+
+            uint score = (50 * ecoScore[ecoClass] + (maxFreq / 2)) / maxFreq;
+            sprintf (tempStr, "%3u%s", score, percentStr);
+            dstr->Append (nextCell, tempStr);
+            dstr->Append (endRow);
+            ecoCount[ecoClass] = 0;
+        }
+    }
+    dstr->Append (endTable);
+}
+
 uint
 OpTable::AvgLength (resultT result)
 {
@@ -1846,8 +2001,9 @@ OpTable::PopularMoveOrders (DString * dstr, uint count)
         sprintf (tempStr, "%2u", i+1);
         dstr->Append (preNum, tempStr, postNum);
         if (Format == OPTABLE_CText) {
-            dstr->Append ("<tab><darkblue><run sc_optable select mo ",
-                          MoveOrder[i].id, "; updateStatsWin>");
+            dstr->Append ("<tab><darkblue>");
+            dstr->Append ("<run sc_report ", Type, " select mo ");
+            dstr->Append (MoveOrder[i].id, "; updateStatsWin>");
         }
         OpLine::PrintMove (dstr, MoveOrder[i].moves, Format);
         dstr->Append (preCount, MoveOrder[i].count, postCount);
@@ -1869,16 +2025,17 @@ OpTable::ThemeReport (DString * dstr, uint argc, const char ** argv)
     const char * startRow = "  ";
     const char * endRow = "\n";
     const char * nextCell = " ";
+    const char * nextCellRight = " ";
 
-    if (argc != NUM_OPTHEMES+1) { return; }
+    if (argc != (NUM_POSTHEMES + 1)) { return; }
 
     if (Format == OPTABLE_HTML) {
-        //endLine = "<br>\n";
-        //startTable = "<table border=0 cellspacing=0 cellpadding=4>\n";
-        //endTable = "</table>";
-        //startRow = "<tr><td>";  endRow = "</td></tr>\n";
-        //nextCell = "</td><td>";
-        startTable = "<pre>\n"; endTable = "</pre>\n";
+        endLine = "<br>\n";
+        startTable = "<table border=0 cellspacing=0 cellpadding=4>\n";
+        endTable = "</table>\n";
+        startRow = "<tr><td>";  endRow = "</td></tr>\n";
+        nextCell = "</td><td>";  nextCellRight = "</td><td align=\"right\">";
+        //startTable = "<pre>\n"; endTable = "</pre>\n";
     }
     if (Format == OPTABLE_CText) {
         startTable = "<tt>"; endTable = "</tt>";
@@ -1888,30 +2045,32 @@ OpTable::ThemeReport (DString * dstr, uint argc, const char ** argv)
         startTable = "\n\\begin{tabular}{lrlr}\n";
         endTable = "\\end{tabular}\n";
         startRow = "";  endRow = " \\\\ \n";
-        nextCell = " & ";
+        nextCell = " & ";  nextCellRight = nextCell;
     }
 
-    const char * themeName [NUM_OPTHEMES] = {NULL};
-    themeName [OPTHEME_QueenSwap] = "Queens exchanged:           ";
-    themeName [OPTHEME_CastSame]  = "Same-side castling:         ";
-    themeName [OPTHEME_CastOpp]   = "Opposite castling:          ";
-    themeName [OPTHEME_CastNone]  = "Both Kings uncastled:       ";
-    themeName [OPTHEME_IQP]       = "Isolated Queen Pawn:        ";
-    themeName [OPTHEME_WAdvPawn]  = "White Pawn on 5/6/7th rank: ";
-    themeName [OPTHEME_BAdvPawn]  = "Black Pawn on 2/3/4th rank: ";
-    themeName [OPTHEME_Kstorm]    = "Kingside pawn storm:        ";
-    themeName [OPTHEME_OpenFyle]  = "Open c/d/e file:            ";
-    themeName [OPTHEME_BPair]     = "Only 1 side has Bishop pair:";
+    const char * themeName [NUM_POSTHEMES] = {NULL};
+    themeName [POSTHEME_CastSame]  = "Same-side castling:         ";
+    themeName [POSTHEME_CastOpp]   = "Opposite castling:          ";
+    themeName [POSTHEME_QueenSwap] = "Queens exchanged:           ";
+    themeName [POSTHEME_OneBPair]  = "Only 1 side has Bishop pair:";
+    themeName [POSTHEME_Kstorm]    = "Kingside pawn storm:        ";
+    themeName [POSTHEME_WIQP]      = "White Isolated Queen Pawn:  ";
+    themeName [POSTHEME_BIQP]      = "Black Isolated Queen Pawn:  ";
+    themeName [POSTHEME_WAdvPawn]  = "White Pawn on 5/6/7th rank: ";
+    themeName [POSTHEME_BAdvPawn]  = "Black Pawn on 2/3/4th rank: ";
+    themeName [POSTHEME_OpenFyle]  = "Open c/d/e file:            ";
 
     char tempStr [250];
-    sprintf (tempStr, argv[0], (StartLength + (OPTABLE_COLUMNS * 2)) / 2);
+    //sprintf (tempStr, argv[0], (StartLength + (OPTABLE_COLUMNS * 2)) / 2);
+    sprintf (tempStr, argv[0], MaxThemeMoveNumber);
     dstr->Append (tempStr, endLine);
-    argc--; argv++;
+    argc--;
+    argv++;
 
     dstr->Append (startTable);
-    uint leftcol = (NUM_OPTHEMES + 1) / 2;
+    uint leftcol = (NUM_POSTHEMES + 1) / 2;
     uint longestLength = 0;
-    for (uint i=0; i < NUM_OPTHEMES; i++) {
+    for (uint i=0; i < NUM_POSTHEMES; i++) {
         uint len = strLength (argv[i]);
         if (len > longestLength) { longestLength = len; }
     }
@@ -1921,23 +2080,25 @@ OpTable::ThemeReport (DString * dstr, uint argc, const char ** argv)
         dstr->Append (theme < leftcol ? startRow : nextCell);
         strPad (tempStr, argv[theme], longestLength, ' ');
         if (Format == OPTABLE_CText) {
-            dstr->Append ("<darkblue><run sc_optable select op ", theme,
-                          "; updateStatsWin>");
+            dstr->Append ("<darkblue><run sc_report ", Type, " select theme ");
+            dstr->Append (theme, "; updateStatsWin>");
         }
         dstr->Append (" ", tempStr);
         if (Format == OPTABLE_CText) { dstr->Append ("</run></darkblue>"); }
-        dstr->Append (nextCell);
-        uint r = ((100 * ThemeCount[theme]) + (FilterCount/2)) / FilterCount;
+        dstr->Append (nextCellRight);
+        uint percent = 0;
+        if (FilterCount > 0) {
+            percent = ((100 * ThemeCount[theme]) + (FilterCount/2)) / FilterCount;
+        }
         char rstr [16];
-        sprintf (rstr, "%3u", r);
+        sprintf (rstr, "%3u", percent);
         dstr->Append (rstr, percentStr);
-        if (Format == OPTABLE_HTML) { dstr->Append ("</td>"); }
         if (theme < leftcol) {
             dstr->Append ("  ");
         } else {
             dstr->Append (endRow);
         }
-        if (theme == NUM_OPTHEMES - 1) { break; }
+        if (theme == NUM_POSTHEMES - 1) { break; }
         if (theme < leftcol) {
             theme += leftcol;
         } else {
@@ -1945,7 +2106,7 @@ OpTable::ThemeReport (DString * dstr, uint argc, const char ** argv)
             theme++;
         }
     }
-    if (NUM_OPTHEMES % 2 == 1) { dstr->Append (endRow); }
+    if (NUM_POSTHEMES % 2 == 1) { dstr->Append (endRow); }
     dstr->Append (endTable);
 }
 
@@ -1973,7 +2134,11 @@ OpTable::EndMaterialReport (DString * dstr, const char * repGames,
     const char * postNum = "";
 
     if (Format == OPTABLE_HTML) {
-        startTable = "<pre>\n"; endTable = "</pre>\n";
+        startTable = "<table border=0 cellspacing=0 cellpadding=4>\n";
+        endTable = "</table>\n";
+        startRow = "<tr><td>";  endRow = "</td></tr>\n";
+        nextCell = "</td><td align=\"right\">";
+        // startTable = "<pre>\n"; endTable = "</pre>\n";
     }
     if (Format == OPTABLE_CText) {
         startTable = "<tt>"; endTable = "</tt>";
@@ -2005,6 +2170,7 @@ OpTable::EndMaterialReport (DString * dstr, const char * repGames,
         dstr->Append (p, bn, r, bn); dstr->Append (q, bn, qr, bn);
         dstr->Append (endRow, "\\hline\n");
     } else {
+        dstr->Append(startRow);
         uint len = length[OPTABLE_Line];
         if (length[OPTABLE_All] > len) { len = length[OPTABLE_All]; }
         len++;
@@ -2030,8 +2196,8 @@ OpTable::EndMaterialReport (DString * dstr, const char * repGames,
             sprintf (numStr, "%5u", pc);
             dstr->Append (nextCell);
             if (Format == OPTABLE_CText  &&  t == OPTABLE_Line) {
-                dstr->Append ("<darkblue><run sc_optable select end ", i,
-                              "; updateStatsWin>");
+                dstr->Append ("<darkblue><run sc_report ", Type);
+                dstr->Append (" select end ", i, "; updateStatsWin>");
             }
             dstr->Append (preNum, numStr, percentStr, postNum);
             if (Format == OPTABLE_CText  &&  t == OPTABLE_Line) {
@@ -2068,9 +2234,10 @@ OpTable::SelectGames (char type, uint number)
         if (type == 'e') {
             // Only games from one endgame classification:
             if (line->EgTheme == number) { selected = true; }
-        } else if (type == 'o') {
-            // Only games from one opening theme:
-            if (number < NUM_OPTHEMES  &&  line->Theme[number]) {
+        } else if (type == 't') {
+            // Only games from one positional theme:
+            if (number < NUM_POSTHEMES
+                  &&  line->Theme[number] >= POSTHEME_THRESHOLD) {
                 selected = true;
             }
         } else if (type == 'n') {
