@@ -1,6 +1,6 @@
 ###
 ### analysis.tcl: part of Scid.
-### Copyright (C) 1999-2002  Shane Hudson.
+### Copyright (C) 1999-2003  Shane Hudson.
 ###
 
 ######################################################################
@@ -26,7 +26,7 @@ proc resetEngine {n} {
   set analysis(seen$n) 0              ;# Seen any output from engine yet?
   set analysis(seenEval$n) 0          ;# Seen evaluation line yet?
   set analysis(score$n) 0             ;# Current score in centipawns
-  set analysis(nodes$n) 0             ;# Number of nodes searched
+  set analysis(nodes$n) 0             ;# Number of (kilo)nodes searched
   set analysis(depth$n) 0             ;# Depth in ply
   set analysis(prev_depth$n) 0        ;# Previous depth
   set analysis(time$n) 0              ;# Time in centisec (or sec; see below)
@@ -49,6 +49,7 @@ proc resetEngine {n} {
   set analysis(log$n) ""              ;# Log file channel
   set analysis(logCount$n) 0          ;# Number of lines sent to log file
   set analysis(wbEngineDetected$n) 0  ;# Is this a special Winboard engine?
+  set analysis(priority$n) normal     ;# CPU priority: idle/normal
 }
 
 resetEngine 1
@@ -57,6 +58,22 @@ resetEngine 2
 set annotateMode 0
 set annotateMoves all
 
+ 
+# calculateNodes:
+#   Divides string-represented node count by 1000
+#
+proc calculateNodes {{n}} {
+  set len [string length $n]
+  if { $len < 4 } {
+     return 0 
+  } else {
+     set shortn [string range $n 0 [expr {$len - 4}]]
+     scan $shortn "%d" nd
+     return $nd
+  }
+}
+
+
 # resetAnalysis:
 #   Resets the analysis statistics: score, depth, etc.
 #
@@ -105,7 +122,7 @@ proc engine {arglist} {
 #   Reads the user Engine list file.
 #
 proc ::enginelist::read {} {
-  catch {source $::engines(file)}
+  catch {source [scidConfigFile engines]}
 }
 
 # ::enginelist::write:
@@ -113,10 +130,12 @@ proc ::enginelist::read {} {
 #
 proc ::enginelist::write {} {
   global engines
-  # Try to rename old list to backup file and open new file:
-  catch {file rename -force $engines(file) $engines(backup)}
-  if {[catch {open $engines(file) w} f]} {
-    catch {file rename $engines(backup) $engines(file)}
+  set enginesFile [scidConfigFile engines]
+  set enginesBackupFile [scidConfigFile engines.bak]
+  # Try to rename old file to backup file and open new file:
+  catch {file rename -force $enginesFile $enginesBackupFile}
+  if {[catch {open $enginesFile w} f]} {
+    catch {file rename $enginesBackupFile $enginesFile}
     return 0
   }
 
@@ -149,7 +168,16 @@ proc ::enginelist::write {} {
 #
 catch { ::enginelist::read }
 if {[llength $engines(list)] == 0} {
-  # No engines, so set up a default engine list:
+  # No engines, so set up a default engine list with Scidlet and Crafty:
+  set cmd scidlet
+  if {$::windowsOS} {
+    set cmd [file join $::scidExeDir scidlet.exe]
+  }
+  engine [list \
+    Name Scidlet \
+    Cmd  $cmd \
+    Dir  . \
+  ]
   set cmd crafty
   if {$::windowsOS} { set cmd wcrafty.exe }
   engine [list \
@@ -271,7 +299,7 @@ proc ::enginelist::choose {} {
   set f $w.list
   pack [frame $f] -side top -expand yes -fill both
   listbox $f.list -height 10 -width 55  -selectmode browse \
-    -selectbackground lightBlue -background white -setgrid 1 \
+    -background white -setgrid 1 \
     -yscrollcommand "$f.ybar set" -font font_Fixed -exportselection 0
   bind $f.list <Double-ButtonRelease-1> "$w.buttons.ok invoke; break"
   scrollbar $f.ybar -command "$f.list yview"
@@ -307,7 +335,7 @@ proc ::enginelist::choose {} {
   bind $w <Escape> "destroy $w"
   bind $w.list.list <Return> "$w.buttons.ok invoke; break"
   set engines(selection) ""
-  grab $w
+  catch {grab $w}
   tkwait window $w
   return $engines(selection)
 }
@@ -326,7 +354,7 @@ proc ::enginelist::setTime {index {time -1}} {
   set engines(list) [lreplace $engines(list) $index $index $e]
 }
 
-trace variable engines(newElo) w {forceInt 4000 0}
+trace variable engines(newElo) w [list forceInt [sc_info limit elo] 0]
 
 # ::enginelist::delete
 #   Removes an engine from the list.
@@ -503,13 +531,13 @@ proc ::enginelist::edit {index} {
   pack $f.cancel $f.ok -side right -padx 2 -pady 2
   label $f.required -font font_Small -text $::tr(EngineRequired)
   pack $f.required -side left
-  
+
   bind $w <Return> "$f.ok invoke"
   bind $w <Escape> "destroy $w"
   bind $w <F1> { helpWindow Analysis List }
   focus $w.f.eName
   wm resizable $w 1 0
-  grab $w
+  catch {grab $w}
 }
 
 proc addAnalysisVariation {{n 1}} {
@@ -539,7 +567,7 @@ proc addAnalysisVariation {{n 1}} {
   sc_var exit
   # Remove the variation if necessary:
   if {$annotateMode  &&  $annotateMoves == "notbest"} {
-    set lastvar [expr [sc_var count] - 1]
+    set lastvar [expr {[sc_var count] - 1} ]
     set firstMove [lindex [sc_var list] $lastvar]
     if {$firstMove == [sc_game info next]} {
       sc_var delete $lastvar
@@ -547,7 +575,9 @@ proc addAnalysisVariation {{n 1}} {
   }
   # Restore the pre-move command:
   sc_info preMoveCmd preMoveCommand
-  updateBoardAndPgn
+  updateBoard -pgn
+  # Update score graph if it is open:
+  if {[winfo exists .sgraph]} { updateScoreGraph }
 }
 
 proc addAnalysisToComment {line {n 1}} {
@@ -563,7 +593,7 @@ proc addAnalysisToComment {line {n 1}} {
   }
   set score $analysis(score$n)
   if {$analysis(invertScore$n)  && (! [string compare [sc_pos side] "black"])} {
-    set score [expr 0.0 - $score]
+    set score [expr {0.0 - $score} ]
   }
 
   # If line is true, add the whole line, else just add the score:
@@ -607,7 +637,7 @@ proc makeAnalysisMove {{n 1}} {
   set ::analysis(automoveThinking$n) 0
   if {$action == "var"} { sc_var create }
   if {[catch {sc_move addSan $move}]} { return 0 }
-  updateBoardAndPgn .board
+  updateBoard -pgn
   return 1
 }
 
@@ -632,6 +662,15 @@ proc destroyAnalysisWin {{n 1}} {
   # so ensure the engine exits analyze mode first:
   sendToEngine $n "exit"
   sendToEngine $n "quit"
+  flush $analysis(pipe$n)
+
+  # Uncomment the following line to turn on blocking mode before
+  # closing the engine (but probably not a good idea!)
+  #   fconfigure $analysis(pipe$n) -blocking 1
+
+  # Close the engine, ignoring any errors since nothing can really
+  # be done about them anyway -- maybe should alert the user with
+  # a message box?
   catch {close $analysis(pipe$n)}
 
   if {$analysis(log$n) != ""} {
@@ -656,6 +695,9 @@ proc sendToEngine {n text} {
 #   that it wants it, send with "usermove " before the move.
 #
 proc sendMoveToEngine {n move} {
+  # Convert "e7e8Q" into "e7e8q" since that is the XBoard/WinBoard
+  # standard for sending moves in coordinate notation:
+  set move [string tolower $move]
   if {$::analysis(wants_usermove$n)} {
     sendToEngine $n "usermove $move"
   } else {
@@ -754,7 +796,7 @@ proc makeAnalysisWin {{n 1}} {
   # Open log file if applicable:
   set analysis(log$n) ""
   if {$analysis(logMax) > 0} {
-    if {! [catch {open [file join $::scidUserDir "engine$n.log"] w} log]} {
+    if {! [catch {open [file join $::scidLogDir "engine$n.log"] w} log]} {
       set analysis(log$n) $log
       logEngine $n "Scid-Engine communication log file"
       logEngine $n "Engine: $analysisName"
@@ -780,6 +822,11 @@ proc makeAnalysisWin {{n 1}} {
     wm title $w "Scid: Analysis $n: $analysisName"
   }
   bind $w <F1> { helpWindow Analysis }
+  setWinLocation $w
+
+  ::board::new $w.bd 25
+  $w.bd configure -relief solid -borderwidth 1
+  set analysis(showBoard$n) 0
 
   frame $w.b1
   frame $w.b2
@@ -792,21 +839,27 @@ proc makeAnalysisWin {{n 1}} {
     -command "addAnalysisVariation $n"
   button $w.b1.move -textvar ::tr(AddMove) \
     -command "makeAnalysisMove $n"
+  button $w.b1.showboard -image tb_coords -command "toggleAnalysisBoard $n"
   if {$n == 1} {
     checkbutton $w.b2.annotate -textvar ::tr(Annotate...) \
       -variable annotateMode -relief raised -pady 5 -padx 4 \
       -command {toggleAutoplay 1}
   }
+  checkbutton $w.b2.priority -text $::tr(LowPriority) \
+      -variable analysis(priority$n) -onvalue idle -offvalue normal \
+      -command "setAnalysisPriority $n"
   button $w.b2.update -textvar ::tr(Update) \
     -command "sendToEngine $n ."
   button $w.b2.help -textvar ::tr(Help) -command { helpWindow Analysis }
   button $w.b2.close -textvar ::tr(Close) -command "focus .; destroy $w"
 
   pack $w.b1.automove $w.b1.line $w.b1.move -side left -padx 2 -pady 2
+  pack $w.b1.showboard -side right -padx 2 -pady 2
   pack $w.b2.close $w.b2.help $w.b2.update -side right -padx 2 -pady 2
   if {$n == 1} {
     pack $w.b2.annotate -side left -padx 2 -pady 2
   }
+  pack $w.b2.priority -side left -padx 2 -pady 2
 
   text $w.text -width 50 -height 5 -fg black -bg white -font font_Fixed \
     -wrap word
@@ -830,13 +883,50 @@ until the board changes. So if you see this message, try changing the board \
 by moving backwards or forwards or making a new move."
   $w.text configure -state disabled
   bind $w <Destroy> "destroyAnalysisWin $n"
+  bind $w <Configure> "recordWinSize $w"
   wm minsize $w 45 0
+  bindMouseWheel $w $w.hist.text
 
   fileevent $analysis(pipe$n) readable "processAnalysisInput $n"
 
   after 1000 "checkAnalysisStarted $n"
 }
 
+# setAnalysisPriority
+#   Sets the priority class (in Windows) or nice level (in Unix)
+#   of a running analysis engine.
+#
+proc setAnalysisPriority {n} {
+  global analysis
+
+  # Get the process ID of the analysis engine:
+  if {$analysis(pipe$n) == ""} { return }
+  set pidlist [pid $analysis(pipe$n)]
+  if {[llength $pidlist] < 1} { return }
+  set pid [lindex $pidlist 0]
+
+  # Set the priority class (idle or normal):
+  if {$::windowsOS} {
+    catch {sc_info priority $pid $analysis(priority$n)}
+  } else {
+    set priority 0
+    if {$analysis(priority$n) == "idle"} { set priority 15 }
+    catch {sc_info priority $pid $priority}
+  }
+
+  # Re-read the priority class for confirmation:
+  if {[catch {sc_info priority $pid} newpriority]} { return }
+  if {$::windowsOS} {
+    if {$newpriority == "idle"  ||  $newpriority == "normal"} {
+      set analysis(priority$n) $newpriority
+    }
+  } else {
+    set priority normal
+    if {$newpriority > 0} { set priority idle }
+    set analysis(priority$n) $priority
+  }
+}
+
 # checkAnalysisStarted
 #   Called a short time after an analysis engine was started
 #   to send it commands if Scid has not seen any output from
@@ -899,11 +989,12 @@ proc processAnalysisInput {{n 1}} {
   # has the setboard and analyze commands:
   #
   if {! [string compare [string range $line 0 6] "feature"]} {
-    if {[regexp "analyze=1" $line]} { set analysis(has_analyze$n) 1 }
-    if {[regexp "setboard=1" $line]} { set analysis(has_setboard$n) 1 }
-    if {[regexp "usermove=1" $line]} { set analysis(wants_usermove$n) 1 }
-    if {[regexp "sigint=1" $line]} { set analysis(send_sigint$n) 1 }
-    if {[regexp "myname=\"(\[^\"\]*)\"" $line dummy name]} {
+    if {[string match "*analyze=1*" $line]} { set analysis(has_analyze$n) 1 }
+    if {[string match "*setboard=1*" $line]} { set analysis(has_setboard$n) 1 }
+    if {[string match "*usermove=1*" $line]} { set analysis(wants_usermove$n) 1 }
+    if {[string match "*sigint=1*" $line]} { set analysis(send_sigint$n) 1 }
+    if {[string match "*myname=*" $line] && \
+        [regexp "myname=\"(\[^\"\]*)\"" $line dummy name]} {
       if {$n == 1} {
         catch {wm title .analysisWin$n "Scid: Analysis: $name"}
       } else {
@@ -917,7 +1008,7 @@ proc processAnalysisInput {{n 1}} {
   # Check for a line starting with "Crafty", so Scid can work well
   # with older Crafty versions that do not recognize "protover":
   #
-  if {[regexp "^Crafty" $line]} {
+  if {! [string compare [string range $line 0 5] "Crafty"]} {
     logEngineNote $n {Seen "Crafty"; assuming analyze and setboard commands.}
     set major 0
     if {[scan $line "Crafty v%d.%d" major minor] == 2  &&  $major >= 18} {
@@ -938,20 +1029,20 @@ proc processAnalysisInput {{n 1}} {
 
   # Scan the line from the engine for the analysis data:
   #
-  set res [scan $line "%d%c %d %d %d %\[^\n\]\n" \
+  set res [scan $line "%d%c %d %d %s %\[^\n\]\n" \
              temp_depth dummy temp_score \
              temp_time temp_nodes temp_moves]
   if {$res == 6} {
     set analysis(depth$n) $temp_depth
     set analysis(score$n) $temp_score
     set analysis(time$n) $temp_time
-    set analysis(nodes$n) $temp_nodes
+    set analysis(nodes$n) [calculateNodes $temp_nodes]
     set analysis(moves$n) [formatAnalysisMoves $temp_moves]
     # Convert score to pawns from centipawns:
-    set analysis(score$n) [expr double($analysis(score$n)) / 100.0]
+    set analysis(score$n) [expr {double($analysis(score$n)) / 100.0} ]
     # Convert time to seconds from centiseconds:
     if {! $analysis(wholeSeconds$n)} {
-      set analysis(time$n) [expr double($analysis(time$n)) / 100.0]
+      set analysis(time$n) [expr {double($analysis(time$n)) / 100.0} ]
     }
     updateAnalysisText $n
     if {! $analysis(seenEval$n)} {
@@ -966,14 +1057,14 @@ proc processAnalysisInput {{n 1}} {
   # Check for a "stat01:" line, the reply to the "." command:
   #
   if {! [string compare [string range $line 0 6] "stat01:"]} {
-    if {[scan $line "%s %d %d %d" \
+    if {[scan $line "%s %d %s %d" \
            dummy temp_time temp_nodes temp_depth] == 4} {
       set analysis(depth$n) $temp_depth
       set analysis(time$n) $temp_time
-      set analysis(nodes$n) $temp_nodes
+      set analysis(nodes$n) [calculateNodes $temp_nodes]
       # Convert time to seconds from centiseconds:
       if {! $analysis(wholeSeconds$n)} {
-        set analysis(time$n) [expr double($analysis(time$n)) / 100.0]
+        set analysis(time$n) [expr {double($analysis(time$n)) / 100.0} ]
       }
       updateAnalysisText $n
     }
@@ -1038,13 +1129,13 @@ proc updateAnalysisText {{n 1}} {
   global analysis
   set nps 0
   if {$analysis(time$n) > 0.0} {
-    set nps [expr round($analysis(nodes$n) / $analysis(time$n))]
+    set nps [expr {round($analysis(nodes$n) / $analysis(time$n))} ]
   }
-  set newStr [format "Depth:   %6u      Nodes: %8u (%u n/s)\n" \
+  set newStr [format "Depth:   %6u      Nodes: %6uK (%u kn/s)\n" \
                 $analysis(depth$n) $analysis(nodes$n) $nps]
   set score $analysis(score$n)
   if {$analysis(invertScore$n)  && (![string compare [sc_pos side] "black"])} {
-    set score [expr 0.0 - $score]
+    set score [expr {0.0 - $score} ]
   }
   append newStr [format "Score: %+8.2f      Time: %9.2f seconds\n" \
                    $score $analysis(time$n)]
@@ -1058,29 +1149,73 @@ proc updateAnalysisText {{n 1}} {
     } else {
       set moves "   Your move..... "
     }
-  } else {
-    set moves $analysis(moves$n)
+    $t insert end $moves blue
+    $t configure -state disabled
+    updateAnalysisBoard $n ""
+    return
   }
 
-  if {! $analysis(automove$n)} {
-    set h .analysisWin$n.hist.text
-    $h configure -state normal
-    set cleared 0
-    if {$analysis(depth$n) < $analysis(prev_depth$n)  || \
-        $analysis(prev_depth$n) == 0} {
-      $h delete 1.0 end
-      set cleared 1
-    }
-    if {! $cleared} { $h insert end "\n" }
-    $h insert end [format "%2d %+5.2f  %s (%.2f)" $analysis(depth$n) \
-                     $score $moves $analysis(time$n)] indent
-    $h see end-1c
-    $h configure -state disabled
-    set analysis(prev_depth$n) $analysis(depth$n)
+  set moves $analysis(moves$n)
+  set h .analysisWin$n.hist.text
+  $h configure -state normal
+  set cleared 0
+  if {$analysis(depth$n) < $analysis(prev_depth$n)  || \
+      $analysis(prev_depth$n) == 0} {
+    $h delete 1.0 end
+    set cleared 1
   }
+  if {! $cleared} { $h insert end "\n" }
+  $h insert end [format "%2d %+5.2f  %s (%.2f)" $analysis(depth$n) \
+                   $score $moves $analysis(time$n)] indent
+  $h see end-1c
+  $h configure -state disabled
+  set analysis(prev_depth$n) $analysis(depth$n)
+
   $t insert end $moves blue
   $t tag add score 2.0 2.13
   $t configure -state disabled
+
+  updateAnalysisBoard $n $moves
+}
+
+# toggleAnalysisBoard
+#   Toggle whether the small analysis board is shown.
+#
+proc toggleAnalysisBoard {n} {
+  global analysis
+  if {$analysis(showBoard$n)} {
+    set analysis(showBoard$n) 0
+    pack forget .analysisWin$n.bd
+  } else {
+    set analysis(showBoard$n) 1
+    pack .analysisWin$n.bd -side right -before .analysisWin$n.b2 \
+      -padx 4 -pady 4 -anchor n
+  }
+}
+
+# updateAnalysisBoard
+#   Update the small analysis board in the analysis window,
+#   showing the position after making the specified moves
+#   from the current main board position.
+#
+proc updateAnalysisBoard {n moves} {
+  global analysis
+  # if {! $analysis(showBoard$n)} { return }
+
+  set bd .analysisWin$n.bd
+  # Temporarily wipe the premove command:
+  sc_info preMoveCmd {}
+  # Push a temporary copy of the current game:
+  sc_game push copy
+
+  # Make the engine moves and update the board:
+  catch {sc_move addSan $moves}
+  ::board::update $bd [sc_pos board]
+
+  # Pop the temporary game:
+  sc_game pop
+  # Restore pre-move command:
+  sc_info preMoveCmd preMoveCommand
 }
 
 # updateAnalysis
@@ -1099,7 +1234,7 @@ proc updateAnalysis {{n 1}} {
   if {[catch {set clicks [clock clicks -milliseconds]}]} {
     set clicks [clock clicks]
   }
-  set diff [expr $clicks - $analysis(lastClicks$n)]
+  set diff [expr {$clicks - $analysis(lastClicks$n)} ]
   if {$diff < 300  &&  $diff >= 0} {
     if {$analysis(after$n) == ""} {
       set analysis(after$n) [after 300 updateAnalysis $n]
@@ -1119,10 +1254,19 @@ proc updateAnalysis {{n 1}} {
 
   if {$analysis(has_analyze$n)} {
 
+    #
     # This section is for engines that support "analyze":
+    #
 
-    sendToEngine $n "exit"
-    sendToEngine $n "force"
+    sendToEngine $n "exit"   ;# Get out of analyze mode, to send moves.
+
+    # On Crafty, "force" command has different meaning when not in
+    # XBoard mode, and some users have noticed Crafty not being in
+    # that mode at this point -- although I cannot reproduce this.
+    # So just re-send "xboard" to Crafty to make sure:
+    if {$analysis(isCrafty$n)} { sendToEngine $n "xboard" }
+
+    sendToEngine $n "force"  ;# Stop engine replying to moves.
 
     # Check if the setboard command must be used -- that is, if the
     # previous or current position arose from a non-standard start.
@@ -1162,11 +1306,11 @@ proc updateAnalysis {{n 1}} {
     # the same as the previous move list, with one extra move):
 
     if {($newlen == $oldlen + 1) \
-          && ($old_movelist == [lrange $movelist 0 [expr $oldlen - 1]])} {
+          && ($old_movelist == [lrange $movelist 0 [expr {$oldlen - 1} ]])} {
       sendMoveToEngine $n [lindex $movelist $oldlen]
 
     } elseif {($newlen + 1 == $oldlen) && \
-                ($movelist == [lrange $old_movelist 0 [expr $newlen - 1]])} {
+                ($movelist == [lrange $old_movelist 0 [expr {$newlen - 1} ]])} {
 
       # Here the new move list is the same as the old list but with one
       # less move, just send one "undo":
@@ -1228,7 +1372,7 @@ trace variable temptime w {forceRegexp {^[0-9]*\.?[0-9]*$}}
 proc setAutomoveTime {{n 1}} {
   global analysis temptime dialogResult
   set ::tempn $n
-  set temptime [expr $analysis(automoveTime$n) / 1000.0]
+  set temptime [expr {$analysis(automoveTime$n) / 1000.0} ]
   set w .apdialog
   toplevel $w
   #wm transient $w .analysisWin
@@ -1248,17 +1392,17 @@ proc setAutomoveTime {{n 1}} {
   pack $b -side top -fill x
   button $b.cancel -text $::tr(Cancel) -command {
     focus .
-    grab release .apdialog
+    catch {grab release .apdialog}
     destroy .apdialog
     focus .
     set dialogResult Cancel
   }
   button $b.ok -text "OK" -command {
-    grab release .apdialog
+    catch {grab release .apdialog}
     if {$temptime < 0.1} { set temptime 0.1 }
-    set analysis(automoveTime$tempn) [expr int($temptime * 1000)]
+    set analysis(automoveTime$tempn) [expr {int($temptime * 1000)} ]
     focus .
-    grab release .apdialog
+    catch {grab release .apdialog}
     destroy .apdialog
     focus .
     set dialogResult OK
@@ -1266,7 +1410,7 @@ proc setAutomoveTime {{n 1}} {
   pack $b.cancel $b.ok -side right -padx 5 -pady 5
   focus $w.entry
   update
-  grab .apdialog
+  catch {grab .apdialog}
   tkwait window .apdialog
   if {$dialogResult != "OK"} {
     return 0
@@ -1308,7 +1452,7 @@ proc automove_go {{n 1}} {
   if {$analysis(automove$n)} {
     if {[makeAnalysisMove $n]} {
       set analysis(autoMoveThinking$n) 0
-      updateBoardAndPgn .board
+      updateBoard -pgn
       after cancel "automove $n"
       ::tree::doTraining $n
     } else {
