@@ -1,5 +1,5 @@
 # basewind.tcl: part of Scid
-# Copyright (C) 2000   Shane Hudson.
+# Copyright (C) 2000-2003  Shane Hudson.
 
 
 # 0: Unknown/empty
@@ -308,7 +308,7 @@ proc changeBaseType {baseNum} {
     "catch {sc_base type $baseNum \$temp_dbtype}; updateBaseWin;
      focus .; destroy $w"
 
-  button $w.b.cancel -text "Cancel" -command "focus .; destroy $w; focus ."
+  button $w.b.cancel -text $::tr(Cancel) -command "focus .; destroy $w"
   pack $w.b.set $w.b.cancel -side left -padx 5
 
   set numtypes [llength $base_types]
@@ -407,9 +407,11 @@ proc makeBaseWin {} {
       bind $f$win <ButtonRelease-1> "baseWin_offCursor $i %X %Y"
     }
     menu $f.menu -tearoff 0
-    $f.menu add command -label [tr SearchReset] -command "sc_filter reset $i"
+    $f.menu add command -label [tr SearchReset] \
+      -command "sc_filter reset $i; updateStatsWin"
     $f.menu add command -label "Change icon..." -command "changeBaseType $i"
     $f.menu add separator
+    $f.menu add command -label [tr FileOpen] -command fileOpen
     set closeLabel [tr FileClose]
     if {$i == [sc_info clipbase]} { set closeLabel [tr EditReset] }
     $f.menu add command -label $closeLabel \
