@@ -1,6 +1,6 @@
 ###
 ### email.tcl: part of Scid.
-### Copyright (C) 1999-2001  Shane Hudson.
+### Copyright (C) 1999-2003  Shane Hudson.
 ###
 
 # Email manager window: closed by default
@@ -51,7 +51,7 @@ proc makeEmailWin {} {
   bind $w.list <Key-d> {.emailWin.b.delete invoke}
   bind $w.list <Key-l> {.emailWin.b.load invoke}
   bind $w.list <Key-s> {.emailWin.b.send invoke}
-  bind $w.list <Key-t> {tkMbPost .emailWin.b.time}
+  bind $w.list <Key-t> {.emailWin.b.time invoke [winfo pointerx .] [winfo pointery .]}
 
   set w .emailWin.b
 
@@ -123,7 +123,7 @@ proc email_Config {} {
   addHorizontalRule $w
   pack [frame $w.b] -side top -fill x
   button $w.b.ok -text [tr OptionsSave] -command {
-    .menu.options.m invoke [tr OptionsSave]
+    .menu.options invoke [tr OptionsSave]
     catch {grab release .emailConf}
     destroy .emailConf
   }
@@ -173,8 +173,9 @@ proc email_LoadButton {} {
     if {[catch {sc_game load [lindex [lindex $details 3] 0]} result]} {
       tk_messageBox -type ok -icon warning -title "Scid" -message $result
     } else {
+      flipBoardForPlayerNames $::myPlayerNames
       sc_move end
-      updateBoardAndPgn .board
+      updateBoard -pgn
       updateTitle
     }
   }
@@ -201,7 +202,7 @@ proc email_TimesButton {type} {
   if {[llength $emailData] <= $idx} { return }
   set details [lindex $emailData $idx]
   while {[llength $details] < 6} { lappend details {} }
-  set timeList [lindex $details 5] 
+  set timeList [lindex $details 5]
   set last [lindex $timeList end]
 
   if {$type == "r"  || $type == "s"} {
@@ -250,7 +251,7 @@ proc email_addSentReceived {idx type} {
   if {[llength $emailData] <= $idx} { return }
   set details [lindex $emailData $idx]
   while {[llength $details] < 6} { lappend details {} }
-  set timeList [lindex $details 5] 
+  set timeList [lindex $details 5]
   set last [lindex $timeList end]
 
   set new ""
