@@ -1,5 +1,5 @@
 # end.tcl: part of Scid.
-# Copyright (C) 2001 Shane Hudson.
+# Copyright (C) 2000-2003 Shane Hudson.
 
 ############################################################
 ### Main window title, etc:
@@ -50,6 +50,9 @@ proc updateStatusBar {} {
     return
   }
 
+  # Check if translations have not been set up yet:
+  if {! [info exists ::tr(Database)]} { return }
+
   # Show "%%" if base is read-only, "XX" if game altered, "--" otherwise:
   if {[sc_base isReadOnly]} {
     append statusBar "%%"
@@ -79,17 +82,49 @@ proc updateStatusBar {} {
 #    Prompt for confirmation then exit.
 #
 proc fileExit {}  {
-  set answer [tk_dialog .exitDialog "Scid: [tr FileExit]" \
-                $::tr(ExitDialog) "" 0 $::tr(Yes) $::tr(No)]
-  if {$answer == 0} { 
-    if {$::optionsAutoSave} { .menu.options.m invoke [tr OptionsSave] }
-    destroy . 
+  # Check for altered game in all bases except the clipbase:
+  set unsavedCount 0
+  set savedBase [sc_base current]
+  set msg ""
+  set nbases [sc_base count total]
+  for {set i 1} {$i < [sc_base count total]} {incr i} {
+    sc_base switch $i
+    if {[sc_base inUse] && [sc_game altered] && ![sc_base isReadOnly]} {
+      if {$unsavedCount == 0} {
+        append msg $::tr(ExitUnsaved)
+        append msg "\n\n"
+      }
+      incr unsavedCount
+      set fname [file tail [sc_base filename]]
+      set g [sc_game number]
+      append msg "   Base $i: $fname "
+      append msg "($::tr(game) $g)"
+      append msg "\n"
+    }
   }
+  # Switch back to original database:
+  sc_base switch $savedBase
+
+  if {$msg != ""} {
+    append msg "\n"
+  }
+  append msg $::tr(ExitDialog)
+
+  # Only ask before exiting if there are unsaved changes:
+  if {$unsavedCount > 0} {
+    set answer [tk_dialog .exitDialog "Scid: [tr FileExit]" \
+                  $msg "" 0 $::tr(Yes) $::tr(No)]
+    if {$answer != 0} { return }
+  }
+  if {$::optionsAutoSave} { .menu.options invoke [tr OptionsSave] }
+  ::recentFiles::save
+  destroy .
 }
 
 proc fastExit {} {
-  if {$::optionsAutoSave} { .menu.options.m invoke [tr OptionsSave] }
-  destroy . 
+  if {$::optionsAutoSave} { .menu.options invoke [tr OptionsSave] }
+  ::recentFiles::save
+  destroy .
 }
 
 # fileNew:
@@ -101,7 +136,7 @@ proc fileNew {} {
       -message "Too many databases open; close one first"
     return
   }
-  set ftype { 
+  set ftype {
     { "Scid databases, EPD files" {".si3" ".epd"} }
     { "Scid databases" {".si3"} }
     { "EPD files" {".epd"} }
@@ -161,6 +196,10 @@ proc fileOpen {{fName ""}} {
     if {$fName == ""} { return }
   }
 
+  if {[file extension $fName] == ""} {
+    set fName "$fName.si3"
+  }
+
   if {[file extension $fName] == ".sor"} {
     if {[catch {::rep::openWithFile $fName} err]} {
       tk_messageBox -parent . -type ok -icon info -title "Scid" \
@@ -184,8 +223,9 @@ proc fileOpen {{fName ""}} {
         -title "Scid: Error opening file" -message $result
     } else {
       set ::initialDir(base) [file dirname $fName]
+      ::recentFiles::add "$fName.si3"
     }
-  } elseif {[regexp {\.epd} [string tolower $fName]]} {
+  } elseif {[string match "*.epd" [string tolower $fName]]} {
     # EPD file:
     newEpdWin open $fName
   } else {
@@ -199,17 +239,21 @@ proc fileOpen {{fName ""}} {
     } else {
       doPgnFileImport $fName "Opening [file tail $fName] read-only...\n"
       sc_base type [sc_base current] 3
+      ::recentFiles::add $fName
     }
   }
 
-  if {$err == 0} { catch {sc_game load auto} }
+  if {$err == 0} {
+    catch {sc_game load auto}
+    flipBoardForPlayerNames $::myPlayerNames
+  }
   unbusyCursor .
   set glstart 1
   updateGList
   ::tree::refresh
   updateStatsWin
   updateMenuStates
-  updateBoardAndPgn
+  updateBoard -pgn
   updateTitle
   updateStatusBar
 }
@@ -269,7 +313,7 @@ proc openBase {name} {
 #
 proc fileClose {} {
   if {[sc_base inUse]} {
-    if ![confirmDiscardGame] { return }
+    if {![confirmDiscardGame]} { return }
     sc_base close
     updateGList
     # Close Tree and Email windows whenever a base is closed/switched:
@@ -306,7 +350,7 @@ proc gameClear {} {
   if {![confirmDiscardGame]} { return }
   setTrialMode 0
   sc_game new
-  updateBoardAndPgn
+  updateBoard -pgn
   updateTitle
   updateMenuStates
 }
@@ -319,7 +363,27 @@ proc gameStrip {type} {
     tk_messageBox -parent . -type ok -icon info -title "Scid" -message $result
     return
   }
-  updateBoardAndPgn
+  updateBoard -pgn
+  updateTitle
+}
+
+# gameTruncateBegin
+proc gameTruncateBegin {} {
+  if {[catch {sc_game truncate -start} result]} {
+    tk_messageBox -parent . -type ok -icon info -title "Scid" -message $result
+    return
+  }
+  updateBoard -pgn
+  updateTitle
+}
+
+# gameTruncate
+proc gameTruncate {} {
+  if {[catch {sc_game truncate} result]} {
+    tk_messageBox -parent . -type ok -icon info -title "Scid" -message $result
+    return
+  }
+  updateBoard -pgn
   updateTitle
 }
 
@@ -341,7 +405,8 @@ proc gameLoadNextPrev {action} {
   if {![confirmDiscardGame]} { return }
   setTrialMode 0
   sc_game load $number
-  updateBoardAndPgn
+  flipBoardForPlayerNames $::myPlayerNames
+  updateBoard -pgn
   updateGList
   updateTitle
 }
@@ -350,12 +415,29 @@ proc gameLoadNextPrev {action} {
 #   Reloads the current game.
 #
 proc gameReload {} {
-  if ![sc_base inUse] { return }
+  if {![sc_base inUse]} { return }
   if {[sc_game number] < 1} { return }
   if {![confirmDiscardGame]} { return }
   setTrialMode 0
   sc_game load [sc_game number]
-  updateBoardAndPgn
+  updateBoard -pgn
+  updateGList
+  updateTitle
+}
+
+# gameLoadRandom:
+#   Loads a random game from the database.
+#
+proc gameLoadRandom {} {
+  set ngames [sc_filter size]
+  if {$ngames == 0} { return }
+  set r [expr {(int (rand() * $ngames)) + 1} ]
+  set gnum [sc_filter index $r]
+  if {[catch {sc_game load $gnum} result]} {
+    tk_messageBox -type ok -icon info -title "Scid" -message $result
+  }
+  flipBoardForPlayerNames $::myPlayerNames
+  updateBoard -pgn
   updateGList
   updateTitle
 }
@@ -398,14 +480,15 @@ proc gameLoadNumber {} {
     }
     focus .
     destroy .glnumDialog
-    updateBoardAndPgn
+    flipBoardForPlayerNames $::myPlayerNames
+    updateBoard -pgn
     updateGList
     updateTitle
   }
   pack $b.cancel $b.load -side right -padx 5 -pady 5
 
-  set x [ expr [winfo width .] / 4 + [winfo rootx .] ]
-  set y [ expr [winfo height .] / 4 + [winfo rooty .] ]
+  set x [ expr {[winfo width .] / 4 + [winfo rootx .] }]
+  set y [ expr {[winfo height .] / 4 + [winfo rooty .] }]
   wm geometry $w "+$x+$y"
 
   focus $w.entry
@@ -420,7 +503,8 @@ proc gameLoad { selection } {
   if {$selection > [sc_base numGames]} { return }
   setTrialMode 0
   sc_game load $selection
-  updateBoardAndPgn
+  flipBoardForPlayerNames $::myPlayerNames
+  updateBoard -pgn
   updateGList
   updateTitle
 }
@@ -467,25 +551,25 @@ proc gotoMoveNumber {} {
 
   set b [frame $w.buttons]
   pack $b -side top -fill x
-  button $b.cancel -text $::tr(Cancel) -command {
-    focus .
-    grab release .mnumDialog
-    destroy .mnumDialog
-    focus .
-  }
-  button $b.load -text "OK" -command {
+  dialogbutton $b.load -text "OK" -command {
     grab release .mnumDialog
     if {$moveEntryNumber > 0} {
-      catch {sc_move ply [expr ($moveEntryNumber - 1) * 2]}
+      catch {sc_move ply [expr {($moveEntryNumber - 1) * 2}]}
     }
     focus .
     destroy .mnumDialog
-    updateBoardAndPgn
+    updateBoard -pgn
+  }
+  dialogbutton $b.cancel -text $::tr(Cancel) -command {
+    focus .
+    grab release .mnumDialog
+    destroy .mnumDialog
+    focus .
   }
   pack $b.cancel $b.load -side right -padx 5 -pady 5
 
-  set x [ expr [winfo width .] / 4 + [winfo rootx .] ]
-  set y [ expr [winfo height .] / 4 + [winfo rooty .] ]
+  set x [ expr {[winfo width .] / 4 + [winfo rootx .] } ]
+  set y [ expr {[winfo height .] / 4 + [winfo rooty .] } ]
   wm geometry $w "+$x+$y"
 
   focus $w.entry
@@ -540,9 +624,9 @@ proc findNovelty {} {
   label $w.status -text "" -width 1 -font font_Small -relief sunken -anchor w
   pack $w.status -side bottom -fill x
   pack [frame $w.b] -side top -fill x
-  button $w.b.stop -textvar ::tr(Stop) -state disabled \
+  dialogbutton $w.b.stop -textvar ::tr(Stop) -state disabled \
     -command sc_progressBar
-  button $w.b.go -text $::tr(FindNovelty) -command {
+  dialogbutton $w.b.go -text $::tr(FindNovelty) -command {
     .noveltyWin.b.stop configure -state normal
     .noveltyWin.b.go configure -state disabled
     .noveltyWin.b.close configure -state disabled
@@ -564,10 +648,10 @@ proc findNovelty {} {
     .noveltyWin.status configure -text $result
     updateBoard
   }
-  button $w.b.close -textvar ::tr(Close) -command {
+  dialogbutton $w.b.close -textvar ::tr(Close) -command {
     catch {destroy .noveltyWin}
   }
-  pack $w.b.close $w.b.go $w.b.stop -side right -padx 5 -pady 2
+  packbuttons right $w.b.close $w.b.go $w.b.stop
   wm resizable $w 0 0
   focus $w.b.go
   bind $w <KeyPress-1> "$w.b1 invoke"
@@ -635,7 +719,7 @@ proc mergeGame {{base 0} {gnum 0}} {
   label $w.b.label -text "Up to move:" -font $small
   pack $w.b.label -side left
   foreach i {5 10 15 20 25 30 35 40} {
-    radiobutton $w.b.m$i -text $i -variable merge(ply) -value [expr $i * 2] \
+    radiobutton $w.b.m$i -text $i -variable merge(ply) -value [expr {$i * 2}] \
       -indicatoron 0 -padx 2 -pady 1 -font $small -command updateMergeGame
     pack $w.b.m$i -side left
   }
@@ -643,15 +727,15 @@ proc mergeGame {{base 0} {gnum 0}} {
     -variable merge(ply) -value 1000 -indicatoron 0 -padx 2 -pady 1 \
     -font $small -command updateMergeGame
   pack $w.b.all -side left
-  button $w.b.ok -text "OK" -command {
+  dialogbutton $w.b.ok -text "OK" -command {
     sc_game merge $merge(base) $merge(gnum) $merge(ply)
     catch {grab release .mergeDialog}
     destroy .mergeDialog
-    updateBoardAndPgn
+    updateBoard -pgn
   }
-  button $w.b.cancel -text $::tr(Cancel) \
+  dialogbutton $w.b.cancel -text $::tr(Cancel) \
     -command "catch {grab release $w}; destroy $w"
-  pack $w.b.cancel $w.b.ok -side right -padx 2
+  packbuttons right $w.b.cancel $w.b.ok
   grab $w
   updateMergeGame
 }
@@ -745,7 +829,7 @@ proc setExportText {exportType} {
     focus .
     destroy $w
   "
-  button $w.buttons.cancel -text "Cancel" -command "focus .; destroy $w"
+  button $w.buttons.cancel -text $::tr(Cancel) -command "focus .; destroy $w"
   pack $w.buttons.default -side left -padx 5 -pady 2
   pack $w.buttons.cancel $w.buttons.ok -side right -padx 5 -pady 2
   focus $pane.start.text
@@ -828,6 +912,7 @@ proc exportOptions {exportType} {
   wm protocol $w WM_DELETE_WINDOW { }
   bind $w <Escape> "$w.b.cancel invoke"
   bind $w <Return> "$w.b.ok invoke"
+  bind $w <F1> {helpWindow Export}
 
   pack [frame $w.o] -side top -fill x -pady 5 -padx 5
   label $w.o.append -text $::tr(AddToExistingFile)
@@ -840,6 +925,11 @@ proc exportOptions {exportType} {
     -variable exportFlags(comments) -value 1
   radiobutton $w.o.commentsOff -text $::tr(No) \
     -variable exportFlags(comments) -value 0
+  label $w.o.stripMarks -text $::tr(ExportStripMarks)
+  radiobutton $w.o.stripMarksOn -text $::tr(Yes) \
+    -variable exportFlags(stripMarks) -value 1
+  radiobutton $w.o.stripMarksOff -text $::tr(No) \
+    -variable exportFlags(stripMarks) -value 0
   label $w.o.indentc -text $::tr(IndentComments)
   radiobutton $w.o.indentcOn -text $::tr(Yes) \
     -variable exportFlags(indentc) -value 1
@@ -869,22 +959,40 @@ proc exportOptions {exportType} {
   grid $w.o.comments -row 1 -column 0 -sticky w
   grid $w.o.commentsOn -row 1 -column 1 -sticky w
   grid $w.o.commentsOff -row 1 -column 2 -sticky w
-  grid $w.o.indentc -row 2 -column 0 -sticky w
-  grid $w.o.indentcOn -row 2 -column 1 -sticky w
-  grid $w.o.indentcOff -row 2 -column 2 -sticky w
-  grid $w.o.vars -row 3 -column 0 -sticky w
-  grid $w.o.varsOn -row 3 -column 1 -sticky w
-  grid $w.o.varsOff -row 3 -column 2 -sticky w
-  grid $w.o.indentv -row 4 -column 0 -sticky w
-  grid $w.o.indentvOn -row 4 -column 1 -sticky w
-  grid $w.o.indentvOff -row 4 -column 2 -sticky w
-  grid $w.o.column -row 5 -column 0 -sticky w
-  grid $w.o.columnOn -row 5 -column 1 -sticky w
-  grid $w.o.columnOff -row 5 -column 2 -sticky w
-  grid $w.o.symbols -row 6 -column 0 -sticky w
-  grid $w.o.symbolsOn -row 6 -column 1 -sticky w
-  grid $w.o.symbolsOff -row 6 -column 2 -sticky w
+  grid $w.o.stripMarks -row 2 -column 0 -sticky w
+  grid $w.o.stripMarksOn -row 2 -column 1 -sticky w
+  grid $w.o.stripMarksOff -row 2 -column 2 -sticky w
+  grid $w.o.indentc -row 3 -column 0 -sticky w
+  grid $w.o.indentcOn -row 3 -column 1 -sticky w
+  grid $w.o.indentcOff -row 3 -column 2 -sticky w
+  grid $w.o.vars -row 4 -column 0 -sticky w
+  grid $w.o.varsOn -row 4 -column 1 -sticky w
+  grid $w.o.varsOff -row 4 -column 2 -sticky w
+  grid $w.o.indentv -row 5 -column 0 -sticky w
+  grid $w.o.indentvOn -row 5 -column 1 -sticky w
+  grid $w.o.indentvOff -row 5 -column 2 -sticky w
+  grid $w.o.column -row 6 -column 0 -sticky w
+  grid $w.o.columnOn -row 6 -column 1 -sticky w
+  grid $w.o.columnOff -row 6 -column 2 -sticky w
+  grid $w.o.symbols -row 7 -column 0 -sticky w
+  grid $w.o.symbolsOn -row 7 -column 1 -sticky w
+  grid $w.o.symbolsOff -row 7 -column 2 -sticky w
 
+  # Extra option for PGN format: handling of null moves
+  if {$exportType == "PGN"} {
+    label $w.o.space -text ""
+    grid $w.o.space -row 8 -column 0 -sticky w
+    label $w.o.nullMoves -text "Convert null moves to comments"
+    radiobutton $w.o.convertNullMoves -text $::tr(Yes) \
+      -variable exportFlags(convertNullMoves) -value 1
+    radiobutton $w.o.keepNullMoves -text $::tr(No) \
+      -variable exportFlags(convertNullMoves) -value 0
+    grid $w.o.nullMoves -row 9 -column 0 -sticky w
+    grid $w.o.convertNullMoves -row 9 -column 1 -sticky w
+    grid $w.o.keepNullMoves -row 9 -column 2 -sticky w
+  }
+
+  # Extra option for HTML format: diagram image set
   if {$exportType == "HTML"} {
     label $w.o.space -text ""
     label $w.o.hdiag -text "Diagram"
@@ -894,12 +1002,12 @@ proc exportOptions {exportType} {
       -variable exportFlags(htmldiag) -value 1
     label $w.o.hl0 -image htmldiag0
     label $w.o.hl1 -image htmldiag1
-    grid $w.o.space -row 7 -column 0
-    grid $w.o.hdiag -row 8 -column 0 -sticky w
-    grid $w.o.hb0 -row 8 -column 1 -sticky w
-    grid $w.o.hb1 -row 8 -column 2 -sticky w
-    grid $w.o.hl0 -row 9 -column 1
-    grid $w.o.hl1 -row 9 -column 2
+    grid $w.o.space -row 8 -column 0
+    grid $w.o.hdiag -row 9 -column 0 -sticky w
+    grid $w.o.hb0 -row 9 -column 1 -sticky w
+    grid $w.o.hb1 -row 9 -column 2 -sticky w
+    grid $w.o.hl0 -row 10 -column 1
+    grid $w.o.hl1 -row 10 -column 2
   }
 
   addHorizontalRule $w
@@ -983,8 +1091,8 @@ proc exportGames {selection exportType} {
     default { return }
   }
 
-  if {$exportFlags(append)} { 
-    set getfile tk_getOpenFile 
+  if {$exportFlags(append)} {
+    set getfile tk_getOpenFile
     set title "Add games to $title"
   } else {
     set getfile tk_getSaveFile
@@ -1004,7 +1112,8 @@ proc exportGames {selection exportType} {
     -comments $exportFlags(comments) -variations $exportFlags(vars) \
     -space $pgnMoveNumSpace -symbols $exportFlags(symbols) \
     -indentC $exportFlags(indentc) -indentV $exportFlags(indentv) \
-    -column $exportFlags(column)
+    -column $exportFlags(column) -noMarkCodes $exportFlags(stripMarks) \
+    -convertNullMoves $exportFlags(convertNullMoves)
   unbusyCursor .
   if {$exportFilter} {
     closeProgressWindow
@@ -1136,10 +1245,10 @@ proc updateMatchList { tw nametype maxMatches name el op } {
   set matches {}
   catch {set matches [sc_name match $nametype $val $maxMatches]}
   set count [llength $matches]
-  set nameMatchCount [expr $count / 2]
+  set nameMatchCount [expr {$count / 2}]
   for {set i 0} { $i < $count } {incr i 2} {
-    set nameMatchCount [expr ($i / 2) + 1]
-    set nameMatches($nameMatchCount) [lindex $matches [expr $i + 1]]
+    set nameMatchCount [expr {($i / 2) + 1}]
+    set nameMatches($nameMatchCount) [lindex $matches [expr {$i + 1}]]
     set str "$nameMatchCount:\t[lindex $matches $i]\t$nameMatches($nameMatchCount)\n"
     $tw insert end $str
   }
@@ -1178,7 +1287,7 @@ trace variable editDateNew w forceDate
 
 proc editNameNewProc { tw nametype maxMatches name el op } {
   global editNameNew
-  if {! [winfo exists .nedit]} { return } 
+  if {! [winfo exists .nedit]} { return }
   if {[string compare $editNameNew ""]} {
     .nedit.buttons.replace configure -state normal
   } else {
@@ -1253,7 +1362,19 @@ proc nameEditor {} {
       grid .nedit.g.toL -row 1 -column 1 -sticky e
       grid .nedit.g.toD -row 1 -column 2 -sticky w
     }
-  pack $w.typeButtons.rating $w.typeButtons.date -side left -padx 5
+  radiobutton $w.typeButtons.edate -textvar ::tr(EventDate) \
+    -variable editNameType -value edate -indicatoron false -pady 5 -padx 5 \
+    -command {
+      grid remove .nedit.g.toE
+      grid remove .nedit.g.fromE
+      grid remove .nedit.g.ratingE
+      grid remove .nedit.g.rtype
+      grid .nedit.g.fromD -row 0 -column 2 -sticky w
+      grid .nedit.g.toL -row 1 -column 1 -sticky e
+      grid .nedit.g.toD -row 1 -column 2 -sticky w
+    }
+  pack $w.typeButtons.rating $w.typeButtons.date $w.typeButtons.edate \
+    -side left -padx 5
 
   addHorizontalRule .nedit
 
@@ -1261,13 +1382,13 @@ proc nameEditor {} {
   frame $w.selectButtons
   pack $w.selectLabel $w.selectButtons -side top -pady 5
   foreach i {all filter crosstable} row {0 1 2} text {
-    SelectAllGames 
-    SelectFilterGames 
+    SelectAllGames
+    SelectFilterGames
     SelectTournamentGames
   } {
     radiobutton $w.selectButtons.$i -textvar ::tr($text) \
-      -variable editNameSelect -value $i -pady 5 -padx 5 -indicatoron false
-    grid $w.selectButtons.$i -row $row -column 0 -sticky we
+      -variable editNameSelect -value $i
+    grid $w.selectButtons.$i -row $row -column 0 -sticky w
   }
 
   addHorizontalRule $w
@@ -1327,7 +1448,7 @@ proc nameEditor {} {
   button $w.buttons.replace -textvar ::tr(NameEditReplace) -command {
     if {$editNameType == "rating"} {
       set err [catch {sc_name edit $editNameType $editNameSelect $editName $editNameRating $editNameRType} result]
-    } elseif {$editNameType == "date"} {
+    } elseif {$editNameType == "date"  ||  $editNameType == "edate"} {
       set err [catch {sc_name edit $editNameType $editNameSelect $editDate $editDateNew} result]
     } else {
       set err [catch {sc_name edit $editNameType $editNameSelect $editName $editNameNew} result]
@@ -1338,8 +1459,8 @@ proc nameEditor {} {
     } else {
       .nedit.status configure -text $result
     }
-    sc_game reloadTags
-    updateBoardAndPgn
+    sc_game tags reload
+    updateBoard -pgn
     updateGList
   }
 
@@ -1408,17 +1529,17 @@ proc gameSave { gnum } {
     -tabs {2c right 2.5c left} -wrap none
 
   # Get current values of tags:
-  set year [sc_game getTag Year];    set eyear [sc_game getTag EYear]
-  set month [sc_game getTag Month];  set emonth [sc_game getTag EMonth]
-  set day [sc_game getTag Day];      set eday [sc_game getTag EDay]
-  set white [sc_game getTag White];  set black [sc_game getTag Black]
-  set event [sc_game getTag Event];  set site [sc_game getTag Site]
-  set resultVal [sc_game getTag Result];  set round [sc_game getTag Round]
-  set whiteElo [sc_game getTag WhiteElo]
-  set blackElo [sc_game getTag BlackElo]
-  set whiteRType [sc_game getTag WhiteRType]
-  set blackRType [sc_game getTag BlackRType]
-  set eco [sc_game getTag ECO];  set extraTags [sc_game getTag Extra]
+  set year [sc_game tag get Year];    set eyear [sc_game tag get EYear]
+  set month [sc_game tag get Month];  set emonth [sc_game tag get EMonth]
+  set day [sc_game tag get Day];      set eday [sc_game tag get EDay]
+  set white [sc_game tag get White];  set black [sc_game tag get Black]
+  set event [sc_game tag get Event];  set site [sc_game tag get Site]
+  set resultVal [sc_game tag get Result];  set round [sc_game tag get Round]
+  set whiteElo [sc_game tag get WhiteElo]
+  set blackElo [sc_game tag get BlackElo]
+  set whiteRType [sc_game tag get WhiteRType]
+  set blackRType [sc_game tag get BlackRType]
+  set eco [sc_game tag get ECO];  set extraTags [sc_game tag get Extra]
   clearMatchList $f.list
 
   # Use question marks instead of zero values in date:
@@ -1548,9 +1669,12 @@ proc gameSave { gnum } {
   frame .save.extra
   text .save.extra.text -height 4 -width 40 -bg white -wrap none \
     -yscrollcommand ".save.extra.scroll set"
-  scrollbar .save.extra.scroll -command ".save.extra.text yview"
+  # Override tab-binding for this text widget:
+  bind .save.extra.text <Key-Tab> "[bind all <Key-Tab>]; break"
+  scrollbar .save.extra.scroll -command ".save.extra.text yview" \
+    -takefocus 0
   button .save.extra.last -text "Use\nlast\ngame's\ntags" -command {
-    set extraTags [sc_game getTag -last Extra]
+    set extraTags [sc_game tag get -last Extra]
     .save.extra.text delete 1.0 end
     .save.extra.text insert 1.0 $extraTags
   }
@@ -1629,14 +1753,17 @@ proc gsave { gnum } {
   set date [format "%s.%s.%s" $year $month $day]
   set edate [format "%s.%s.%s" $eyear $emonth $eday]
   set extraTagsList [split $extraTags "\n"]
-  sc_game setTags $event $site $date $round $white $black $resultVal \
-    $whiteElo $whiteRType $blackElo $blackRType $eco $edate $extraTagsList
+  sc_game tags set -event $event -site $site -date $date -round $round \
+    -white $white -black $black -result $resultVal \
+    -whiteElo $whiteElo -whiteRatingType $whiteRType \
+    -blackElo $blackElo -blackRatingType $blackRType \
+    -eco $eco -eventdate $edate -extra $extraTagsList
   set res [sc_game save $gnum]
   if {$res != ""} {
     tk_messageBox -type ok -icon info -parent .save \
       -title "Scid" -message $res
   }
-  updateBoardAndPgn
+  updateBoard -pgn
   updateGList
   updateTitle
 }
@@ -1661,11 +1788,12 @@ proc helpAbout {} {
   append str "Version [sc_info version], [sc_info version date]\n"
   append str "Using Tcl/Tk version: [info patchlevel]\n\n"
   append str "Author: Shane Hudson\n"
-  append str "Email: shane@cosc.canterbury.ac.nz\n"
+  append str "Email: sgh@users.sourceforge.net\n"
   append str "Website: scid.sourceforge.net\n\n"
-  append str "Copyright (C) Shane Hudson 1999-2001.\n"
+  append str "Copyright (C) Shane Hudson 1999-2003.\n\n"
   append str "Scid is freeware, but you are welcome to make "
-  append str "a small donation for it -- just email the author for details."
+  append str "a small donation for it.\n"
+  append str "See the Scid website for details."
   set asserts [sc_info asserts]
   if {$asserts > 0} {
     append str "\n\n[thousands $asserts] asserts tested."
@@ -1691,7 +1819,7 @@ set moveEntry(List) {}
 # matching the move entry bindings, so Alt+letter ONLY invokes
 # the menus:
 foreach key {a b c d e f g h i j k l m n o p q r s t u v w x y z} {
-  bind . <Alt-$key> { 
+  bind . <Alt-$key> {
     # nothing
   }
 }
@@ -1719,7 +1847,7 @@ proc moveEntry_Complete {} {
       sc_move addSan $move
     }
     moveEntry_Clear
-    updateBoardAndPgn
+    updateBoard -pgn -animate
     if {$action == "replace"} { ::tree::doTraining }
   }
 }
@@ -1727,7 +1855,7 @@ proc moveEntry_Complete {} {
 proc moveEntry_Backspace {} {
   global moveEntry
   set moveEntry(Text) [string range $moveEntry(Text) 0 \
-                         [expr [string length $moveEntry(Text)] - 2]]
+                         [expr {[string length $moveEntry(Text)] - 2}]]
   set moveEntry(List) [sc_pos matchMoves $moveEntry(Text) $moveEntry(Coord)]
   updateStatusBar
 }
@@ -1810,39 +1938,68 @@ bind . <space> moveEntry_Complete
 
 # Bindings for quick move annotation entry in the main window:
 
-bind . <exclam><Return> "sc_pos addNag !; updateBoardAndPgn .board"
-bind . <exclam><exclam><Return> "sc_pos addNag !!; updateBoardAndPgn .board"
-bind . <exclam><question><Return> "sc_pos addNag !?; updateBoardAndPgn .board"
-bind . <question><Return> "sc_pos addNag ?; updateBoardAndPgn .board"
-bind . <question><question><Return> "sc_pos addNag ??; updateBoardAndPgn .board"
-bind . <question><exclam><Return> "sc_pos addNag ?!; updateBoardAndPgn .board"
+bind . <exclam><Return> "sc_pos addNag !; updateBoard -pgn"
+bind . <exclam><exclam><Return> "sc_pos addNag !!; updateBoard -pgn"
+bind . <exclam><question><Return> "sc_pos addNag !?; updateBoard -pgn"
+bind . <question><Return> "sc_pos addNag ?; updateBoard -pgn"
+bind . <question><question><Return> "sc_pos addNag ??; updateBoard -pgn"
+bind . <question><exclam><Return> "sc_pos addNag ?!; updateBoard -pgn"
 
-bind . <plus><minus> "sc_pos addNag +-; updateBoardAndPgn .board"
-bind . <plus><slash> "sc_pos addNag +/-; updateBoardAndPgn .board"
-bind . <plus><equal> "sc_pos addNag +=; updateBoardAndPgn .board"
-bind . <equal><Return> "sc_pos addNag =; updateBoardAndPgn .board"
-bind . <minus><plus> "sc_pos addNag -+; updateBoardAndPgn .board"
-bind . <minus><slash> "sc_pos addNag -/+; updateBoardAndPgn .board"
-bind . <equal><plus> "sc_pos addNag =+; updateBoardAndPgn .board"
-# bind . <asciitilde><Return> "sc_pos addNag ~; updateBoardAndPgn .board"
+bind . <plus><minus> "sc_pos addNag +-; updateBoard -pgn"
+bind . <plus><slash> "sc_pos addNag +/-; updateBoard -pgn"
+bind . <plus><equal> "sc_pos addNag +=; updateBoard -pgn"
+bind . <equal><Return> "sc_pos addNag =; updateBoard -pgn"
+bind . <minus><plus> "sc_pos addNag -+; updateBoard -pgn"
+bind . <minus><slash> "sc_pos addNag -/+; updateBoard -pgn"
+bind . <equal><plus> "sc_pos addNag =+; updateBoard -pgn"
+bind . <asciitilde><Return> "sc_pos addNag ~; updateBoard -pgn"
+bind . <asciitilde><equal><Return> "sc_pos addNag ~=; updateBoard -pgn"
+
+# Null move entry:
+bind . <minus><minus> "addMove null null"
 
 # Arrow keys, Home and End:
-bind . <Home> {if {!$tree(refresh)} {sc_move start; updateBoard .board}}
-bind . <Up> {if {!$tree(refresh)} {sc_move back 10; updateBoard .board}}
-bind . <Left> {if {!$tree(refresh)} {sc_move back; updateBoard .board}}
-bind . <Down> {if {!$tree(refresh)} {sc_move forward 10; updateBoard .board}}
-bind . <Right> {if {!$tree(refresh)} {sc_move forward; updateBoard .board}}
-bind . <End> {if {!$tree(refresh)} {sc_move end; updateBoard .board}}
+bind . <Home> {if {!$tree(refresh)} {sc_move start; updateBoard -animate}}
+bind . <Up> {if {!$tree(refresh)} {sc_move back 10; updateBoard -animate}}
+bind . <Left> {if {!$tree(refresh)} {sc_move back; updateBoard -animate}}
+bind . <Down> {if {!$tree(refresh)} {sc_move forward 10; updateBoard -animate}}
+bind . <Right> {if {!$tree(refresh)} {sc_move forward; updateBoard -animate}}
+bind . <End> {if {!$tree(refresh)} {sc_move end; updateBoard -animate}}
 
 bind . <period> {if {!$tree(refresh)} {toggleRotateBoard}}
 
+# MouseWheel in main window:
+bind . <MouseWheel> {
+  if {! $tree(refresh)} {
+    if {[expr -%D] < 0} { sc_move back; updateBoard -animate }
+    if {[expr -%D] > 0} { sc_move forward; updateBoard -animate }
+  }
+}
+bind . <Shift-MouseWheel> {
+  if {! $tree(refresh)} {
+    if {[expr -%D] < 0} { sc_move back 10; updateBoard -animate }
+    if {[expr -%D] > 0} { sc_move forward 10; updateBoard -animate }
+  }
+}
+if {! $windowsOS} {
+  bind . <Button-4> {
+    if {! $tree(refresh)} { sc_move back; updateBoard -animate }
+  }
+  bind . <Button-5> {
+    if {! $tree(refresh)} { sc_move forward; updateBoard -animate }
+  }
+  bind . <Shift-Button-4> {
+    if {! $tree(refresh)} { sc_move back 10; updateBoard -animate }
+  }
+  bind . <Shift-Button-5> {
+    if {! $tree(refresh)} { sc_move forward 10; updateBoard -animate }
+  }
+}
+
 
 ############################################################
 ### Packing the main window:
 
-pack .menu.file .menu.edit .menu.game .menu.search .menu.windows .menu.tools \
-    .menu.options .menu.help -side left
-
 pack .button -side top -ipadx 0 -pady 3
 
 label .statusbar -textvariable statusBar -relief sunken -anchor w -width 1 \
@@ -1858,17 +2015,19 @@ proc gotoNextBase {} {
     sc_base switch $n
     if {[sc_base inUse]} { break }
   }
-  updateBoard .board
+  updateBoard -pgn
+  updateTitle
+  updateMenuStates
+  updateStatusBar
+  updateGList
 }
 
-#pack .board -padx 5 -pady 5 -side top
 pack .board -side top -padx 5 -pady 5
 
-pack .ginfoXbar -side bottom -fill x
-pack .ginfoYbar -side right -fill y
-pack .gameInfo -side bottom -fill both -expand yes
+pack .gameInfoFrame -side bottom -fill both -padx 2 -expand yes
 
-setToolbar $showToolbar
+#setToolbar $showToolbar
+redrawToolbar
 
 wm resizable . 0 1
 wm minsize . 0 0
@@ -1953,7 +2112,7 @@ getCommandLineOptions
 setLanguage $language
 
 updateTitle
-updateBoard .board
+updateBoard
 updateStatusBar
 update idle
 
@@ -1965,7 +2124,7 @@ if {$loadAtStart(tb)} {
     foreach i {1 2 3 4} {
       if {$initialDir(tablebase$i) != ""} {
         if {$tbDirs != ""} { append tbDirs ";" }
-        append tbDirs $initialDir(tablebase$i)
+        append tbDirs [file nativename $initialDir(tablebase$i)]
       }
     }
     set result 0
@@ -1988,7 +2147,7 @@ if {$loadAtStart(eco)} {
   addSplash "Trying to load the ECO openings file..."
   if {[catch { sc_eco read $ecoFile_fullname } result]} {
     # Could not load, so try "scid.eco" in the current directory:
-    if [catch {sc_eco read "scid.eco"} result] {
+    if {[catch {sc_eco read "scid.eco"} result]} {
       # Neither attempt worked, so do not use ECO classification
       addSplash "    Unable to open the ECO file: $ecoFile"
     } else {
@@ -2058,9 +2217,11 @@ while {$argc > 0} {
       if {$err == 0} {
         doPgnFileImport $startbase "\nOpening [file tail $startbase] read-only...\n"
         sc_base type [sc_base current] 3
+        ::recentFiles::add $startbase
       }
     } else {
       set err [catch {openBase [file rootname $startbase]} errMessage]
+      if {! $err} { ::recentFiles::add "[file rootname $startbase].si3" }
     }
     if {$err} {
       addSplash "   Error: could not open database \"$startbase\":\n  $errMessage"
@@ -2068,6 +2229,7 @@ while {$argc > 0} {
       addSplash "   Database \"$startbase\" opened: [sc_base numGames] games."
       set initialDir(base) [file dirname $startbase]
       catch {sc_game load auto}
+      flipBoardForPlayerNames $::myPlayerNames
     }
   }
   unbusyCursor .
@@ -2077,21 +2239,25 @@ while {$argc > 0} {
 
 addSplash "\nStartup completed."
 addSplash "Scid has over 35 online help pages; just press F1 for help!"
-bind . <Configure> "recordWinSize ."
 setWinLocation .
 wm deiconify .
 wm protocol . WM_DELETE_WINDOW { fileExit }
 
-if {$startup(pgn)} { makePgnWin }
-if {$startup(tree)} { ::tree::make }
 if {$startup(switcher)} { makeBaseWin }
+if {$startup(pgn)} { makePgnWin }
+if {$startup(gamelist)} { makeGList }
+if {$startup(tree)} { ::tree::make }
+if {$startup(stats)} { makeStatsWin }
+if {$startup(crosstable)} { crosstabWin }
 if {$startup(finder)} { fileFinder }
 
-updateBoard .board
+
+updateBoard
 updateStatusBar
 updateTitle
 updateLocale
 update
+bind . <Configure> "recordWinSize ."
 
 # Bindings to map/unmap all windows when main window is mapped:
 bind .statusbar <Map> {showHideAllWindows deiconify}
@@ -2114,15 +2280,30 @@ proc showHideAllWindows {type} {
   foreach w {.baseWin .glistWin .pgnWin .tourney .maintWin \
                .ecograph .crosstabWin .treeWin .analysisWin1 .anslysisWin2 \
                .playerInfoWin .commentWin .repWin .statsWin .tbWin \
-               .sb .sh .sm .noveltyWin .emailWin .oprepWin \
+               .sb .sh .sm .noveltyWin .emailWin .oprepWin .plist \
                .rgraph .sgraph .importWin .helpWin .tipsWin} {
     if {[winfo exists $w]} { catch {wm $type $w} }
   }
 }
 
+proc raiseAllWindows {} {
+  # Don't do this if auto-raise option is turned off:
+  if {! $::autoRaise} { return }
+  foreach w {.baseWin .glistWin .pgnWin .tourney .maintWin \
+               .ecograph .crosstabWin .treeWin .analysisWin1 .anslysisWin2 \
+               .playerInfoWin .commentWin .repWin .statsWin .tbWin \
+               .sb .sh .sm .noveltyWin .emailWin .oprepWin .plist \
+               .rgraph .sgraph .importWin .helpWin .tipsWin} {
+    if {[winfo exists $w]} { catch {raise $w} }
+  }
+}
+
+# Bind double-click in main Scid window to raise all Scid windows:
+bind . <Double-Button-1> raiseAllWindows
+
 if {$startup(tip)} { ::tip::show }
 
-after 1500 {
+after 500 {
   if {$autoCloseSplash} {wm withdraw .splash}
 }
 
