@@ -36,7 +36,7 @@
 #     If in doubt, just make them all "0" and I'll assign sensible underlined
 #     letters when your translations are incorporated into Scid.
 #
-# Additions, corrections? Email: shane@cosc.canterbury.ac.nz
+# Additions, corrections? Email: sgh@users.sourceforge.net
 
 
 addLanguage E English 0
@@ -50,42 +50,44 @@ menuText E FileOpen "Open..." 0 {Open an existing Scid database}
 menuText E FileClose "Close" 0 {Close the active Scid database}
 menuText E FileFinder "Finder" 0 {Open the File Finder window}
 menuText E FileBookmarks "Bookmarks" 0 {Bookmarks menu (shortcut: Ctrl+B)}
-menuText E FileBookmarksAdd "Add bookmark" 0 \
+menuText E FileBookmarksAdd "Add Bookmark" 0 \
   {Bookmark the current database game and position}
-menuText E FileBookmarksFile "File bookmark" 0 \
+menuText E FileBookmarksFile "File Bookmark" 0 \
   {File a bookmark for the current game and position}
-menuText E FileBookmarksEdit "Edit bookmarks..." 0 \
+menuText E FileBookmarksEdit "Edit Bookmarks..." 0 \
   {Edit the bookmarks menus}
-menuText E FileBookmarksList "Display folders as single list" 0 \
+menuText E FileBookmarksList "Display Folders as Single List" 0 \
   {Display bookmark folders as a single list, not submenus}
-menuText E FileBookmarksSub "Display folders as submenus" 0 \
+menuText E FileBookmarksSub "Display Folders as Submenus" 0 \
   {Display bookmark folders as submenus, not a single list}
 menuText E FileMaint "Maintenance" 0 {Scid database maintenance tools}
 menuText E FileMaintWin "Maintenance Window" 0 \
   {Open/close the Scid database maintenance window}
-menuText E FileMaintCompact "Compact database..." 0 \
+menuText E FileMaintCompact "Compact Database..." 0 \
   {Compact database files, removing deleted games and unused names}
-menuText E FileMaintClass "ECO-Classify games..." 2 \
+menuText E FileMaintClass "ECO-Classify Games..." 2 \
   {Recompute the ECO code of all games}
-menuText E FileMaintSort "Sort database..." 0 \
+menuText E FileMaintSort "Sort Database..." 0 \
   {Sort all games in the database}
-menuText E FileMaintDelete "Delete twin games..." 0 \
+menuText E FileMaintDelete "Delete Twin Games..." 0 \
   {Find twin games and set them to be deleted}
-menuText E FileMaintTwin "Twin checker window" 0 \
+menuText E FileMaintTwin "Twin Checker Window" 0 \
   {Open/update the Twin checker window}
-menuText E FileMaintName "Name spelling" 0 {Name editing and spelling tools}
-menuText E FileMaintNameEditor "Name editor" 0 \
+menuText E FileMaintName "Name Spelling" 0 {Name editing and spelling tools}
+menuText E FileMaintNameEditor "Name Editor" 0 \
   {Open/close the name editor window}
-menuText E FileMaintNamePlayer "Spellcheck Player names..." 11 \
+menuText E FileMaintNamePlayer "Spellcheck Player Names..." 11 \
   {Spellcheck player names using the spellcheck file}
-menuText E FileMaintNameEvent "Spellcheck Event names..." 11 \
+menuText E FileMaintNameEvent "Spellcheck Event Names..." 11 \
   {Spellcheck event names using the spellcheck file}
-menuText E FileMaintNameSite "Spellcheck Site names..." 11 \
+menuText E FileMaintNameSite "Spellcheck Site Names..." 11 \
   {Spellcheck site names using the spellcheck file}
-menuText E FileMaintNameRound "Spellcheck Round names..." 11 \
+menuText E FileMaintNameRound "Spellcheck Round Names..." 11 \
   {Spellcheck round names using the spellcheck file}
 menuText E FileReadOnly "Read-only..." 0 \
   {Treat the current database as read-only, preventing changes}
+menuText E FileSwitch "Switch to Database" 0 \
+  {Switch to a different opened database}
 menuText E FileExit "Exit" 1 {Exit Scid}
 
 # Edit menu:
@@ -94,28 +96,34 @@ menuText E EditAdd "Add Variation" 0 {Add a variation at this move in the game}
 menuText E EditDelete "Delete Variation" 0 {Delete a variation for this move}
 menuText E EditFirst "Make First Variation" 5 \
   {Promote a variation to be first in the list}
-menuText E EditMain "Promote Variation to Main line" 21 \
+menuText E EditMain "Promote Variation to Main Line" 21 \
   {Promote a variation to be the main line}
-menuText E EditTrial "Try variation" 0 \
+menuText E EditTrial "Try Variation" 0 \
   {Start/stop trial mode, for testing an idea on the board}
 menuText E EditStrip "Strip" 2 {Strip comments or variations from this game}
 menuText E EditStripComments "Comments" 0 \
   {Strip all comments and annotations from this game}
 menuText E EditStripVars "Variations" 0 {Strip all variations from this game}
+menuText E EditStripBegin "Moves from the beginning" 1 \
+  {Strip moves from the beginning of the game}
+menuText E EditStripEnd "Moves to the end" 0 \
+  {Strip moves to the end of the game}
 menuText E EditReset "Empty Clipbase" 0 \
   {Reset the clipbase to be completely empty}
-menuText E EditCopy "Copy this game to Clipbase" 0 \
+menuText E EditCopy "Copy This Game to Clipbase" 0 \
   {Copy this game to the Clipbase database}
-menuText E EditPaste "Paste last Clipbase game" 0 \
+menuText E EditPaste "Paste Last Clipbase Game" 0 \
   {Paste the active Clipbase game here}
-menuText E EditSetup "Setup start board..." 0 \
+menuText E EditSetup "Setup Start Board..." 0 \
   {Set the start position for this game}
-menuText E EditPasteBoard "Paste start board" 12 \
+menuText E EditCopyBoard "Copy Position" 6 \
+  {Copy the current board in FEN notation to the text selection (clipboard)}
+menuText E EditPasteBoard "Paste Start Board" 12 \
   {Set the start board from the current text selection (clipboard)}
 
 # Game menu:
 menuText E Game "Game" 0
-menuText E GameNew "New game" 0 \
+menuText E GameNew "New Game" 0 \
   {Reset to an empty game, discarding any changes}
 menuText E GameFirst "Load First Game" 5 {Load the first filtered game}
 menuText E GamePrev "Load Previous Game" 5 {Load the previous filtered game}
@@ -123,15 +131,16 @@ menuText E GameReload "Re-Load Current Game" 3 \
   {Reload this game, discarding any changes made}
 menuText E GameNext "Load Next Game" 7 {Load the next filtered game}
 menuText E GameLast "Load Last Game" 8 {Load the last filtered game}
+menuText E GameRandom "Load Random Game" 8 {Load a random filtered game}
 menuText E GameNumber "Load Game Number..." 5 \
   {Load a game by entering its number}
 menuText E GameReplace "Save: Replace game..." 6 \
   {Save this game, replacing the old version}
-menuText E GameAdd "Save: Add new game..." 6 \
+menuText E GameAdd "Save: Add New Game..." 6 \
   {Save this game as a new game in the database}
-menuText E GameDeepest "Identify opening" 0 \
+menuText E GameDeepest "Identify Opening" 0 \
   {Goto the deepest game position listed in the ECO book}
-menuText E GameGotoMove "Goto move number..." 5 \
+menuText E GameGotoMove "Goto Move Number..." 5 \
   {Go to a specified move number in the current game}
 menuText E GameNovelty "Find Novelty..." 7 \
   {Find the first move of this game that has not played before}
@@ -143,129 +152,143 @@ menuText E SearchNegate "Negate Filter" 0 {Negate the filter to only include exc
 menuText E SearchCurrent "Current Board..." 0 {Search for the current board position}
 menuText E SearchHeader "Header..." 0 {Search by Header (player, event, etc) information}
 menuText E SearchMaterial "Material/Pattern..." 0 {Search for material or board patterns}
-menuText E SearchUsing "Using search file..." 0 {Search using a SearchOptions file}
+menuText E SearchUsing "Using Search File..." 0 {Search using a SearchOptions file}
 
 # Windows menu:
 menuText E Windows "Windows" 0
-menuText E WindowsComment "Comment editor" 0 {Open/close the comment editor}
+menuText E WindowsComment "Comment Editor" 0 {Open/close the comment editor}
 menuText E WindowsGList "Game List" 0 {Open/close the game list window}
-menuText E WindowsPGN "PGN window" 0 \
+menuText E WindowsPGN "PGN Window" 0 \
   {Open/close the PGN (game notation) window}
+menuText E WindowsPList "Player Finder" 2 {Open/close the player finder}
 menuText E WindowsTmt "Tournament Finder" 2 {Open/close the tournament finder}
 menuText E WindowsSwitcher "Database switcher" 0 \
   {Open/close the Database Switcher window}
-menuText E WindowsMaint "Maintenance window" 0 \
+menuText E WindowsMaint "Maintenance Window" 0 \
   {Open/close the Maintenance window}
 menuText E WindowsECO "ECO Browser" 0 {Open/close the ECO Browser window}
-menuText E WindowsRepertoire "Repertoire editor" 0 \
+menuText E WindowsRepertoire "Repertoire Editor" 0 \
   {Open/close the opening repertoire editor}
-menuText E WindowsStats "Statistics window" 0 \
+menuText E WindowsStats "Statistics Window" 0 \
   {Open/close the filter statistics window}
-menuText E WindowsTree "Tree window" 0 {Open/close the Tree window}
-menuText E WindowsTB "Endgame Tablebase window" 1 \
+menuText E WindowsTree "Tree Window" 0 {Open/close the Tree window}
+menuText E WindowsTB "Endgame Tablebase Window" 1 \
   {Open/close the Tablebase window}
 
 # Tools menu:
 menuText E Tools "Tools" 0
-menuText E ToolsAnalysis "Analysis engine..." 0 \
+menuText E ToolsAnalysis "Analysis Engine..." 0 \
   {Start/stop a chess analysis engine}
-menuText E ToolsAnalysis2 "Analysis engine #2..." 17 \
+menuText E ToolsAnalysis2 "Analysis Engine #2..." 17 \
   {Start/stop the 2nd chess analysis engine}
 menuText E ToolsCross "Crosstable" 0 {Show tournament crosstable for this game}
-menuText E ToolsEmail "Email manager" 0 \
+menuText E ToolsEmail "Email Manager" 0 \
   {Open/close the email chess manager window}
-menuText E ToolsOpReport "Opening report" 0 \
+menuText E ToolsFilterGraph "Filter Graph" 7 \
+  {Open/close the filter graph window}
+menuText E ToolsOpReport "Opening Report" 0 \
   {Generate an opening report for the current position}
+menuText E ToolsTracker "Piece Tracker"  6 {Open the Piece Tracker window}
 menuText E ToolsPInfo "Player Information"  0 \
   {Open/update the Player Information window}
-menuText E ToolsRating "Rating graph" 0 \
+menuText E ToolsPlayerReport "Player Report..." 3 \
+  {Generate a player report}
+menuText E ToolsRating "Rating Graph" 0 \
   {Graph the rating history of the current game players}
-menuText E ToolsScore "Score graph" 0 {Show the score graph window}
-menuText E ToolsExpCurrent "Export current game" 8 \
+menuText E ToolsScore "Score Graph" 0 {Show the score graph window}
+menuText E ToolsExpCurrent "Export Current Game" 8 \
   {Write current game to a text file}
-menuText E ToolsExpCurrentPGN "Export game to PGN file..." 15 \
+menuText E ToolsExpCurrentPGN "Export Game to PGN File..." 15 \
   {Write current game to a PGN file}
-menuText E ToolsExpCurrentHTML "Export game to HTML file..." 15 \
+menuText E ToolsExpCurrentHTML "Export Game to HTML File..." 15 \
   {Write current game to a HTML file}
-menuText E ToolsExpCurrentLaTeX "Export game to LaTeX file..." 15 \
+menuText E ToolsExpCurrentLaTeX "Export Game to LaTeX File..." 15 \
   {Write current game to a LaTeX file}
-menuText E ToolsExpFilter "Export all filter games" 1 \
+menuText E ToolsExpFilter "Export All Filter Games" 1 \
   {Write all filtered games to a text file}
-menuText E ToolsExpFilterPGN "Export filter to PGN file..." 17 \
+menuText E ToolsExpFilterPGN "Export Filter to PGN File..." 17 \
   {Write all filtered games to a PGN file}
-menuText E ToolsExpFilterHTML "Export filter to HTML file..." 17 \
+menuText E ToolsExpFilterHTML "Export Filter to HTML File..." 17 \
   {Write all filtered games to a HTML file}
-menuText E ToolsExpFilterLaTeX "Export filter to LaTeX file..." 17 \
+menuText E ToolsExpFilterLaTeX "Export Filter to LaTeX File..." 17 \
   {Write all filtered games to a LaTeX file}
-menuText E ToolsImportOne "Import one PGN game..." 0 \
+menuText E ToolsImportOne "Import One PGN Game..." 0 \
   {Import a game from PGN text}
-menuText E ToolsImportFile "Import file of PGN games..." 7 \
+menuText E ToolsImportFile "Import File of PGN Games..." 7 \
   {Import games from a PGN file}
 
 # Options menu:
 menuText E Options "Options" 0
-menuText E OptionsSize "Board Size" 0 {Change the board size}
-menuText E OptionsPieces "Board Piece Style" 6 {Change the board piece style}
-menuText E OptionsColors "Colors..." 0 {Change board colors}
+menuText E OptionsBoard "Chessboard" 0 {Chess board appearance options}
+menuText E OptionsBoardSize "Size" 0 {Change the board size}
+menuText E OptionsBoardPieces "Piece Style" 6 {Change the board piece style}
+menuText E OptionsBoardColors "Colors..." 0 {Change board colors}
+menuText E OptionsBoardNames "My Player Names..." 0 {Edit my player names}
 menuText E OptionsExport "Exporting" 0 {Change text export options}
 menuText E OptionsFonts "Fonts" 0 {Change fonts}
 menuText E OptionsFontsRegular "Regular" 0 {Change the regular font}
+menuText E OptionsFontsMenu "Menu" 0 {Change the menu font}
 menuText E OptionsFontsSmall "Small" 0 {Change the small font}
 menuText E OptionsFontsFixed "Fixed" 0 {Change the fixed-width font}
-menuText E OptionsGInfo "Game information" 0 {Game information options}
+menuText E OptionsGInfo "Game Information" 0 {Game information options}
 menuText E OptionsLanguage "Language" 0 {Select menu language}
 menuText E OptionsMoves "Moves" 0 {Move entry options}
-menuText E OptionsMovesAsk "Ask before replacing moves" 0 \
+menuText E OptionsMovesAsk "Ask Before Replacing Moves" 0 \
   {Ask before overwriting any existing moves}
-menuText E OptionsMovesDelay "Autoplay time delay..." 1 \
+menuText E OptionsMovesAnimate "Animation Time" 1 \
+  {Set the amount of time used to animate moves}
+menuText E OptionsMovesDelay "Autoplay Time Delay..." 1 \
   {Set the time delay for autoplay mode}
-menuText E OptionsMovesCoord "Coordinate move entry" 0 \
-  {Accept coordinate-style move entry ("g1f3")}
-menuText E OptionsMovesSuggest "Show suggested moves" 0 \
+menuText E OptionsMovesCoord "Coordinate Move Entry" 0 \
+  {Accept coordinate-style move entry (e.g. "g1f3")}
+menuText E OptionsMovesSuggest "Show Suggested Moves" 0 \
   {Turn on/off move suggestion}
-menuText E OptionsMovesKey "Keyboard completion" 0 \
+menuText E OptionsMovesKey "Keyboard Completion" 0 \
   {Turn on/off keyboard move auto-completion}
-menuText E OptionsNumbers "Number format" 0 {Select the number format}
+menuText E OptionsNumbers "Number Format" 0 {Select the number format}
 menuText E OptionsStartup "Startup" 3 {Select windows to open at startup}
 menuText E OptionsWindows "Windows" 0 {Window options}
-menuText E OptionsWindowsIconify "Auto-iconify" 5 \
+menuText E OptionsWindowsIconify "Auto-Iconify" 5 \
   {Iconify all windows when the main window is iconified}
-menuText E OptionsWindowsRaise "Auto-raise" 5 \
+menuText E OptionsWindowsRaise "Auto-Raise" 5 \
   {Raise certain windows (e.g. progress bars) whenever they are obscured}
-menuText E OptionsToolbar "Main window Toolbar" 12 \
-  {Show/hide the main window toolbar}
-menuText E OptionsECO "Load ECO file..." 7 {Load the ECO classification file}
-menuText E OptionsSpell "Load Spellcheck file..." 6 \
+menuText E OptionsToolbar "Toolbar..." 0 {Configure the main window toolbar}
+menuText E OptionsECO "Load ECO File..." 7 {Load the ECO classification file}
+menuText E OptionsSpell "Load Spellcheck File..." 11 \
   {Load the Scid spellcheck file}
-menuText E OptionsTable "Tablebase directory..." 10 \
+menuText E OptionsTable "Tablebase Directory..." 10 \
   {Select a tablebase file; all tablebases in its directory will be used}
+menuText E OptionsRecent "Recent Files..." 0 \
+  {Change the number of recent files displayed in the File menu}
 menuText E OptionsSave "Save Options" 0 \
   "Save all settable options to the file $::optionsFile"
-menuText E OptionsAutoSave "Auto-save Options on Exit" 0 \
+menuText E OptionsAutoSave "Auto-Save Options on Exit" 0 \
   {Auto-save all options when exiting Scid}
 
 # Help menu:
 menuText E Help "Help" 0
+menuText E HelpContents "Contents" 0 {Show the help contents page}
 menuText E HelpIndex "Index" 0 {Show the help index page}
 menuText E HelpGuide "Quick Guide" 0 {Show the quick guide help page}
 menuText E HelpHints "Hints" 0 {Show the hints help page}
-menuText E HelpContact "Contact info" 0 {Show the contact information help page}
-menuText E HelpTip "Tip of the day" 0 {Show a useful Scid tip}
-menuText E HelpStartup "Startup window" 0 {Show the startup window}
+menuText E HelpContact "Contact Info" 1 {Show the contact information help page}
+menuText E HelpTip "Tip of the Day" 0 {Show a useful Scid tip}
+menuText E HelpStartup "Startup Window" 0 {Show the startup window}
 menuText E HelpAbout "About Scid" 0 {Information about Scid}
 
 # Game info box popup menu:
-menuText E GInfoHideNext "Hide next move" 0
-menuText E GInfoMaterial "Show material values" 0
+menuText E GInfoHideNext "Hide Next Move" 0
+menuText E GInfoMaterial "Show Material Values" 0
 menuText E GInfoFEN "Show FEN" 5
-menuText E GInfoMarks "Show colored squares and arrows" 5
-menuText E GInfoWrap "Wrap long lines" 0
+menuText E GInfoMarks "Show Colored Squares and Arrows" 5
+menuText E GInfoWrap "Wrap Long Lines" 0
 menuText E GInfoFullComment "Show Full Comment" 10
-menuText E GInfoTBNothing "Tablebases: nothing" 12
-menuText E GInfoTBResult "Tablebases: result only" 12
-menuText E GInfoTBAll "Tablebases: result and best moves" 19
-menuText E GInfoDelete "(Un)Delete this game" 4
-menuText E GInfoMark "(Un)Mark this game" 4
+menuText E GInfoPhotos "Show Photos" 5
+menuText E GInfoTBNothing "Tablebases: Nothing" 12
+menuText E GInfoTBResult "Tablebases: Result Only" 12
+menuText E GInfoTBAll "Tablebases: Result and Best Moves" 19
+menuText E GInfoDelete "(Un)Delete This Game" 4
+menuText E GInfoMark "(Un)Mark This Game" 4
 
 # Main window buttons:
 helpMsg E .button.start {Go to start of game  (key: Home)}
@@ -276,22 +299,25 @@ helpMsg E .button.intoVar {Move into a variation  (shortcut key: v)}
 helpMsg E .button.exitVar {Leave the current variation  (shortcut key: z)}
 helpMsg E .button.flip {Rotate board  (shortcut key: .)}
 helpMsg E .button.coords {Turn board coordinates on or off  (shortcut key: 0)}
+helpMsg E .button.stm {Turn the side-to-move icon on or off}
 helpMsg E .button.autoplay {Autoplay moves  (key: Ctrl+Z)}
 
 # General buttons:
 translate E Back {Back}
+translate E Browse {Browse}
 translate E Cancel {Cancel}
 translate E Clear {Clear}
 translate E Close {Close}
+translate E Contents {Contents}
 translate E Defaults {Defaults}
 translate E Delete {Delete}
 translate E Graph {Graph}
 translate E Help {Help}
 translate E Import {Import}
 translate E Index {Index}
-translate E LoadGame {Load game}
-translate E BrowseGame {Browse game}
-translate E MergeGame {Merge game}
+translate E LoadGame {Load Game}
+translate E BrowseGame {Browse Game}
+translate E MergeGame {Merge Game}
 translate E Preview {Preview}
 translate E Revert {Revert}
 translate E Save {Save}
@@ -325,12 +351,14 @@ translate E Black {Black}
 translate E Player {Player}
 translate E Rating {Rating}
 translate E RatingDiff {Rating difference (White - Black)}
+translate E AverageRating {Average Rating}
 translate E Event {Event}
 translate E Site {Site}
 translate E Country {Country}
 translate E IgnoreColors {Ignore colors}
 translate E Date {Date}
 translate E EventDate {Event date}
+translate E Decade {Decade}
 translate E Year {Year}
 translate E Month {Month}
 translate E Months {January February March April May June
@@ -355,6 +383,11 @@ translate E score {score}
 translate E StartPos {Start position}
 translate E Total {Total}
 
+# Standard error messages:
+translate E ErrNotOpen {This is not an open database.}
+translate E ErrReadOnly {This database is read-only; it cannot be altered.}
+translate E ErrSearchInterrupted {Search was interrupted; results are incomplete.}
+
 # Game information:
 translate E twin {twin}
 translate E deleted {deleted}
@@ -375,6 +408,7 @@ translate E PInfoMostWhite {Most common openings as White}
 translate E PInfoMostBlack {Most common openings as Black}
 translate E PInfoRating {Rating history}
 translate E PInfoBio {Biography}
+translate E PInfoEditRatings {Edit Ratings}
 
 # Tablebase information:
 translate E Draw {Draw}
@@ -389,6 +423,10 @@ translate E allOthersLose {all others lose}
 translate E matesIn {mates in}
 translate E hasCheckmated {has checkmated}
 translate E longest {longest}
+translate E WinningMoves {Winning moves}
+translate E DrawingMoves {Drawing moves}
+translate E LosingMoves {Losing moves}
+translate E UnknownMoves {Unknown-result moves}
 
 # Tip of the day:
 translate E Tip {Tip}
@@ -396,37 +434,41 @@ translate E TipAtStartup {Tip at startup}
 
 # Tree window menus:
 menuText E TreeFile "File" 0
-menuText E TreeFileSave "Save cache file" 0 {Save the tree cache (.stc) file}
-menuText E TreeFileFill "Fill cache file" 0 \
+menuText E TreeFileSave "Save Cache File" 0 {Save the tree cache (.stc) file}
+menuText E TreeFileFill "Fill Cache File" 0 \
   {Fill the cache file with common opening positions}
-menuText E TreeFileBest "Best games list" 0 {Show the best tree games list}
-menuText E TreeFileGraph "Graph window" 0 {Show the graph for this tree branch}
-menuText E TreeFileCopy "Copy tree text to clipboard" 1 \
+menuText E TreeFileBest "Best Games List" 0 {Show the best tree games list}
+menuText E TreeFileGraph "Graph Window" 0 {Show the graph for this tree branch}
+menuText E TreeFileCopy "Copy Tree Text to Clipboard" 1 \
   {Copy the tree statisctics to the clipboard}
-menuText E TreeFileClose "Close tree window" 0 {Close the tree window}
+menuText E TreeFileClose "Close Tree Window" 0 {Close the tree window}
 menuText E TreeSort "Sort" 0
 menuText E TreeSortAlpha "Alphabetical" 0
-menuText E TreeSortECO "ECO code" 0
+menuText E TreeSortECO "ECO Code" 0
 menuText E TreeSortFreq "Frequency" 0
 menuText E TreeSortScore "Score" 0
 menuText E TreeOpt "Options" 0
 menuText E TreeOptLock "Lock" 0 {Lock/unlock the tree to the current database}
 menuText E TreeOptTraining "Training" 0 {Turn on/off tree training mode}
-menuText E TreeOptAutosave "Auto-save cache file" 0 \
+menuText E TreeOptAutosave "Auto-Save Cache File" 0 \
   {Auto-save the cache file when closing the tree window}
 menuText E TreeHelp "Help" 0
-menuText E TreeHelpTree "Tree help" 0
-menuText E TreeHelpIndex "Help index" 0
-translate E SaveCache {Save cache}
+menuText E TreeHelpTree "Tree Help" 0
+menuText E TreeHelpIndex "Help Index" 0
+translate E SaveCache {Save Cache}
 translate E Training {Training}
 translate E LockTree {Lock}
 translate E TreeLocked {locked}
 translate E TreeBest {Best}
-translate E TreeBestGames {Best tree games}
+translate E TreeBestGames {Best Tree Games}
+# Note: the next message is the tree window title row. After editing it,
+# check the tree window to make sure it lines up with the actual columns.
+translate E TreeTitleRow \
+  {    Move   ECO       Frequency    Score  AvElo Perf AvYear %Draws}
 
 # Finder window:
 menuText E FinderFile "File" 0
-menuText E FinderFileSubdirs "Look in subdirectories" 0
+menuText E FinderFileSubdirs "Look in Subdirectories" 0
 menuText E FinderFileClose "Close File Finder" 0
 menuText E FinderSort "Sort" 0
 menuText E FinderSortType "Type" 0
@@ -435,20 +477,31 @@ menuText E FinderSortMod "Modified" 0
 menuText E FinderSortName "Name" 0
 menuText E FinderSortPath "Path" 0
 menuText E FinderTypes "Types" 0
-menuText E FinderTypesScid "Scid databases" 0
-menuText E FinderTypesOld "Old-format Scid databases" 0
-menuText E FinderTypesPGN "PGN files" 0
-menuText E FinderTypesEPD "EPD files" 0
-menuText E FinderTypesRep "Repertoire files" 0
+menuText E FinderTypesScid "Scid Databases" 0
+menuText E FinderTypesOld "Old-Format Scid Databases" 0
+menuText E FinderTypesPGN "PGN Files" 0
+menuText E FinderTypesEPD "EPD Files" 0
+menuText E FinderTypesRep "Repertoire Files" 0
 menuText E FinderHelp "Help" 0
-menuText E FinderHelpFinder "File Finder help" 0
-menuText E FinderHelpIndex "Help index" 0
+menuText E FinderHelpFinder "File Finder Help" 0
+menuText E FinderHelpIndex "Help Index" 0
 translate E FileFinder {File Finder}
 translate E FinderDir {Directory}
 translate E FinderDirs {Directories}
 translate E FinderFiles {Files}
 translate E FinderUpDir {up}
 
+# Player finder:
+menuText E PListFile "File" 0
+menuText E PListFileUpdate "Update" 0
+menuText E PListFileClose "Close Player Finder" 0
+menuText E PListSort "Sort" 0
+menuText E PListSortName "Name" 0
+menuText E PListSortElo "Elo" 0
+menuText E PListSortGames "Games" 0
+menuText E PListSortOldest "Oldest" 0
+menuText E PListSortNewest "Newest" 2
+
 # Tournament finder:
 menuText E TmtFile "File" 0
 menuText E TmtFileUpdate "Update" 0
@@ -461,33 +514,35 @@ menuText E TmtSortElo "Elo" 0
 menuText E TmtSortSite "Site" 0
 menuText E TmtSortEvent "Event" 1
 menuText E TmtSortWinner "Winner" 0
-translate E TmtLimit "List limit"
-translate E TmtMeanElo "Lowest mean Elo"
+translate E TmtLimit "List Limit"
+translate E TmtMeanElo "Mean Elo"
 translate E TmtNone "No matching tournaments were found."
 
 # Graph windows:
 menuText E GraphFile "File" 0
 menuText E GraphFileColor "Save as Color PostScript..." 8
 menuText E GraphFileGrey "Save as Greyscale PostScript..." 8
-menuText E GraphFileClose "Close window" 6
+menuText E GraphFileClose "Close Window" 6
 menuText E GraphOptions "Options" 0
 menuText E GraphOptionsWhite "White" 0
 menuText E GraphOptionsBlack "Black" 0
 menuText E GraphOptionsBoth "Both" 1
 menuText E GraphOptionsPInfo "Player Info player" 0
+translate E GraphFilterTitle "Filter Graph: frequency per 1000 games"
 
 # Analysis window:
-translate E AddVariation {Add variation}
-translate E AddMove {Add move}
+translate E AddVariation {Add Variation}
+translate E AddMove {Add Move}
 translate E Annotate {Annotate}
-translate E AnalysisCommand {Analysis command}
-translate E PreviousChoices {Previous choices}
+translate E AnalysisCommand {Analysis Command}
+translate E PreviousChoices {Previous Choices}
 translate E AnnotateTime {Set the time between moves in seconds}
 translate E AnnotateWhich {Add variations}
 translate E AnnotateAll {For moves by both sides}
 translate E AnnotateWhite {For White moves only}
 translate E AnnotateBlack {For Black moves only}
 translate E AnnotateNotBest {When game move is not best move}
+translate E LowPriority {Low CPU Priority}
 
 # Analysis Engine open dialog:
 translate E EngineList {Analysis Engine List}
@@ -503,22 +558,24 @@ translate E EngineRequired {Fields in bold are required; others are optional}
 
 # Stats window menus:
 menuText E StatsFile "File" 0
-menuText E StatsFilePrint "Print to file..." 0
-menuText E StatsFileClose "Close window" 0
+menuText E StatsFilePrint "Print to File..." 0
+menuText E StatsFileClose "Close Window" 0
 menuText E StatsOpt "Options" 0
 
 # PGN window menus:
 menuText E PgnFile "File" 0
-menuText E PgnFilePrint "Print to file..." 0
-menuText E PgnFileClose "Close PGN window" 0
+menuText E PgnFileCopy "Copy Game to Clipboard" 0
+menuText E PgnFilePrint "Print to File..." 0
+menuText E PgnFileClose "Close PGN Window" 10
 menuText E PgnOpt "Display" 0
-menuText E PgnOptColor "Color display" 0
-menuText E PgnOptShort "Short (3-line) header" 0
-menuText E PgnOptSymbols "Symbolic annotations" 1
-menuText E PgnOptIndentC "Indent comments" 0
-menuText E PgnOptIndentV "Indent variations" 7
-menuText E PgnOptColumn "Column style (one move per line)" 1
-menuText E PgnOptSpace "Space after move numbers" 1
+menuText E PgnOptColor "Color Display" 0
+menuText E PgnOptShort "Short (3-line) Header" 0
+menuText E PgnOptSymbols "Symbolic Annotations" 1
+menuText E PgnOptIndentC "Indent Comments" 0
+menuText E PgnOptIndentV "Indent Variations" 7
+menuText E PgnOptColumn "Column Style (one move per line)" 1
+menuText E PgnOptSpace "Space after Move Numbers" 1
+menuText E PgnOptStripMarks "Strip out Colored Square/Arrow Codes" 1
 menuText E PgnColor "Colors" 0
 menuText E PgnColorHeader "Header..." 0
 menuText E PgnColorAnno "Annotations..." 0
@@ -526,15 +583,15 @@ menuText E PgnColorComments "Comments..." 0
 menuText E PgnColorVars "Variations..." 0
 menuText E PgnColorBackground "Background..." 0
 menuText E PgnHelp "Help" 0
-menuText E PgnHelpPgn "PGN help" 0
+menuText E PgnHelpPgn "PGN Help" 0
 menuText E PgnHelpIndex "Index" 0
 
 # Crosstable window menus:
 menuText E CrosstabFile "File" 0
-menuText E CrosstabFileText "Print to Text file..." 9
-menuText E CrosstabFileHtml "Print to HTML file..." 9
-menuText E CrosstabFileLaTeX "Print to LaTeX file..." 9
-menuText E CrosstabFileClose "Close Crosstable window" 0
+menuText E CrosstabFileText "Print to Text File..." 9
+menuText E CrosstabFileHtml "Print to HTML File..." 9
+menuText E CrosstabFileLaTeX "Print to LaTeX File..." 9
+menuText E CrosstabFileClose "Close Crosstable Window" 0
 menuText E CrosstabEdit "Edit" 0
 menuText E CrosstabEditEvent "Event" 0
 menuText E CrosstabEditSite "Site" 0
@@ -544,37 +601,44 @@ menuText E CrosstabOptAll "All-play-all" 0
 menuText E CrosstabOptSwiss "Swiss" 0
 menuText E CrosstabOptKnockout "Knockout" 0
 menuText E CrosstabOptAuto "Auto" 1
-menuText E CrosstabOptAges "Ages in years" 8
+menuText E CrosstabOptAges "Ages in Years" 8
 menuText E CrosstabOptNats "Nationalities" 0
 menuText E CrosstabOptRatings "Ratings" 0
 menuText E CrosstabOptTitles "Titles" 0
-menuText E CrosstabOptBreaks "Tie-break scores" 4
+menuText E CrosstabOptBreaks "Tie-Break Scores" 4
+menuText E CrosstabOptDeleted "Include Deleted Games" 8
 menuText E CrosstabOptColors "Colors (Swiss table only)" 0
-menuText E CrosstabOptGroup "Group scores" 0
+menuText E CrosstabOptColumnNumbers "Numbered Columns (All-play-all table only)" 2
+menuText E CrosstabOptGroup "Group Scores" 0
 menuText E CrosstabSort "Sort" 0
 menuText E CrosstabSortName "Name" 0
 menuText E CrosstabSortRating "Rating" 0
 menuText E CrosstabSortScore "Score" 0
 menuText E CrosstabColor "Color" 0
-menuText E CrosstabColorPlain "Plain text" 0
+menuText E CrosstabColorPlain "Plain Text" 0
 menuText E CrosstabColorHyper "Hypertext" 0
 menuText E CrosstabHelp "Help" 0
-menuText E CrosstabHelpCross "Crosstable help" 0
-menuText E CrosstabHelpIndex "Help index" 0
+menuText E CrosstabHelpCross "Crosstable Help" 0
+menuText E CrosstabHelpIndex "Help Index" 0
 translate E SetFilter {Set Filter}
 translate E AddToFilter {Add to Filter}
 translate E Swiss {Swiss}
+translate E Category {Category}
 
 # Opening report window menus:
 menuText E OprepFile "File" 0
-menuText E OprepFileText "Print to Text file..." 9
-menuText E OprepFileHtml "Print to HTML file..." 9
-menuText E OprepFileLaTeX "Print to LaTeX file..." 9
+menuText E OprepFileText "Print to Text File..." 9
+menuText E OprepFileHtml "Print to HTML File..." 9
+menuText E OprepFileLaTeX "Print to LaTeX File..." 9
 menuText E OprepFileOptions "Options..." 0
-menuText E OprepFileClose "Close report window" 0
+menuText E OprepFileClose "Close Report Window" 0
+menuText E OprepFavorites "Favorites" 1
+menuText E OprepFavoritesAdd "Add Report..." 0
+menuText E OprepFavoritesEdit "Edit Report Favorites..." 0
+menuText E OprepFavoritesGenerate "Generate Reports..." 0
 menuText E OprepHelp "Help" 0
-menuText E OprepHelpReport "Opening Report help" 0
-menuText E OprepHelpIndex "Help index" 0
+menuText E OprepHelpReport "Opening Report Help" 0
+menuText E OprepHelpIndex "Help Index" 0
 
 # Repertoire editor:
 menuText E RepFile "File" 0
@@ -582,21 +646,21 @@ menuText E RepFileNew "New" 0
 menuText E RepFileOpen "Open..." 0
 menuText E RepFileSave "Save..." 0
 menuText E RepFileSaveAs "Save As..." 5
-menuText E RepFileClose "Close window" 0
+menuText E RepFileClose "Close Window" 0
 menuText E RepEdit "Edit" 0
 menuText E RepEditGroup "Add Group" 4
-menuText E RepEditInclude "Add Include line" 4
-menuText E RepEditExclude "Add Exclude line" 4
+menuText E RepEditInclude "Add Include Line" 4
+menuText E RepEditExclude "Add Exclude Line" 4
 menuText E RepView "View" 0
-menuText E RepViewExpand "Expand all groups" 0
-menuText E RepViewCollapse "Collapse all groups" 0
+menuText E RepViewExpand "Expand All Groups" 0
+menuText E RepViewCollapse "Collapse All Groups" 0
 menuText E RepSearch "Search" 0
-menuText E RepSearchAll "All of repertoire..." 0
-menuText E RepSearchDisplayed "Displayed lines only..." 0
+menuText E RepSearchAll "All of Repertoire..." 0
+menuText E RepSearchDisplayed "Displayed Lines Only..." 0
 menuText E RepHelp "Help" 0
-menuText E RepHelpRep "Repertoire help" 0
-menuText E RepHelpIndex "Help index" 0
-translate E RepSearch "Repertoire search"
+menuText E RepHelpRep "Repertoire Help" 0
+menuText E RepHelpIndex "Help Index" 0
+translate E RepSearch "Repertoire Search"
 translate E RepIncludedLines "included lines"
 translate E RepExcludedLines "excluded lines"
 translate E RepCloseDialog {This repertoire has unsaved changes.
@@ -672,6 +736,7 @@ translate E NumDeletedGames {Deleted games:}
 translate E NumFilterGames {Games in filter:}
 translate E YearRange {Year range:}
 translate E RatingRange {Rating range:}
+translate E Description {Description}
 translate E Flag {Flag}
 translate E DeleteCurrent {Delete current game}
 translate E DeleteFilter {Delete filter games}
@@ -697,6 +762,8 @@ translate E CompactDatabase {Compact database}
 translate E SortDatabase {Sort database}
 translate E AddEloRatings {Add Elo ratings}
 translate E AutoloadGame {Autoload game number}
+translate E StripTags {Strip PGN tags}
+translate E StripTag {Strip tag}
 translate E Cleaner {Cleaner}
 translate E CleanerHelp {
 The Scid Cleaner will perform all the maintenance actions you select from the list below, on the current database.
@@ -714,6 +781,7 @@ Are you sure you want to commence the maintenance functions you selected?
 # Comment editor:
 translate E AnnotationSymbols  {Annotation Symbols:}
 translate E Comment {Comment:}
+translate E InsertMark {Insert mark}
 
 # Board search:
 translate E BoardSearch {Board Search}
@@ -756,7 +824,7 @@ translate E InitialBoard {Initial board}
 translate E SideToMove {Side to move}
 translate E MoveNumber {Move number}
 translate E Castling {Castling}
-translate E EnPassentFile {En Passent file}
+translate E EnPassantFile {En Passant file}
 translate E ClearFen {Clear FEN}
 translate E PasteFen {Paste FEN}
 
@@ -786,6 +854,7 @@ Do you really want to continue and discard the changes made to it?
 
 # Exit dialog:
 translate E ExitDialog {Do you really want to exit Scid?}
+translate E ExitUnsaved {The following databases have unsaved game changes. If you exit now, these changes will be lost.}
 
 # Import window:
 translate E PasteCurrentGame {Paste current game}
@@ -819,6 +888,7 @@ translate E OprepUp {up %u%s from all years}
 translate E OprepDown {down %u%s from all years}
 translate E OprepSame {no change from all years}
 translate E OprepMostFrequent {Most frequent players}
+translate E OprepMostFrequentOpponents {Most frequent opponents}
 translate E OprepRatingsPerf {Ratings and Performance}
 translate E OprepAvgPerf {Average ratings and performance}
 translate E OprepWRating {White rating}
@@ -844,14 +914,16 @@ translate E OprepMoveOrdersAll \
 translate E OprepMoveOrdersMany \
   {There were %u move orders reaching this position. The top %u are:}
 translate E OprepMovesFrom {Moves from the report position}
+translate E OprepMostFrequentEcoCodes {Most frequent ECO codes}
 translate E OprepThemes {Positional Themes}
-translate E OprepThemeDescription {Frequency of themes at move %u}
+translate E OprepThemeDescription {Frequency of themes in the first %u moves of each game}
 translate E OprepThemeSameCastling {Same-side castling}
 translate E OprepThemeOppCastling {Opposite castling}
 translate E OprepThemeNoCastling {Both Kings uncastled}
 translate E OprepThemeKPawnStorm {Kingside pawn storm}
 translate E OprepThemeQueenswap {Queens exchanged}
-translate E OprepThemeIQP {Isolated Queen Pawn}
+translate E OprepThemeWIQP {White Isolated Queen Pawn}
+translate E OprepThemeBIQP {Black Isolated Queen Pawn}
 translate E OprepThemeWP567 {White Pawn on 5/6/7th rank}
 translate E OprepThemeBP234 {Black Pawn on 2/3/4th rank}
 translate E OprepThemeOpenCDE {Open c/d/e file}
@@ -864,6 +936,27 @@ translate E OprepTheoryTable {Theory Table}
 translate E OprepTableComment {Generated from the %u highest-rated games.}
 translate E OprepExtraMoves {Extra note moves in theory table}
 translate E OprepMaxGames {Maximum games in theory table}
+translate E OprepViewHTML {View HTML}
+translate E OprepViewLaTeX {View LaTeX}
+
+# Player Report:
+translate E PReportTitle {Player Report}
+translate E PReportColorWhite {with the White pieces}
+translate E PReportColorBlack {with the Black pieces}
+translate E PReportMoves {after %s}
+translate E PReportOpenings {Openings}
+translate E PReportClipbase {Empty clipbase and copy matching games to it}
+
+# Piece Tracker window:
+translate E TrackerSelectSingle {Left mouse button selects this piece.}
+translate E TrackerSelectPair {Left mouse button selects this piece; right button also selects its sibling.}
+translate E TrackerSelectPawn {Left mouse button selects this pawn; right button selects all 8 pawns.}
+translate E TrackerStat {Statistic}
+translate E TrackerGames {% games with move to square}
+translate E TrackerTime {% time on each square}
+translate E TrackerMoves {Moves}
+translate E TrackerMovesStart {Enter the move number where tracking should begin.}
+translate E TrackerMovesStop {Enter the move number where tracking should stop.}
 
 # Game selection dialogs:
 translate E SelectAllGames {All games in the database}
@@ -895,6 +988,10 @@ translate E TwinsUndelete {Undelete all games first?}
 translate E TwinsSetFilter {Set filter to all deleted twin games?}
 translate E TwinsComments {Always keep games with comments?}
 translate E TwinsVars {Always keep games with variations?}
+translate E TwinsDeleteWhich {Delete which game:}
+translate E TwinsDeleteShorter {Shorter game}
+translate E TwinsDeleteOlder {Smaller game number}
+translate E TwinsDeleteNewer {Larger game number}
 translate E TwinsDelete {Delete games}
 
 # Name editor window:
@@ -940,6 +1037,7 @@ translate E IndentComments {Indent comments?}
 translate E IndentVariations {Indent variations?}
 translate E ExportColumnStyle {Column style (one move per line)?}
 translate E ExportSymbolStyle {Symbolic annotation style:}
+translate E ExportStripMarks {Strip square/arrow mark codes from comments?}
 
 # Goto game/move dialogs:
 translate E LoadGameNumber {Enter the game number to load:}
@@ -996,5 +1094,16 @@ This may take a while, but it only needs to be done one time. You can cancel if
 Do you want to upgrade this database now?
 }
 
+# Recent files options:
+translate E RecentFilesMenu {Number of recent files in File menu}
+translate E RecentFilesExtra {Number of recent files in extra submenu}
+
+# My Player Names options:
+translate E MyPlayerNamesDescription {
+Enter a list of preferred player names below, one name per line. Wildcards (e.g. "?" for any single character, "*" for any sequence of characters) are permitted.
+
+Every time a game with a player in the list is loaded, the main window chessboard will be rotated if necessary to show the game from that players perspective.
+}
+
 }
 # end of english.tcl
