@@ -86,15 +86,16 @@ proc updateHelpWindow {name {heading ""}} {
 
     frame $w.b -relief raised -border 2
     pack $w.b -side bottom -fill x
+    button $w.b.contents -textvar ::tr(Contents) -command { helpWindow Contents }
     button $w.b.index -textvar ::tr(Index) -command { helpWindow Index }
     button $w.b.back -textvar ::tr(Back) -command { help_PopStack }
-    button $w.b.close -textvar ::tr(Close) -command { 
+    button $w.b.close -textvar ::tr(Close) -command {
       set ::helpWin(Stack) {}
       set ::helpWin(yStack) {}
-      destroy .helpWin 
+      destroy .helpWin
     }
 
-    pack $w.b.index $w.b.back -side left -padx 5 -pady 2
+    pack $w.b.contents $w.b.index $w.b.back -side left -padx 5 -pady 2
     pack $w.b.close -side right -padx 5 -pady 2
     pack $w.scroll -side right -fill y -padx 2 -pady 2
     pack $w.text -fill both -expand 1 -padx 5
@@ -110,6 +111,8 @@ proc updateHelpWindow {name {heading ""}} {
 
   $w.b.index configure -state normal
   if {$name == "Index"} { $w.b.index configure -state disabled }
+  $w.b.contents configure -state normal
+  if {$name == "Contents"} { $w.b.contents configure -state disabled }
   $w.b.back configure -state disabled
   if {[llength $helpWin(Stack)] >= 2} {
     $w.b.back configure -state normal
@@ -191,14 +194,19 @@ proc ::htext::init {w} {
 
   # PGN-window-specific tags:
   $w tag configure tag -foreground $::pgnColor(Header)
-  $w tag configure nag -foreground $::pgnColor(Nag)
-  $w tag configure var -foreground $::pgnColor(Var)
+  if { $::pgnMoveFont } {
+     $w tag configure nag -foreground $::pgnColor(Nag) -font font_Regular
+     $w tag configure var -foreground $::pgnColor(Var) -font font_Regular
+  } else {
+     $w tag configure nag -foreground $::pgnColor(Nag) 
+     $w tag configure var -foreground $::pgnColor(Var) 
+  }
   $w tag configure ip1 -lmargin1 25 -lmargin2 25
   $w tag configure ip2 -lmargin1 50 -lmargin2 50
 }
 
 proc ::htext::isStartTag {tagName} {
-  return [expr ![strIsPrefix "/" $tagName]]
+  return [expr {![strIsPrefix "/" $tagName]} ]
 }
 
 proc ::htext::isEndTag {tagName} {
@@ -227,6 +235,7 @@ set ::htext::interrupt 0
 
 proc ::htext::display {w helptext {section ""} {fixed 1}} {
   global helpWin
+  # set start [clock clicks -milli]
   set helpWin(Indent) 0
   set ::htext::interrupt 0
   $w mark set insert 0.0
@@ -258,7 +267,7 @@ proc ::htext::display {w helptext {section ""} {fixed 1}} {
     set endPos [string first ">" $str]
     if {$endPos < 1} { break }
 
-    set tagName [string range $str [expr $startPos + 1] [expr $endPos - 1]]
+    set tagName [string range $str [expr {$startPos + 1}] [expr {$endPos - 1}]]
 
     # Check if it is a starting tag (no "/" at the start):
 
@@ -279,10 +288,8 @@ proc ::htext::display {w helptext {section ""} {fixed 1}} {
         $w tag bind $linkTag <Any-Leave> \
           "$w tag configure \"$linkTag\" -background {}
            $w configure -cursor {}"
-      }
-
-      # Check if it is a URL tag:
-      if {[strIsPrefix "url " $tagName]} {
+      } elseif {[strIsPrefix "url " $tagName]} {
+        # Check if it is a URL tag:
         set urlName [string range $tagName 4 end]
         set urlTag "url $urlName"
         set tagName "url"
@@ -294,10 +301,8 @@ proc ::htext::display {w helptext {section ""} {fixed 1}} {
         $w tag bind $urlTag <Any-Leave> \
           "$w tag configure \"$urlTag\" -background {}
            $w configure -cursor {}"
-      }
-
-      # Check if it is a Tcl command tag:
-      if {[strIsPrefix "run " $tagName]} {
+      } elseif {[strIsPrefix "run " $tagName]} {
+        # Check if it is a Tcl command tag:
         set runName [string range $tagName 4 end]
         set runTag "run $runName"
         set tagName "run"
@@ -310,10 +315,8 @@ proc ::htext::display {w helptext {section ""} {fixed 1}} {
           "$w tag configure \"$runTag\" -foreground {}
            $w tag configure \"$runTag\" -background {}
            $w configure -cursor {}"
-      }
-
-      # Check if it is a goto tag:
-      if {[strIsPrefix "go " $tagName]} {
+      } elseif {[strIsPrefix "go " $tagName]} {
+        # Check if it is a goto tag:
         set goName [string range $tagName 3 end]
         set goTag "go $goName"
         set tagName "go"
@@ -327,10 +330,8 @@ proc ::htext::display {w helptext {section ""} {fixed 1}} {
           "$w tag configure \"$goTag\" -foreground {}
            $w tag configure \"$goTag\" -background {}
            $w configure -cursor {}"
-      }
-
-      # Check if it is a player info tag:
-      if {[strIsPrefix "pi " $tagName]} {
+      } elseif {[strIsPrefix "pi " $tagName]} {
+        # Check if it is a player info tag:
         set playerTag $tagName
         set playerName [string range $playerTag 3 end]
         set tagName "pi"
@@ -344,10 +345,8 @@ proc ::htext::display {w helptext {section ""} {fixed 1}} {
           "$w tag configure \"$playerTag\" -foreground darkBlue
            $w tag configure \"$playerTag\" -background {}
            $w configure -cursor {}"
-      }
-
-      # Check if it is a game-load tag:
-      if {[strIsPrefix "g_" $tagName]} {
+      } elseif {[strIsPrefix "g_" $tagName]} {
+        # Check if it is a game-load tag:
         set gameTag $tagName
         set tagName "g"
         set gnum [string range $gameTag 2 end]
@@ -363,10 +362,8 @@ proc ::htext::display {w helptext {section ""} {fixed 1}} {
           "$w tag configure $gameTag -foreground {}
            $w tag configure $gameTag -background {}
            $w configure -cursor {}"
-      }
-
-      # Check if it is a move tag:
-      if {[strIsPrefix "m_" $tagName]} {
+      } elseif {[strIsPrefix "m_" $tagName]} {
+        # Check if it is a move tag:
         set moveTag $tagName
         set tagName "m"
         $w tag bind $moveTag <ButtonRelease-1> \
@@ -377,13 +374,16 @@ proc ::htext::display {w helptext {section ""} {fixed 1}} {
         $w tag bind $moveTag <Any-Leave> \
           "$w tag configure $moveTag -underline 0
            $w configure -cursor {}"
-      }
-
-      # Check if it is a comment tag:
-      if {[strIsPrefix "c_" $tagName]} {
+      } elseif {[strIsPrefix "c_" $tagName]} {
+        # Check if it is a comment tag:
         set commentTag $tagName
         set tagName "c"
-        $w tag configure $commentTag -foreground $::pgnColor(Comment)
+        if { $::pgnMoveFont } {
+          $w tag configure $commentTag -foreground $::pgnColor(Comment) \
+            -font font_Regular
+        } else {
+           $w tag configure $commentTag -foreground $::pgnColor(Comment) 
+        }
         $w tag bind $commentTag <ButtonRelease-1> \
           "sc_move pgn [string range $commentTag 2 end]; updateBoard; openCommentWin"
         $w tag bind $commentTag <Any-Enter> \
@@ -399,7 +399,7 @@ proc ::htext::display {w helptext {section ""} {fixed 1}} {
     }
 
     # Now insert the text up to the formatting tag:
-    $w insert end [string range $str 0 [expr $startPos - 1]]
+    $w insert end [string range $str 0 [expr {$startPos - 1}]]
 
     # Check if it is a name tag matching the section we want:
     if {$section != ""  &&  [strIsPrefix "name " $tagName]} {
@@ -470,9 +470,13 @@ proc ::htext::display {w helptext {section ""} {fixed 1}} {
       button $winName -image $imgName
       $w window create end -window $winName
     }
+    if {[strIsPrefix "window " $tagName]} {
+      set winName [string range $tagName 7 end]
+      $w window create end -window $winName
+    }
 
     # Now eliminate the processed text from the string:
-    set str [string range $str [expr $endPos + 1] end]
+    set str [string range $str [expr {$endPos + 1}] end]
     incr count
     if {$count == $::htext::updates($w)} { update idletasks; set count 1 }
     if {$::htext::interrupt} {
@@ -486,6 +490,7 @@ proc ::htext::display {w helptext {section ""} {fixed 1}} {
 
   if {$seePoint != ""} { $w yview $seePoint }
   $w configure -state disabled
+  # set elapsed [expr {[clock clicks -milli] - $start}]
 }
 
 
