@@ -1,6 +1,6 @@
 # maint.tcl:   Maintenance-related functions
 # Part of Scid.
-# Copyright (C) 2000 Shane Hudson.
+# Copyright (C) 2000-2003 Shane Hudson.
 
 
 # setGameFlags:
@@ -25,9 +25,10 @@ proc setGameFlags {flag type value} {
     }
     default { return }
   }
-  updateBoard .board
+  updateBoard
   updateGList
   updateMaintWin
+  updateStatsWin
 }
 
 set maintFlag W
@@ -86,6 +87,14 @@ proc makeMaintWin {} {
   label $w.title.dates -textvar ::tr(YearRange) -font $font
   label $w.title.ratings -textvar ::tr(RatingRange) -font $font
   button $w.title.vicon -command {changeBaseType [sc_base current]}
+  frame $w.title.desc
+  label $w.title.desc.lab -text $::tr(Description:) -font font_SmallBold
+  label $w.title.desc.text -width 1 -font $font -relief sunken -anchor w
+  button $w.title.desc.edit -text "[tr Edit]..." -font $font \
+    -command changeBaseDescription
+  pack $w.title.desc.lab -side left
+  pack $w.title.desc.edit -side right -padx 2
+  pack $w.title.desc.text -side left -fill x -expand yes
 
   foreach name {name games delete mark filter dates ratings} {
     label $w.title.v$name -text "0" -font $font
@@ -104,6 +113,7 @@ proc makeMaintWin {} {
   grid [label $w.title.space -text "   "] -row 0 -column 2
   $w.title.vname configure -font font_Bold
   $w.title.vgames configure -font font_SmallBold
+  grid $w.title.desc -row $row -column 0 -columnspan 5 -sticky we
 
   foreach grid {title delete mark spell db} cols {5 3 3 4 3} {
     for {set i 0} {$i < $cols} {incr i} {
@@ -166,8 +176,9 @@ proc makeMaintWin {} {
   button $w.db.dups -textvar ::tr(DeleteTwins...) -command "markTwins $w"
   button $w.db.cleaner -textvar ::tr(Cleaner...) -command cleanerWin
   button $w.db.autoload -textvar ::tr(AutoloadGame...) -command setAutoloadGame
+  button $w.db.strip -textvar ::tr(StripTags...) -command stripTags
 
-  foreach i {eco compact sort elo dups cleaner autoload} {
+  foreach i {eco compact sort elo dups cleaner autoload strip} {
     $w.db.$i configure -font $font
   }
   bind $w <Alt-d> "$w.db.dups invoke"
@@ -179,6 +190,7 @@ proc makeMaintWin {} {
   grid $w.db.dups -row 2 -column 1 -sticky we
   grid $w.db.cleaner -row 2 -column 2 -sticky we
   grid $w.db.autoload -row 3 -column 0 -sticky we
+  grid $w.db.strip -row 3 -column 1 -sticky we
 
   button $w.buttons.help -textvar ::tr(Help) -command {helpWindow Maintenance}
   button $w.buttons.close -textvar ::tr(Close) -command "destroy $w"
@@ -189,6 +201,29 @@ proc makeMaintWin {} {
   updateMaintWin
 }
 
+proc changeBaseDescription {} {
+  set w .bdesc
+  if {[winfo exists $w]} { return }
+  toplevel $w
+  wm title $w "Scid: $::tr(Description): [file tail [sc_base filename]]"
+  set font font_Small
+  entry $w.entry -width 50 -relief sunken -background white
+  $w.entry insert end [sc_base description]
+  pack $w.entry -side top -pady 4
+  frame $w.b
+  button $w.b.ok -text OK -command {
+    catch {sc_base description [.bdesc.entry get]}
+    grab release .bdesc
+    destroy .bdesc
+    updateMaintWin
+  }
+  button $w.b.cancel -text $::tr(Cancel) -command "grab release $w; destroy $w"
+  pack $w.b -side bottom -fill x
+  pack $w.b.cancel $w.b.ok -side right -padx 2 -pady 2
+  wm resizable $w 0 0
+  catch {grab $w}
+}
+
 proc updateMaintWin {} {
   global maintFlag maintFlags
   updateSortWin
@@ -216,6 +251,7 @@ proc updateMaintWin {} {
   set flagname "$::tr(Flag): $::tr($maintFlags($maintFlag)) ($maintFlag)"
   $w.mark.title configure -text $flagname
   $w.title.mark configure -text $flagname
+  $w.title.desc.text configure -text [sc_base description]
 
   # Disable buttons if current base is closed or read-only:
   set state disabled
@@ -231,6 +267,7 @@ proc updateMaintWin {} {
   }
   $w.db.dups configure -state $state
   $w.title.vicon configure -state $state
+  $w.title.desc.edit configure -state $state
   $w.db.elo configure -state $state
   $w.db.autoload configure -state $state
 
@@ -238,6 +275,7 @@ proc updateMaintWin {} {
   if {[sc_base inUse]} { set state normal }
   $w.db.eco configure -state $state
   $w.db.sort configure -state $state
+  $w.db.strip configure -state $state
 
   set state disabled
   if {[baseIsCompactable]} {
@@ -354,7 +392,7 @@ proc markTwins {{parent .}} {
     grid $w.g.yesPlayers -row $row -column 1 -columnspan 3 -sticky w
     grid $w.g.noPlayers  -row $row -column 4 -columnspan 3 -sticky w
   }
-    
+
 
   addHorizontalRule $w
   label $w.twhich -text $::tr(TwinsWhich:) -font font_Bold
@@ -378,17 +416,31 @@ proc markTwins {{parent .}} {
   set row 0
   foreach n {skipshort undelete setfilter comments variations} {
     label $w.g3.l$n -text "" -font $small
-    checkbutton $w.g3.v$n -width 6 -variable twinSettings($n) -font $small \
-      -textvariable twinSettings($n) -onvalue Yes -offvalue No -anchor w
-      grid $w.g3.l$n -row $row -column 0 -sticky w
-      grid $w.g3.v$n -row $row -column 1 -sticky w
-      incr row
+    radiobutton $w.g3.yes$n -variable twinSettings($n) -value Yes \
+      -text $::tr(Yes) -font $small
+    radiobutton $w.g3.no$n -variable twinSettings($n) -value No \
+        -text $::tr(No) -font $small
+    grid $w.g3.l$n -row $row -column 0 -sticky w
+    grid $w.g3.yes$n -row $row -column 1 -sticky w
+    grid $w.g3.no$n -row $row -column 2 -sticky w
+    incr row
   }
   $w.g3.lskipshort configure -text $::tr(TwinsSkipShort)
   $w.g3.lundelete configure -text $::tr(TwinsUndelete)
   $w.g3.lsetfilter configure -text $::tr(TwinsSetFilter)
   $w.g3.lcomments configure -text $::tr(TwinsComments)
   $w.g3.lvariations configure -text $::tr(TwinsVars)
+  label $w.g3.ldelete -text $::tr(TwinsDeleteWhich)  -font $small
+  grid $w.g3.ldelete -row $row -column 0 -sticky we -columnspan 3
+  incr row
+  frame $w.g3.vdelete
+  foreach v {Shorter Older Newer} {
+    radiobutton $w.g3.vdelete.v$v -text $::tr(TwinsDelete$v) \
+      -variable twinSettings(delete) -value $v -font $small
+    pack $w.g3.vdelete.v$v -side left -padx 5
+  }
+  grid $w.g3.vdelete -row $row -column 0 -columnspan 3
+
   foreach g {g g2 g3} {
     grid columnconfigure $w.$g 0 -weight 1
   }
@@ -398,9 +450,9 @@ proc markTwins {{parent .}} {
   button $w.b.defaults -textvar ::tr(Defaults) -command {
     array set twinSettings [array get twinSettingsDefaults]
   }
-  button $w.b.help -text $::tr(Help) \
+  button $w.b.help -text $::tr(Help) -font $small \
     -command "helpWindow Maintenance Twins; focus $w"
-  button $w.b.go -text $::tr(TwinsDelete) -command {
+  button $w.b.go -text $::tr(TwinsDelete) -font $small -command {
     if {[twinCriteriaOK .twinSettings]} {
       grab release .twinSettings
       sc_progressBar .twinSettings.progress bar 301 21 time
@@ -411,7 +463,7 @@ proc markTwins {{parent .}} {
     }
   }
 
-  button $w.b.cancel -text $::tr(Cancel) \
+  button $w.b.cancel -text $::tr(Cancel) -font $small \
     -command "grab release $w; focus .; destroy $w"
   canvas $w.progress -width 300 -height 20 -bg white -relief solid -border 1
   $w.progress create rectangle 0 0 0 0 -fill blue -outline blue -tags bar
@@ -498,7 +550,8 @@ proc doMarkDups {{parent .}} {
                 -setfilter $twinSettings(setfilter) \
                 -usefilter $twinSettings(usefilter) \
                 -comments $twinSettings(comments) \
-                -variations $twinSettings(variations)} result]} {
+                -variations $twinSettings(variations) \
+                -delete $twinSettings(delete)} result]} {
     unbusyCursor .
     tk_messageBox -type ok -parent $parent -icon info \
       -title "Scid" -message $result
@@ -516,7 +569,7 @@ proc doMarkDups {{parent .}} {
 }
 
 
-set classifyOption(AllGames) 1
+set classifyOption(AllGames) all
 set classifyOption(ExtendedCodes) 1
 
 # ClassifyAllGames:
@@ -538,12 +591,15 @@ proc makeClassifyWin {} {
   toplevel $w
   wm title $w "Scid: [tr FileMaintClass]"
   label $w.label -font font_Bold -textvar ::tr(ClassifyWhich)
-  radiobutton $w.all -textvar ::tr(ClassifyAll) \
-    -variable classifyOption(AllGames) -value 1
+  frame $w.g
+  radiobutton $w.g.all -textvar ::tr(ClassifyAll) \
+    -variable classifyOption(AllGames) -value all
+  radiobutton $w.g.filter -textvar ::tr(SelectFilterGames) \
+    -variable classifyOption(AllGames) -value filter
   set year [::date::today year]
   set month [::date::today month]
   set day [::date::today day]
-  radiobutton $w.year -textvar ::tr(ClassifyYear) \
+  radiobutton $w.g.year -textvar ::tr(ClassifyYear) \
     -variable classifyOption(AllGames) \
     -value "date:[expr $year - 1].$month.$day"
   if {$month == "01"} {
@@ -554,11 +610,16 @@ proc makeClassifyWin {} {
     incr month -1
     set month [format "%02u" $month]
   }
-  radiobutton $w.month -textvar ::tr(ClassifyMonth) \
+  radiobutton $w.g.month -textvar ::tr(ClassifyMonth) \
     -variable classifyOption(AllGames) \
     -value "date:$year.$month.$day"
-  radiobutton $w.new -textvar ::tr(ClassifyNew) \
-    -variable classifyOption(AllGames) -value 0
+  radiobutton $w.g.new -textvar ::tr(ClassifyNew) \
+    -variable classifyOption(AllGames) -value nocode
+  set row 0
+  foreach f {all filter year month new} {
+    grid $w.g.$f -row $row -column 0 -sticky w
+    incr row
+  }
   label $w.codes -font font_Bold -textvar ::tr(ClassifyCodes:)
   radiobutton $w.extended -textvar ::tr(ClassifyBasic) \
     -variable classifyOption(ExtendedCodes) -value 0
@@ -590,7 +651,7 @@ proc makeClassifyWin {} {
   $w.progress create text 295 10 -anchor e -font font_Regular -tags time \
     -fill black -text "0:00 / 0:00"
 
-  pack $w.label $w.all $w.year $w.month $w.new -side top -pady 5
+  pack $w.label $w.g -side top -pady 5
   addHorizontalRule $w
   pack $w.codes $w.extended $w.basic -side top -pady 5
   addHorizontalRule $w
@@ -635,30 +696,30 @@ proc updateTwinChecker {} {
       pack [frame $f.title] -side top -fill x
       label $f.title.label -font font_Bold -text "Game 0: "
       checkbutton $f.title.d -text "Deleted" -pady 5 \
-        -variable twincheck($i)
-      label $f.title.note
+        -variable twincheck($i) -font font_Small
+      label $f.title.note -font font_Small
       pack $f.title.label $f.title.d $f.title.note -side left
-      frame $f.t
-      pack $f.t -side top -fill both -expand yes
-      text $f.t.text -height 16 -width 40 -background white \
-        -yscroll "$f.t.ybar set" -takefocus 0 -wrap word
+      label $f.tmt -font font_Small -text "" -anchor w -width 1 -relief sunken
+      pack $f.tmt -side bottom -fill x
+      autoscrollframe $f.t text $f.t.text \
+        -height 16 -width 40 -background white \
+        -takefocus 0 -wrap word
       $f.t.text tag configure h -background lightSteelBlue
-      scrollbar $f.t.ybar -command "$f.t.text yview"
-      pack $f.t.ybar -side right -fill y
-      pack $f.t.text -fill both -expand yes
+      pack $f.t -side top -fill both -expand yes
     }
     $w.f.left.title.note configure -text {("1" to flip; "u" undeletes both)}
     $w.f.right.title.note configure -text {("2" to flip; "u" undeletes both)}
-    button $w.b.prev -text "Previous filter game" -underline 0 \
+    button $w.b.prev -text "Previous pair" -underline 0 \
       -command {gameLoadNextPrev previous}
-    button $w.b.next -text "Next filter game" -underline 0 \
+    button $w.b.next -text "Next pair" -underline 0 \
       -command {gameLoadNextPrev next}
+    button $w.b.share -text "Share tags..." -underline 0
     button $w.b.delete -text "Delete twin games..." -underline 0 \
       -command "markTwins $w"
     button $w.b.help -text "Help" -command {helpWindow Maintenance Twins}
     button $w.b.close -text "Close" -command "focus .; destroy $w"
     pack $w.b.close $w.b.help $w.b.delete -side right -padx 5 -pady 2
-    pack $w.b.prev $w.b.next -side left -padx 5 -pady 2
+    pack $w.b.prev $w.b.next $w.b.share -side left -padx 5 -pady 2
     bind $w <F1> "$w.b.help invoke"
     bind $w <Escape> "focus .; destroy $w"
     bind $w <Alt-p> {gameLoadNextPrev previous}
@@ -669,6 +730,7 @@ proc updateTwinChecker {} {
     bind $w <KeyPress-d> "markTwins $w"
     bind $w <KeyPress-1> "$w.f.left.title.d invoke"
     bind $w <KeyPress-2> "$w.f.right.title.d invoke"
+    bind $w <KeyPress-s> "$w.b.share invoke"
     bind $w <KeyPress-u> {
       if {$twincheck(left)} {.twinchecker.f.left.title.d invoke}
       if {$twincheck(right)} {.twinchecker.f.right.title.d invoke}
@@ -695,19 +757,31 @@ proc updateTwinChecker {} {
     set twincheck(left) [sc_game flag delete $gn]
     $w.f.left.title.d configure -command "sc_game flag delete $gn invert; updateBoard"
     $w.f.left.title.d configure -state normal
+    set tmt [sc_game crosstable count +deleted]
+    $w.f.left.tmt configure -text "Games in tournament: $tmt"
   } else {
     $w.f.left.title.d configure -state disabled
+    $w.f.left.tmt configure -text ""
   }
   if {$dup > 0} {
     set twincheck(right) [sc_game flag delete $dup]
     $w.f.right.title.label configure -text "Game $dup:  "
     $w.f.right.title.d configure -command "sc_game flag delete $dup invert; updateBoard"
     $w.f.right.title.d configure -state normal
+    set tmt [sc_game crosstable count -game $dup +deleted]
+    $w.f.right.tmt configure -text "Games in tournament: $tmt"
   } else {
     $w.f.right.title.label configure -text "No twin  "
     $w.f.right.title.d configure -state disabled
+    $w.f.right.tmt configure -text ""
   }
 
+  $w.b.share configure -state disabled -command {}
+  if {$gn > 0  &&  $dup > 0} {
+    if {[llength [sc_game tags share check $gn $dup]] > 0} {
+      $w.b.share configure -state normal -command "shareTwinTags $gn $dup $w"
+    }
+  }
   set t $w.f.left.t.text
   $t configure -state normal
   $t delete 1.0 end
@@ -772,6 +846,28 @@ proc updateTwinChecker {} {
 
 }
 
+# shareTwinTags:
+#   Updates the tags of two twin games by sharing information,
+#   filling in the date, round or ratings of each game based on
+#   the other where possible.
+#
+proc shareTwinTags {g1 g2 {parent .}} {
+  set sharelist [sc_game tags share check $g1 $g2]
+  if {[llength $sharelist] == 0} { return }
+
+  set msg "Change the following game tags:\n\n"
+  foreach {gn tag old new} $sharelist {
+    append msg "Game $gn: $tag: \"$old\" -> \"$new\"\n"
+  }
+  set answer [tk_messageBox -parent $parent -title "Scid" \
+                -type okcancel -default ok -icon question -message $msg]
+  if {$answer != "ok"} { return }
+  sc_game tags share update $g1 $g2
+  sc_game tags reload
+  updateBoard -pgn
+  updateGList
+}
+
 # baseIsCompactable:
 #   Returns true only if the current base is compactable.
 #
@@ -843,7 +939,7 @@ proc makeCompactWin {} {
     label $w.games.t$g -text "$::tr($name)  "
     label $w.games.g$g -text "  [thousands [lindex $ndata $idx]]"
     incr idx
-    set kbytes [expr int(([lindex $ndata $idx] + 512) / 1024)]
+    set kbytes [expr {int(([lindex $ndata $idx] + 512) / 1024)} ]
     label $w.games.s$g -text "  [thousands $kbytes]"
     incr idx
     grid $w.games.t$g -row $row -column 0 -sticky w
@@ -887,7 +983,7 @@ proc compactNames {} {
   }
   grab release $w
   destroy $w
-  updateBoard .board
+  updateBoard
   updateGList
   updateMaintWin
 }
@@ -917,7 +1013,7 @@ proc compactGames {} {
   }
   grab release $w
   destroy $w
-  updateBoard .board
+  updateBoard
   updateGList
   updateMaintWin
 }
@@ -930,7 +1026,7 @@ proc clearSortCriteria {} {
   set ::sortCriteria(translated) ""
   updateSortWin
 }
- 
+
 proc addSortCriteria {args} {
   global sortCriteria
   foreach x $args {
@@ -965,7 +1061,7 @@ proc makeSortWin {} {
   label $w.tadd -textvar ::tr(AddCriteria:) -font font_Bold
   pack $w.tadd -side top
   pack [frame $w.add] -side top -fill x
-  foreach b {Date Year Month Event Site Country Round Result Length 
+  foreach b {Date Year Month Event Site Country Round Result Length
              White Black Rating ECO Deleted EventDate} {
     set n [string tolower $b]
     button $w.add.$n -textvar ::tr($b) -command "addSortCriteria $b"
@@ -1058,7 +1154,7 @@ proc sortDatabase {} {
       -title "Scid: Sort results" \
       -message "The database was successfully sorted."
   }
-  updateBoard .board
+  updateBoard
   updateGList
   updateMaintWin
 }
@@ -1074,6 +1170,10 @@ proc makeBaseReadOnly {} {
   }
 }
 
+
+# allocateRatings:
+#   Allocate player ratings to games based on the spellcheck file.
+#
 set addRatings(overwrite) 0
 set addRatings(filter) 0
 
@@ -1137,6 +1237,124 @@ proc doAllocateRatings {} {
 }
 
 
+# stripTags:
+#   Strip unwanted PGN tags from the current database.
+
+array set stripTagCount {}
+
+proc stripTags {} {
+  global stripTagChoice stripTagCount
+  set w .striptags
+  if {[winfo exists $w]} {
+    raise $w
+    return
+  }
+  set stripTagList {}
+
+  # Find extra PGN tags:
+  set ::interrupt 0
+  progressWindow "Scid" "Searching for extra PGN tags..." \
+    $::tr(Cancel) "set ::interrupt 1; sc_progressBar"
+  busyCursor .
+  set err [catch {sc_base tag list} result]
+  unbusyCursor .
+  closeProgressWindow
+  if {$::interrupt} { return }
+  if {$err} {
+    tk_messageBox -title "Scid" -icon warning -type ok -message $result
+    return
+  }
+
+  # Make list of extra tags and their frequency:
+  array unset stripTagCount
+  set nTags 0
+  foreach {tag count} $result {
+    set stripTagCount($tag) $count
+    incr nTags
+  }
+
+  if {$nTags == 0} {
+    tk_messageBox -title "Scid" -icon info -type ok \
+      -message "No extra tags were found."
+    return
+  }
+
+  toplevel $w
+  wm title $w "Scid: $::tr(StripTags)"
+  label $w.title -text "Extra PGN tags:" -font font_Bold
+  pack $w.title -side top
+  pack [frame $w.f] -side top -fill x
+  addHorizontalRule $w
+  pack [frame $w.b] -side bottom -fill x
+
+  set row 0
+  foreach tag [lsort [array names stripTagCount]] {
+    set count $stripTagCount($tag)
+    radiobutton $w.f.t$tag -text "$tag  " -variable stripTagChoice -value $tag
+    label $w.f.c$tag -text [thousands $count]
+    if {$row == 0} { set stripTagChoice $tag }
+    grid $w.f.t$tag -row $row -column 0 -sticky w
+    grid $w.f.c$tag -row $row -column 1 -sticky e
+    incr row
+  }
+  button $w.b.find -text $::tr(SetFilter) -command findStripTags
+  button $w.b.strip -text $::tr(StripTag...) -command {
+    set removed [doStripTags .striptags]
+    set stripTagCount($stripTagChoice) \
+      [expr {$stripTagCount($stripTagChoice) - $removed} ]
+    .striptags.f.c$stripTagChoice configure -text \
+      [thousands $stripTagCount($stripTagChoice)]
+  }
+  button $w.b.cancel -text $::tr(Cancel) \
+    -command "catch {grab release $w}; destroy $w"
+  pack $w.b.cancel $w.b.strip $w.b.find -side right -padx 2 -pady 2
+  wm resizable $w 0 0
+  update
+  catch {grab $w}
+}
+
+proc doStripTags {{parent .}} {
+  global stripTagChoice
+  set msg "Do you really want to remove all occurences of the PGN tag"
+  append msg " \"$stripTagChoice\" from this database?"
+  set result [tk_messageBox -title "Scid" -parent $parent \
+                -icon question -type yesno -message $msg]
+  if {$result == "no"} { return 0 }
+  progressWindow "Scid" "Removing the PGN tag $stripTagChoice..." \
+    $::tr(Cancel) "sc_progressBar"
+  busyCursor .
+  set err [catch {sc_base tag strip $stripTagChoice} result]
+  unbusyCursor .
+  closeProgressWindow
+  set count 0
+  if {! $err} {
+    set count $result
+    set result "Removed $result instances of \"$stripTagChoice\"."
+    append result "\n\n"
+    append result "To save space and maintain database efficiency, it is a "
+    append result "good idea to compact the game file after removing tags."
+  }
+  tk_messageBox -title "Scid" -parent $parent -type ok -icon info \
+    -message $result
+  return $count
+}
+
+proc findStripTags {} {
+  global stripTagChoice
+  progressWindow "Scid" "Finding games with the PGN tag $stripTagChoice..." \
+    $::tr(Cancel) "sc_progressBar"
+  busyCursor .
+  set err [catch {sc_base tag find $stripTagChoice} result]
+  unbusyCursor .
+  closeProgressWindow
+  updateStatsWin
+}
+
+
+# cleanerWin:
+#   Open a dialog so the user can choose several maintenance tasks
+#   in one action.
+
 set cleaner(players) 1
 set cleaner(events) 1
 set cleaner(sites) 1
@@ -1148,9 +1366,6 @@ set cleaner(cnames) 0
 set cleaner(cgames) 0
 set cleaner(tree) 0
 
-# cleanerWin:
-#   Open a dialog so the user can choose several maintenance tasks
-#   in one action.
 proc cleanerWin {} {
   set w .mtoolWin
   if {[winfo exists $w]} { return }
@@ -1160,10 +1375,10 @@ proc cleanerWin {} {
   bind $w <F1> {helpWindow Maintenance Cleaner}
 
   pack [frame $w.help] -side top -fill x
-  text $w.help.text -width 1 -height 7 -wrap word \
+  text $w.help.text -width 1 -height 8 -wrap word \
     -relief ridge -cursor top_left_arrow -yscrollcommand "$w.help.ybar set"
   scrollbar $w.help.ybar -orient vertical -command "$w.help.text yview" \
-    -takefocus 0 -width 10
+    -takefocus 0
   pack $w.help.ybar -side right -fill y
   pack $w.help.text -side left -fill x -expand yes
   $w.help.text insert end [string trim $::tr(CleanerHelp)]
@@ -1198,6 +1413,12 @@ proc cleanerWin {} {
   button $w.b.cancel -text $::tr(Cancel) -command "catch {grab release $w}; destroy $w"
   pack $w.b.cancel $w.b.ok -side right -padx 2 -pady 2
   wm resizable $w 0 0
+  # Remove the scrollbar if it is not needed:
+  update
+  set yview [$w.help.text yview]
+  if {[lindex $yview 0] <= 0.01  &&  [lindex $yview 1] >= 0.99} {
+      pack forget $w.help.ybar
+  }
   catch {grab $w}
 }
 
@@ -1292,7 +1513,8 @@ proc doCleaner {} {
                   -setfilter $twinSettings(setfilter) \
                   -usefilter $twinSettings(usefilter) \
                   -comments $twinSettings(comments) \
-                  -variations $twinSettings(variations)} result]} {
+                  -variations $twinSettings(variations) \
+                  -delete $twinSettings(delete)} result]} {
       set message $result
     } else {
       set message "Scid found $result twin games"
@@ -1357,7 +1579,7 @@ proc doCleaner {} {
   }
 
   mtoolAdd $t "Done."
-  updateBoard .board
+  updateBoard
   updateGList
   updateMaintWin
   $w.b.close configure -state normal
