@@ -97,7 +97,7 @@ proc ::date::_day {win delta} {
 }
 
 proc ::date::_month {win delta} {
-  set dir [expr ($delta > 0) ? 1 : -1]
+  set dir [expr {($delta > 0) ? 1 : -1} ]
   set day [string trimleft [clock format $::date::_time -format "%d"] 0]
   set month [string trimleft [clock format $::date::_time -format "%m"] 0]
   set year [clock format $::date::_time -format "%Y"]
@@ -125,13 +125,13 @@ proc ::date::_redraw {win} {
 
   $win.cal create window 3 3 -anchor nw -window $win.cal.prevY
   $win.cal create window 40 3 -anchor nw -window $win.cal.prev
-  $win.cal create window [expr $wmax-43] 3 -anchor ne -window $win.cal.next
-  $win.cal create window [expr $wmax-3] 3 -anchor ne -window $win.cal.nextY
+  $win.cal create window [expr {$wmax-43} ] 3 -anchor ne -window $win.cal.next
+  $win.cal create window [expr {$wmax-3} ] 3 -anchor ne -window $win.cal.nextY
   set bottom [lindex [$win.cal bbox all] 3]
 
   set month [string trimleft [clock format $time -format "%m"] 0]
   set year [clock format $time -format "%Y"]
-  $win.cal create text [expr $wmax/2] $bottom -anchor s -font font_Bold \
+  $win.cal create text [expr {$wmax/2} ] $bottom -anchor s -font font_Bold \
     -text "[lindex $::tr(Months) [expr $month - 1]] $year"
 
   incr bottom 3
@@ -141,27 +141,27 @@ proc ::date::_redraw {win} {
   set current ""
 
   set layout [::date::_layout $time]
-  set weeks [expr [lindex $layout end]+1]
+  set weeks [expr {[lindex $layout end]+1} ]
 
   for {set day 0} {$day < 7} {incr day} {
-    set x0 [expr $day*($wmax-7)/7+3]
-    set x1 [expr ($day+1)*($wmax-7)/7+3]
-    $win.cal create text [expr ($x1+$x0)/2] $bottom -anchor s \
+    set x0 [expr {$day*($wmax-7)/7+3} ]
+    set x1 [expr {($day+1)*($wmax-7)/7+3} ]
+    $win.cal create text [expr {($x1+$x0)/2} ] $bottom -anchor s \
       -text [lindex $::tr(Days) $day] -font font_Small
   }
   incr bottom 3
 
   foreach {day date dcol wrow} $layout {
-    set x0 [expr $dcol*($wmax-7)/7+3]
-    set y0 [expr $wrow*($hmax-$bottom-4)/$weeks+$bottom]
-    set x1 [expr ($dcol+1)*($wmax-7)/7+3]
-    set y1 [expr ($wrow+1)*($hmax-$bottom-4)/$weeks+$bottom]
+    set x0 [expr {$dcol*($wmax-7)/7+3} ]
+    set y0 [expr {$wrow*($hmax-$bottom-4)/$weeks+$bottom} ]
+    set x1 [expr {($dcol+1)*($wmax-7)/7+3} ]
+    set y1 [expr {($wrow+1)*($hmax-$bottom-4)/$weeks+$bottom} ]
 
     if {$date == $::date::_selected} {set current $date}
 
     $win.cal create rectangle $x0 $y0 $x1 $y1 -outline black -fill white
 
-    $win.cal create text [expr $x0+4] [expr $y0+2] -anchor nw -text "$day" \
+    $win.cal create text [expr {$x0+4} ] [expr {$y0+2} ] -anchor nw -text "$day" \
       -fill black -font font_Small -tags [list $date-text all-text]
 
     $win.cal create rectangle $x0 $y0 $x1 $y1 \
@@ -188,14 +188,14 @@ proc ::date::_layout {time} {
   }
   set seconds [clock scan "$year-$month-1"]
   set firstday [clock format $seconds -format %w]
-  set weeks [expr ceil(double($lastday+$firstday)/7)]
+  set weeks [expr {ceil(double($lastday+$firstday)/7)} ]
 
   set rlist ""
   for {set day 1} {$day <= $lastday} {incr day} {
     set seconds [clock scan "$year-$month-$day"]
     set date [clock format $seconds -format "%Y-%m-%d"]
     set daycol [clock format $seconds -format %w]
-    set weekrow [expr ($firstday+$day-1)/7]
+    set weekrow [expr {($firstday+$day-1)/7} ]
     lappend rlist $day $date $daycol $weekrow
   }
   return $rlist
@@ -249,7 +249,7 @@ proc plural {n} {
 #   thousands inserts the thousands separator (usually "," or ".") for
 #   every three digits before the decimal separator in the number.
 #   percentFormat does the same as thousands, but also adds a percentage.
-#   If "kilo" is nonzero, numbers >= $kilo are divided by 100 and have
+#   If "kilo" is nonzero, numbers >= $kilo are divided by 1000 and have
 #   the unit "K" appended.
 #
 proc thousands {n {kilo 0}} {
@@ -258,7 +258,7 @@ proc thousands {n {kilo 0}} {
   set unit ""
   if {$kilo > 0  &&  $n >= $kilo} {
     set unit "K"
-    set n [expr int($n / 1000)]
+    set n [expr {int($n / 1000)} ]
   }
   if {$commaChar == ""} { return "$n$unit" }
   while {[regsub {^([-+]?[0-9]+)([0-9][0-9][0-9])} $n "\\1$commaChar\\2" n]} {}
@@ -333,6 +333,168 @@ proc bindFocusColors {w {inColor lightYellow} {outColor white}} {
 }
 
 
+# bindMouseWheel:
+#   Given a window and a text frame within that window, binds
+#   the mouse wheel to scroll the text frame vertically.
+#
+proc bindMouseWheel {win text} {
+  bind $win <MouseWheel> \
+    "$text yview scroll \[expr -(%D / 120)\] units"
+  if {! $::windowsOS} {
+    bind $win <Button-4> [list $text yview scroll -1 units]
+    bind $win <Button-5> [list $text yview scroll  1 units]
+  }
+}
+
+# dialogbuttonframe:
+#   Creates a frame that will be shown at the bottom of a
+#   dialog window. It takes two parameters: the frame widget
+#   name to create, and a list of button args. Each element
+#   should contain a widget name, and button arguments.
+#
+proc dialogbuttonframe {frame buttonlist} {
+  frame $frame
+  set bnames {}
+  set maxlength 0
+  foreach buttonargs $buttonlist {
+    set bname $frame.[lindex $buttonargs 0]
+    set bargs [lrange $buttonargs 1 end]
+    eval button $bname $bargs
+    set bnames [linsert $bnames 0 $bname]
+    set length [string length [$bname cget -text]]
+    if {$length > $maxlength} { set length $maxlength}
+  }
+  if {$maxlength < 7} { set maxlength 7 }
+  foreach b $bnames {
+    $b configure -width $maxlength -padx 4
+    pack $b -side right -padx 4 -pady 4
+  }
+}
+
+# packbuttons
+#   Packs a row of dialog buttons to the left/right of their frame
+#   with a standard amount of padding.
+#
+proc packbuttons {side args} {
+  eval pack $args -side $side -padx 5 -pady 3
+}
+
+# dialogbutton:
+#   Creates a button that will be shown in a dialog box, so it
+#   is given a minumin width.
+#
+proc dialogbutton {w args} {
+  set retval [eval button $w $args]
+  set length [string length [$w cget -text]]
+  if {$length < 6} { set length 6 }
+  $w configure -width $length -pady 1
+  return retval
+}
+
+# autoscrollframe
+#   Creates and returns a frame containing a widget which is gridded
+#   with scrollbars that automatically hide themselves when they are
+#   not needed.
+#   The frame and widget may already exist; they are created if needed.
+#   Usage:
+#      autoscrolltext [-bars none|x|y|both] frame type w args
+#
+proc autoscrollframe {args} {
+  global _autoscroll
+  set bars both
+  if {[lindex $args 0] == "-bars"} {
+    set bars [lindex $args 1]
+    if {$bars != "x" && $bars != "y" && $bars != "none" && $bars != "both"} {
+      return -code error "Invalid parameter: -bars $bars"
+    }
+    set args [lrange $args 2 end]
+  }
+  if {[llength $args] < 3} {
+    return -code error "Insufficient number of parameters"
+  }
+  set frame [lindex $args 0]
+  set type [lindex $args 1]
+  set w [lindex $args 2]
+  set args [lrange $args 3 end]
+
+  set retval $frame
+  if {! [winfo exists $frame]} { frame $frame }
+  $frame configure -relief sunken -borderwidth 2
+  if {! [winfo exists $w]} {
+    $type $w
+  }
+  if {[llength $args] > 0} {
+    eval $w configure $args
+  }
+  $w configure -relief flat -borderwidth 0
+  grid $w -in $frame -row 0 -column 0 -sticky news
+  set setgrid 0
+  catch {set setgrid [$w cget -setgrid]}
+
+  if {$bars == "y"  ||  $bars == "both"} {
+    scrollbar $frame.ybar -command [list $w yview] -takefocus 0 -borderwidth 0
+    $w configure -yscrollcommand [list _autoscroll $frame.ybar]
+    grid $frame.ybar -row 0 -column 1 -sticky ns
+    set _autoscroll($frame.ybar) 1
+    if {! $setgrid} {
+      # bind $frame.ybar <Map> [list _autoscrollMap $frame]
+    }
+  }
+  if {$bars == "x"  ||  $bars == "both"} {
+    scrollbar $frame.xbar -command [list $w xview] -takefocus 0 \
+      -borderwidth 0 -orient horizontal
+    $w configure -xscrollcommand [list _autoscroll $frame.xbar]
+    grid $frame.xbar -row 1 -column 0 -sticky we
+    set _autoscroll($frame.xbar) 1
+    if {! $setgrid} {
+      # bind $frame.xbar <Map> [list _autoscrollMap $frame]
+    }
+  }
+  grid rowconfigure $frame 0 -weight 1
+  grid columnconfigure $frame 0 -weight 1
+  grid rowconfigure $frame 1 -weight 0
+  grid columnconfigure $frame 1 -weight 0
+  return $retval
+}
+
+array set _autoscroll {}
+
+# _autoscroll
+#   This is the "set" command called for auto-scrollbars.
+#   If the bar is shown but should not be, it is hidden.
+#   If the bar is hidden but should be shown, it is redrawn.
+#   Note that once a bar is shown, it will not be removed again for
+#   at least a few milliseconds; this is to overcome problematic
+#   interactions between the x and y scrollbars where hiding one
+#   causes the other to be shown etc. This usually happens because
+#   the stupid Tcl/Tk text widget doesn't handle scrollbars well.
+#
+proc _autoscroll {bar args} {
+  global _autoscroll
+  if {[llength $args] == 2} {
+    set min [lindex $args 0]
+    set max [lindex $args 1]
+    if {$min > 0.0  ||  $max < 1.0} {
+      if {! $_autoscroll($bar)} {
+        grid configure $bar
+        set _autoscroll($bar) [clock clicks -milli]
+      }
+    } else {
+      if {[expr {[clock clicks -milli] - 100}] > $_autoscroll($bar)} {
+        grid remove $bar
+        set _autoscroll($bar) 0
+      }
+    }
+  # update idletasks
+  }
+  eval $bar set $args
+}
+
+proc _autoscrollMap {frame} {
+  # wm geometry [winfo toplevel $frame] [wm geometry [winfo toplevel $frame]]
+}
+
+
 # busyCursor, unbusyCursor:
 #   Sets all cursors to watch (indicating busy) or back to their normal
 #   setting again.
@@ -346,12 +508,13 @@ proc doBusyCursor {w flag} {
   # The comment editor window "flashes" when its cursor is changed,
   # no idea why but skip over it:
   if {$w == ".commentWin"} { return }
+  if {$w == ".menu"} { return }
 
   if {$flag} {
     set scid_busycursor($w) [$w cget -cursor]
     catch {$w configure -cursor watch}
   } else {
-    catch {$w configure -cursor $scid_busycursor($w)}
+    catch {$w configure -cursor $scid_busycursor($w)} err
   }
   foreach i [winfo children $w] { doBusyCursor $i $flag }
 }
@@ -420,7 +583,7 @@ proc forceInt {maxValue allowQuestionMarks name el op} {
   set allowNegatives 0
   if {$maxValue < 0} {
     set allowNegatives 1
-    set maxValue [expr 0 - $maxValue]
+    set maxValue [expr {0 - $maxValue}]
   }
 
   if {$allowNegatives} {
@@ -499,7 +662,7 @@ proc forceAlpha {name el op} {
 proc forceRegexp {expression name el op} {
   global $name ${name}_old
   set old ${name}_old
-  if ![regexp $expression [set $name]] {
+  if {![regexp $expression [set $name]]} {
     set $name [set $old]
     bell
     return
@@ -544,11 +707,11 @@ proc progressWindow {args} {
   }
   # Set up geometry for middle of screen:
   set x [winfo screenwidth $w]
-  set x [expr $x - 400]
-  set x [expr $x / 2]
+  set x [expr {$x - 400} ]
+  set x [expr {$x / 2} ]
   set y [winfo screenheight $w]
-  set y [expr $y - 20]
-  set y [expr $y / 2]
+  set y [expr {$y - 20} ]
+  set y [expr {$y / 2} ]
   wm geometry $w +$x+$y
   sc_progressBar $w.c bar 401 21 time
   update idletasks
@@ -572,7 +735,7 @@ proc leftJustifyProgressWindow {} {
 
 proc changeProgressWindow {newtext} {
   set w .progressWin
-  if {[winfo exists $w]} { 
+  if {[winfo exists $w]} {
     $w.t configure -text $newtext
     update idletasks
   }
@@ -581,7 +744,7 @@ proc changeProgressWindow {newtext} {
 proc resetProgressWindow {} {
   set w .progressWin
   set ::progressWin_time [clock seconds]
-  if {[winfo exists $w]} { 
+  if {[winfo exists $w]} {
     $w.c coords bar 0 0 0 0
     $w.c itemconfigure time -text "0:00 / 0:00"
     update idletasks
@@ -591,19 +754,19 @@ proc resetProgressWindow {} {
 proc updateProgressWindow {done total} {
   set w .progressWin
   if {! [winfo exists $w]} { return }
-  set elapsed [expr [clock seconds] - $::progressWin_time]
+  set elapsed [expr {[clock seconds] - $::progressWin_time}]
   set width 401
-  if {$total > 0} { 
-    set width [expr int(double($width) * double($done) / double($total))]
+  if {$total > 0} {
+    set width [expr {int(double($width) * double($done) / double($total))}]
   }
   $w.c coords bar 0 0 $width 21
   set estimated $elapsed
   if {$done != 0} {
-    set estimated [expr int(double($elapsed) * double($total) / double($done))]
+    set estimated [expr {int(double($elapsed) * double($total) / double($done))}]
   }
   set t [format "%d:%02d / %d:%02d" \
-           [expr $elapsed / 60] [expr $elapsed % 60] \
-           [expr $estimated / 60] [expr $estimated % 60]]
+           [expr {$elapsed / 60}] [expr {$elapsed % 60}] \
+           [expr {$estimated / 60}] [expr {$estimated % 60}]]
   $w.c itemconfigure time -text $t
   update
 }
@@ -717,13 +880,13 @@ proc ::pane::grab {win} {
 proc ::pane::drag {win y} {
   set vertical $::pane::_data($win,vertical)
   if {$vertical} {
-    set realY [expr $y-[winfo rooty $win]]
+    set realY [expr {$y-[winfo rooty $win]}]
     set Ymax  [winfo height $win]
   } else {
-    set realY [expr $y-[winfo rootx $win]]
+    set realY [expr {$y-[winfo rootx $win]}]
     set Ymax  [winfo width $win]
   }
-  set frac [expr double($realY)/$Ymax]
+  set frac [expr {double($realY) / $Ymax}]
   if {$frac < $::pane::_data($win,min)} {set frac $::pane::_data($win,min)}
   if {$frac > $::pane::_data($win,max)} {set frac $::pane::_data($win,max)}
 
@@ -753,12 +916,12 @@ proc ::pane::divide {win frac} {
     place $win.pane_sash -rely $frac
     place $win.pane_grip -rely $frac
     place $win.$::pane::_data($win,1) -relheight $frac
-    place $win.$::pane::_data($win,2) -relheight [expr 1-$frac]
+    place $win.$::pane::_data($win,2) -relheight [expr {1.0 - $frac}]
   } else {
     place $win.pane_sash -relx $frac
     place $win.pane_grip -relx $frac
     place $win.$::pane::_data($win,1) -relwidth $frac
-    place $win.$::pane::_data($win,2) -relwidth [expr 1-$frac]
+    place $win.$::pane::_data($win,2) -relwidth [expr {1.0 - $frac}]
   }
 }
 
