@@ -51,6 +51,8 @@ menuText O FileMaintNameRound "Kontroller runde-navn..." 11 \
   {Sammenlign rundenavn med stavekontroll-filen}
 menuText O FileReadOnly "Skrivebeskytt..." 6 \
   {Hindrer endringer p databasen}
+menuText O FileSwitch "Switch to database" 0 \
+  {Switch to a different opened database} ;# ***
 menuText O FileExit "Avslutt" 0 {Avslutt Scid}
 
 # Edit menu:
@@ -67,6 +69,10 @@ menuText O EditStrip "Fjern" 0 {Fjern kommentarer eller variasjoner fra partiet}
 menuText O EditStripComments "Kommentarer" 0 \
   {Fjern alle kommentarer og annotasjoner fra dette partiet}
 menuText O EditStripVars "Variasjoner" 0 {Fjern alle variasjoner fra dette partiet}
+menuText O EditStripBegin "Moves from the beginning" 1 \
+  {Strip moves from the beginning of the game} ;# ***
+menuText O EditStripEnd "Moves to the end" 0 \
+  {Strip moves to the end of the game} ;# ***
 menuText O EditReset "Rensk utklippsbase" 0 \
   {Tmmer utklippsbasen fullstendig}
 menuText O EditCopy "Kopier partiet til utklippsbasen" 0 \
@@ -75,6 +81,8 @@ menuText O EditPaste "Lim inn siste parti fra utklippsbasen" 0 \
   {Limer inn gjeldende parti fra utklippsbasen her}
 menuText O EditSetup "Still opp stilling..." 0 \
   {Lag en startstilling for dette partiet}
+menuText O EditCopyBoard "Copy position" 6 \
+  {Copy the current board in FEN notation to the text selection (clipboard)} ;# ***
 menuText O EditPasteBoard "Lim inn stilling" 0 \
   {Lag en startstilling fra gjeldende utvalg (utklippstavle)}
 
@@ -88,6 +96,7 @@ menuText O GameReload "Hent dette partiet" 0 \
   {Henter dette partiet p nytt og fjerner alle endringer}
 menuText O GameNext "Hent neste parti" 0 {Henter neste parti fra filteret}
 menuText O GameLast "Hent siste parti" 0 {Henter siste parti fra filteret}
+menuText O GameRandom "Hent tilfeldig parti" 8 {Hent tilfeldig parti fra filteret}
 menuText O GameNumber "Hent parti nummer..." 0 \
   {Finn et parti ved  angi nummeret}
 menuText O GameReplace "Lagre: Erstatt parti..." 0 \
@@ -116,6 +125,7 @@ menuText O WindowsComment "Kommentarer" 0 {pne/lukk kommentarvinduet}
 menuText O WindowsGList "Partioversikt" 0 {pne/lukk partioversikten}
 menuText O WindowsPGN "PGN-vindu" 0 \
   {pne/lukk PGN-vinduet}
+menuText O WindowsPList "Player Finder" 2 {Open/close the player finder} ;# ***
 menuText O WindowsTmt "Turneringsker" 0 {pne/lukk turneringsskeren}
 menuText O WindowsSwitcher "Databasebytter" 0 \
   {pne/lukk databasebytteren}
@@ -134,15 +144,20 @@ menuText O WindowsTB "Sluttspilltabellvindu" 0 \
 menuText O Tools "Verkty" 0
 menuText O ToolsAnalysis "Analysemotor..." 0 \
   {Start/stopp en sjakkanalysemotor}
-menuText O ToolsAnalysis2 "Analysismotor #2..." 0 \
+menuText O ToolsAnalysis2 "Analysemotor #2..." 0 \
   {Start/stopp enda en sjakkanalysemotor}
 menuText O ToolsCross "Krysstabell" 0 {Vis turnerigskrystabellen for dette partiet}
 menuText O ToolsEmail "Epostbehandler" 0 \
   {pne/lukk epostbehandlingsvinduet}
+menuText O ToolsFilterGraph "Filtergraf" 7 \
+  {pne/lukk filtergrafvinduet}
 menuText O ToolsOpReport "pningsrapport" 0 \
   {Lager en pningsrapport for denne stillingen}
+menuText O ToolsTracker "Brikkesporing"  0 {pne brikkesporingsvinduet}
 menuText O ToolsPInfo "Spillerinformasjon"  0 \
   {pne/oppdater informasjonsvinduet for denne spilleren}
+menuText O ToolsPlayerReport "Player Report..." 3 \
+  {Generate a player report} ;# ***
 menuText O ToolsRating "Ratinggraf" 0 \
   {Tegner ratingen til disse spillerene over tid}
 menuText O ToolsScore "Poeng-graf" 0 {Viser poeng-grafen}
@@ -169,13 +184,16 @@ menuText O ToolsImportFile "Importer fil med PGN-partier..." 0 \
 
 # Options menu:
 menuText O Options "Innstillinger" 0
-menuText O OptionsSize "Brettstrrelse" 0 {Endre brettstrrelse}
-menuText O OptionsPieces "Brikkeutseende" 6 \
+menuText O OptionsBoard "Chessboard" 0 {Chess board appearance options} ;# ***
+menuText O OptionsBoardSize "Brettstrrelse" 0 {Endre brettstrrelse}
+menuText O OptionsBoardPieces "Brikkeutseende" 6 \
   {Endrer utseendet p brikkene}
-menuText O OptionsColors "Farger..." 0 {Endre farger p brettet}
+menuText O OptionsBoardColors "Farger..." 0 {Endre farger p brettet}
+menuText O OptionsBoardNames "My Player Names..." 0 {Edit my player names} ;# ***
 menuText O OptionsExport "Eksport" 0 {Endre innstillinger for eksport av tekst}
 menuText O OptionsFonts "Skrifttyper" 0 {Endre skrifttyper}
 menuText O OptionsFontsRegular "Vanlig" 0 {Endre den vanlige skrifttypen}
+menuText O OptionsFontsMenu "Menu" 0 {Change the menu font} ;# ***
 menuText O OptionsFontsSmall "Liten" 0 {Endre den lille skrifttypen}
 menuText O OptionsFontsFixed "Fastbredde" 0 {Endre fastbreddeskrifttypen}
 menuText O OptionsGInfo "Partiinformasjon" 0 {Informasjonsinnstillinger}
@@ -183,6 +201,8 @@ menuText O OptionsLanguage "Sprk" 0 {Velg menysprk}
 menuText O OptionsMoves "Trekk" 0 {Innstillinger for hvordan trekk angis}
 menuText O OptionsMovesAsk "Spr fr trekk erstattes" 0 \
   {Spr fr eksisterende trekk erstattes av et nytt}
+menuText O OptionsMovesAnimate "Animation time" 1 \
+  {Set the amount of time used to animate moves} ;# ***
 menuText O OptionsMovesDelay "Autospillforsinkelse..." 0 \
   {Sett forsinkelsen ved automatisk gjennomgang av partiet}
 menuText O OptionsMovesCoord "Koordinater" 0 \
@@ -205,6 +225,8 @@ menuText O OptionsSpell "Hent stavekontrollfil..." 0 \
   {Henter filen med stavekontrollen til Scid}
 menuText O OptionsTable "Tabellbasekatalog..." 0 \
   {Velg en tabellbase; Alle tabellbaser i katalogen vil bli brukt}
+menuText O OptionsRecent "Recent files..." 0 \
+  {Change the number of recent files displayed in the File menu} ;# ***
 menuText O OptionsSave "Lagre innstillinger" 0 \
   "Lagre alle instillinger til $::optionsFile"
 menuText O OptionsAutoSave "Autolagre innstillinger ved avslutning" 0 \
@@ -212,6 +234,7 @@ menuText O OptionsAutoSave "Autolagre innstillinger ved avslutning" 0 \
 
 # Help menu:
 menuText O Help "Hjelp" 0
+menuText O HelpContents "Contents" 0 {Show the help contents page} ;# ***
 menuText O HelpIndex "Innhold" 0 {Hjelpesystemets innhold}
 menuText O HelpGuide "Lynguide" 0 {Vis lynguiden}
 menuText O HelpHints "Hint" 0 {Vis hint}
@@ -227,6 +250,7 @@ menuText O GInfoFEN "Vis FEN" 0
 menuText O GInfoMarks "Vis fargede ruter og piler" 0
 menuText O GInfoWrap "Tekstbryting" 0
 menuText O GInfoFullComment "Vis full kommentar" 0
+menuText O GInfoPhotos "Show Photos" 5 ;# ***
 menuText O GInfoTBNothing "Tabellbaser: ingenting" 0
 menuText O GInfoTBResult "Tabellbaser: kun resultater" 0
 menuText O GInfoTBAll "Tabellbaser: resultater og beste trekk" 0
@@ -242,13 +266,16 @@ helpMsg O .button.intoVar {G inn i en variasjon (snarvei: v)}
 helpMsg O .button.exitVar {Forlat variasjon (snarvei: z)}
 helpMsg O .button.flip {Roter brett (snarvei: .)}
 helpMsg O .button.coords {Sl av/p brettkoordinater (snarvei: 0)}
+helpMsg O .button.stm {Turn the side-to-move icon on or off} ;# ***
 helpMsg O .button.autoplay {Automatisk spill (tast: Ctrl+Z)}
 
 # General buttons:
 translate O Back {Tilbake}
+translate O Browse {Browse} ;# ***
 translate O Cancel {Avbryt}
 translate O Clear {Slett}
 translate O Close {Lukk}
+translate O Contents {Contents} ;# ***
 translate O Defaults {Standard}
 translate O Delete {Slett}
 translate O Graph {Graf}
@@ -291,12 +318,14 @@ translate O Black {Sort}
 translate O Player {Spiller}
 translate O Rating {Rating}
 translate O RatingDiff {Ratingforskjell (Hvit - Sort)}
+translate O AverageRating {Average Rating} ;# ***
 translate O Event {Anledning}
 translate O Site {Sted}
 translate O Country {Land}
 translate O IgnoreColors {Overse farger}
 translate O Date {Dato}
 translate O EventDate {Anledningsdato}
+translate O Decade {Decade} ;# ***
 translate O Year {r}
 translate O Month {Mned}
 translate O Months {Januar Februar Mars April Mai Juni Juli August September Oktober November Desember}
@@ -320,6 +349,11 @@ translate O score {poeng}
 translate O StartPos {Utgangsstilling}
 translate O Total {Sammenlagt}
 
+# Standard error messages:
+translate O ErrNotOpen {This is not an open database.} ;# ***
+translate O ErrReadOnly {This database is read-only; it cannot be altered.}
+translate O ErrSearchInterrupted {Search was interrupted; results are incomplete.}
+
 # Game information:
 translate O twin {duplikat}
 translate O deleted {slettet}
@@ -340,6 +374,7 @@ translate O PInfoMostWhite {Hyppigste pning som hvit}
 translate O PInfoMostBlack {Hyppigste pning som sort}
 translate O PInfoRating {Historisk rating}
 translate O PInfoBio {Biografi}
+translate O PInfoEditRatings {Edit Ratings} ;# ***
 
 # Tablebase information:
 translate O Draw {Uavgjort}
@@ -354,6 +389,10 @@ translate O allOthersLose {alle andre taper}
 translate O matesIn {setter matt i}
 translate O hasCheckmated {har satt matt}
 translate O longest {lengste}
+translate O WinningMoves {Winning moves} ;# ***
+translate O DrawingMoves {Drawing moves} ;# ***
+translate O LosingMoves {Losing moves} ;# ***
+translate O UnknownMoves {Unknown-result moves} ;# ***
 
 # Tip of the day:
 translate O Tip {Tips}
@@ -388,6 +427,10 @@ translate O LockTree {Ls}
 translate O TreeLocked {lst}
 translate O TreeBest {Beste}
 translate O TreeBestGames {Idealtrepartier}
+# Note: the next message is the tree window title row. After editing it,
+# check the tree window to make sure it lines up with the actual columns.
+translate O TreeTitleRow \
+  {    Move   ECO       Frequency    Score  AvElo Perf AvYear %Draws} ;# ***
 
 # Finder window:
 menuText O FinderFile "Fil" 0
@@ -414,6 +457,17 @@ translate O FinderDirs {Kataloger}
 translate O FinderFiles {Filer}
 translate O FinderUpDir {opp}
 
+# Player finder:
+menuText O PListFile "Fil" 0
+menuText O PListFileUpdate "Oppdater" 0
+menuText O PListFileClose "Close Player Finder" 0 ;# ***
+menuText O PListSort "Sorter" 0
+menuText O PListSortName "Name" 0 ;# ***
+menuText O PListSortElo "Elo" 0
+menuText O PListSortGames "Partier" 0
+menuText O PListSortOldest "Oldest" 0 ;# ***
+menuText O PListSortNewest "Newest" 0 ;# ***
+
 # Tournament finder:
 menuText O TmtFile "Fil" 0
 menuText O TmtFileUpdate "Oppdater" 0
@@ -440,6 +494,7 @@ menuText O GraphOptionsWhite "Hvit" 0
 menuText O GraphOptionsBlack "Sort" 0
 menuText O GraphOptionsBoth "Begge" 0
 menuText O GraphOptionsPInfo "Spiller Info spiller" 0
+translate O GraphFilterTitle "Filtergraf: hyppighet per 1000 partier"
 
 # Analysis window:
 translate O AddVariation {Legg til variasjon}
@@ -453,6 +508,7 @@ translate O AnnotateAll {For trekk av begge sider}
 translate O AnnotateWhite {Kun for hvite trekk}
 translate O AnnotateBlack {Kun for sorte trekk}
 translate O AnnotateNotBest {Nr trekket avviker fra beste linje}
+translate O LowPriority {Low CPU priority} ;# ***
 
 # Analysis Engine open dialog:
 translate O EngineList {Liste over analysemotorer}
@@ -474,6 +530,7 @@ menuText O StatsOpt "Innstillinger" 0
 
 # PGN window menus:
 menuText O PgnFile "Fil" 0
+menuText O PgnFileCopy "Copy Game to Clipboard" 0 ;# ***
 menuText O PgnFilePrint "Skriv til fil..." 0
 menuText O PgnFileClose "Lukk PGN-vindu" 0
 menuText O PgnOpt "Vis" 0
@@ -484,6 +541,7 @@ menuText O PgnOptIndentC "Rykk inn kommentarer" 0
 menuText O PgnOptIndentV "Rykk inn variasjoner" 0
 menuText O PgnOptColumn "Bruk kolonner (ett trekk per linje)" 0
 menuText O PgnOptSpace "Mellomrom etter trekknummer" 0
+menuText O PgnOptStripMarks "Fjern fargekoder" 0
 menuText O PgnColor "Farger" 0
 menuText O PgnColorHeader "Header..." 0
 menuText O PgnColorAnno "Annotasjoner..." 0
@@ -514,7 +572,9 @@ menuText O CrosstabOptNats "Nasjonaliteter" 0
 menuText O CrosstabOptRatings "Ratinger" 0
 menuText O CrosstabOptTitles "Titler" 0
 menuText O CrosstabOptBreaks "Poengfordel" 0
+menuText O CrosstabOptDeleted "Include deleted games" 8 ;# ***
 menuText O CrosstabOptColors "Farger (kun sveitsisk)" 0
+menuText O CrosstabOptColumnNumbers "Nummererte kolonner (kun alle-mot-alle-tabeller)" 0
 menuText O CrosstabOptGroup "Gruppepoeng" 0
 menuText O CrosstabSort "Sorter" 0
 menuText O CrosstabSortName "Navn" 0
@@ -529,6 +589,7 @@ menuText O CrosstabHelpIndex "Innholdsfortegnelse" 0
 translate O SetFilter {Sett filter}
 translate O AddToFilter {Legg til i filter}
 translate O Swiss {Sveitsisk}
+translate O Category {Category} ;# ***
 
 # Opening report window menus:
 menuText O OprepFile "Fil" 0
@@ -537,6 +598,10 @@ menuText O OprepFileHtml "Skriv til HTML-fil..." 0
 menuText O OprepFileLaTeX "Skriv til LaTeX-fil..." 0
 menuText O OprepFileOptions "Innstillinger..." 0
 menuText O OprepFileClose "Lukk rapport-vindu" 0
+menuText O OprepFavorites "Favorites" 1 ;# ***
+menuText O OprepFavoritesAdd "Add Report..." 0 ;# ***
+menuText O OprepFavoritesEdit "Edit Report Favorites..." 0 ;# ***
+menuText O OprepFavoritesGenerate "Generate Reports..." 0 ;# ***
 menuText O OprepHelp "Hjelp" 0
 menuText O OprepHelpReport "pningsrapport hjelp" 0
 menuText O OprepHelpIndex "Innholdsfortegnelse" 0
@@ -637,6 +702,7 @@ translate O NumDeletedGames {Slettede partier:}
 translate O NumFilterGames {Partier i filter:}
 translate O YearRange {Til/fra r:}
 translate O RatingRange {Til/fra rating:}
+translate O Description {Description} ;# ***
 translate O Flag {Flagg}
 translate O DeleteCurrent {Slett gjeldende parti}
 translate O DeleteFilter {Slett filtrerte partier}
@@ -662,6 +728,8 @@ translate O CompactDatabase {Komprimer database}
 translate O SortDatabase {Sorter database}
 translate O AddEloRatings {Legg til ELO-ratinger}
 translate O AutoloadGame {Start med parti nummer}
+translate O StripTags {Fjern PGN-merker}
+translate O StripTag {Fjern merke}
 translate O Cleaner {Opprydding}
 translate O CleanerHelp {
 Scid-opprydding vil utfre alle handlinger du velger fra listen under p gjeldende database.
@@ -679,6 +747,7 @@ Er du sikker p at du vil starte vedlikeholdsfunksjonene du har valgt?
 # Comment editor:
 translate O AnnotationSymbols  {Notasjonssymboler:}
 translate O Comment {Kommentar:}
+translate O InsertMark {Insert mark} ;# ***
 
 # Board search:
 translate O BoardSearch {Stillingsk}
@@ -721,7 +790,7 @@ translate O InitialBoard {Utgangsstilling}
 translate O SideToMove {Side i trekk}
 translate O MoveNumber {Trekk nummer}
 translate O Castling {Rokkade}
-translate O EnPassentFile {En Passent-kolonne}
+translate O EnPassantFile {En Passant-kolonne}
 translate O ClearFen {Slett FEN}
 translate O PasteFen {Lim inn FEN}
 
@@ -749,6 +818,7 @@ Vil du virkelig forkaste endringene som er gjort?
 
 # Exit dialog:
 translate O ExitDialog {Vil du virkelig avslutte Scid?}
+translate O ExitUnsaved {Flgende baser har ulagrede endringer i partier. Hvis du avslutter n vil disse endringene g tapt.}
 
 # Import window:
 translate O PasteCurrentGame {Lim inn gjeldende parti}
@@ -782,6 +852,7 @@ translate O OprepUp {opp %u%s fra alle r}
 translate O OprepDown {ned %u%s fra alle r}
 translate O OprepSame {ingen endring fra alle r}
 translate O OprepMostFrequent {Hyppigste spillere}
+translate O OprepMostFrequentOpponents {Most frequent opponents} ;# ***
 translate O OprepRatingsPerf {Ratinger og resultater}
 translate O OprepAvgPerf {Middelratinger og -resultater}
 translate O OprepWRating {Hvit rating}
@@ -807,14 +878,16 @@ translate O OprepMoveOrdersAll \
 translate O OprepMoveOrdersMany \
   {There were %u move orders reaching this position. The top %u are:}
 translate O OprepMovesFrom {Trekk fra rapportert stilling}
+translate O OprepMostFrequentEcoCodes {Most frequent ECO codes} ;# ***
 translate O OprepThemes {Stillingstemaer}
-translate O OprepThemeDescription {Hyppighet av tema i trekk %u}
+translate O OprepThemeDescription {Frequency of themes in the first %u moves of each game} ;# ***
 translate O OprepThemeSameCastling {Rokkade til samme side}
 translate O OprepThemeOppCastling {Rokkade til motsatt side}
 translate O OprepThemeNoCastling {Ingen konger rokert}
 translate O OprepThemeKPawnStorm {Bondestorm p kongesiden}
 translate O OprepThemeQueenswap {Byttede dronninger}
-translate O OprepThemeIQP {Isolert dronningbonde}
+translate O OprepThemeWIQP {White Isolated Queen Pawn} ;# ***
+translate O OprepThemeBIQP {Black Isolated Queen Pawn} ;# ***
 translate O OprepThemeWP567 {Hvit bonde p rekke 5/6/7}
 translate O OprepThemeBP234 {Sort bonde p rekke 2/3/4}
 translate O OprepThemeOpenCDE {pen c/d/e-kolonne}
@@ -827,6 +900,27 @@ translate O OprepTheoryTable {Teoritabell}
 translate O OprepTableComment {Generert fra de %u hyest ratede partiene.}
 translate O OprepExtraMoves {Ytterligere trekk notert i teoritabellen}
 translate O OprepMaxGames {Maksimalt antall partier i teoritabellen}
+translate O OprepViewHTML {View HTML} ;# ***
+translate O OprepViewLaTeX {View LaTeX} ;# ***
+
+# Player Report:
+translate O PReportTitle {Player Report} ;# ***
+translate O PReportColorWhite {with the White pieces} ;# ***
+translate O PReportColorBlack {with the Black pieces} ;# ***
+translate O PReportMoves {after %s} ;# ***
+translate O PReportOpenings {Openings} ;# ***
+translate O PReportClipbase {Empty clipbase and copy matching games to it} ;# ***
+
+# Piece Tracker window:
+translate O TrackerSelectSingle {Venstre museknapp merker denne brikken}
+translate O TrackerSelectPair {Venstre museknapp merker denne brikken; hyre merker alle brikker av denne typen.}
+translate O TrackerSelectPawn {Venstre museknapp merker denne brikken; hyre merker alle brikker av denne typen.}
+translate O TrackerStat {Statistikk}
+translate O TrackerGames {% partier med trekk til felt}
+translate O TrackerTime {% tid p hvert felt}
+translate O TrackerMoves {Trekk}
+translate O TrackerMovesStart {Oppgi trekket hvor sporingen skal begynne.}
+translate O TrackerMovesStop {Oppgi trekket hvor sporingen skal stoppe.}
 
 # Game selection dialogs:
 translate O SelectAllGames {Alle partier i databasen}
@@ -857,6 +951,10 @@ translate O TwinsUndelete {Gjenopprett alle partier frst?}
 translate O TwinsSetFilter {Sett filter til alle slettede duplikatpartier?}
 translate O TwinsComments {Behold alltid partier med kommentarer?}
 translate O TwinsVars {Behold alltid partier med variasjoner?}
+translate O TwinsDeleteWhich {Slett hvilket parti:}
+translate O TwinsDeleteShorter {Korteste parti}
+translate O TwinsDeleteOlder {Laveste partinummer}
+translate O TwinsDeleteNewer {Hyeste partinummer}
 translate O TwinsDelete {Slett partier}
 
 # Name editor window:
@@ -903,6 +1001,7 @@ translate O IndentComments {Rykk inn kommentarer}
 translate O IndentVariations {Rykk inn variasjoner}
 translate O ExportColumnStyle {Bruk kolonner (ett trekk per linje)}
 translate O ExportSymbolStyle {Symbolnotasjoner}
+translate O ExportStripMarks {Fjern alle fargekoder og piler fra kommentarer?}
 
 # Goto game/move dialogs:
 translate O LoadGameNumber {Angi partinummer som skal lastes inn:}
@@ -956,8 +1055,18 @@ Dette kan ta en stund, men det trenger kun  gjres en gang. Du kan avbryte om det
 nsker du  oppgradere databasen n?
 }
 
-}
+# Recent files options:
+translate O RecentFilesMenu {Number of recent files in File menu} ;# ***
+translate O RecentFilesExtra {Number of recent files in extra submenu} ;# ***
 
+# My Player Names options:
+translate O MyPlayerNamesDescription {
+Enter a list of preferred player names below, one name per line. Wildcards (e.g. "?" for any single character, "*" for any sequence of characters) are permitted.
+
+Every time a game with a player in the list is loaded, the main window chessboard will be rotated if necessary to show the game from that players perspective.
+} ;# ***
+
+}
 
 # norsk.tcl
 
