@@ -8,7 +8,7 @@ proc setLanguage_P {} {
 menuText P File "Plik" 0
 menuText P FileNew "Nowy..." 0 {Twrz nowa baz Scid}
 menuText P FileOpen "Otwrz..." 0 {Otwrz istniejc baz Scid}
-menuText P FileClose "Zamknij" 0 {Zamknij aktywna baz Scid}
+menuText P FileClose "Zamknij" 0 {Zamknij aktywn baz Scid}
 menuText P FileFinder "Poszukiwacz plikw" 0 {Otwrz okno poszukiwacza plikw}
 menuText P FileBookmarks "Zakadki" 2 {Menu zakadek (klawisz: Ctrl+B)}
 menuText P FileBookmarksAdd "Dodaj zakadk" 0 \
@@ -48,6 +48,8 @@ menuText P FileMaintNameRound "Sprawd numery rund..." 15 \
   {Sprawd numery rund przy pomocy pliku}
 menuText P FileReadOnly "Tylko do odczytu..." 0 \
   {Zabezpiecz baz przed zapisem}
+menuText P FileSwitch "Przecz baz" 1 \
+  {Przecz na inn otwart baz} 
 menuText P FileExit "Koniec" 0 {Zamknij Scida}
 
 menuText P Edit "Edytuj" 0
@@ -65,6 +67,10 @@ menuText P EditStripComments "Komentarze" 0 \
   {Usu wszystkie komentarze z aktualnej partii}
 menuText P EditStripVars "Warianty" 0 \
   {Usu wszystkie warianty z aktualnej partii}
+menuText P EditStripBegin "Poprzednie posunicia" 0 \
+  {Usu wszystkie posunicia do biecej pozycji}
+menuText P EditStripEnd "Nastpne posunicia" 0 \
+  {Usu wszystkie posunicia od biecej pozycji do koca partii}
 menuText P EditReset "Oprnij schowek" 0 \
   {Oprnij schowek bazy}
 menuText P EditCopy "Kopiuj parti do schowka" 0 \
@@ -73,22 +79,25 @@ menuText P EditPaste "Wklej aktywn parti ze schowka" 0 \
   {Wklej aktywn parti ze schowka}
 menuText P EditSetup "Ustaw pozycj pocztkow..." 6 \
   {Ustaw pozycj pocztkow partii}
+menuText P EditCopyBoard "Kopiuj pozycj" 7 \
+  {Kopiuj aktualn pozycj w notacji FEN do schowka}
 menuText P EditPasteBoard "Ustaw pozycj ze schowka" 3 \
   {Ustaw pozycj ze schowka}
 
 menuText P Game "Partia" 1
 menuText P GameNew "Opu parti" 0 \
   {Opu parti, rezygnujc z wszelkich zmian}
-menuText P GameFirst "Pierwsza partia" 2 {Zaaduj pierwsz parti z filtra}
+menuText P GameFirst "Pierwsza partia" 2 {Wczytaj pierwsz parti z filtra}
 menuText P GamePrev "Poka poprzedni parti" 0 \
-  {Poka poprzedni wyszukan parti}
+  {Wczytaj poprzedni wyszukan parti}
 menuText P GameReload "Przeaduj aktualn parti"  10 \
-  {Przeaduj parti, rezygnujc z wszelkich zmian}
-menuText P GameNext "Zaaduj nastpn parti" 0 \
-  {Zaaduj nastpn wyszukan parti}
-menuText P GameLast "Ostatnia partia" 2 {Zaaduj ostatni parti z filtra}
-menuText P GameNumber "Zaaduj parti numer..." 17 \
-  {Zaaduj parti wprowadzajc jej numer}
+  {Wczytaj parti ponownie, rezygnujc z wszelkich zmian}
+menuText P GameNext "Nastpna partia" 0 \
+  {Wczytaj nastpn wyszukan parti}
+menuText P GameLast "Ostatnia partia" 5 {Wczytaj ostatni parti z filtra}
+menuText P GameRandom "Losowa partia z filtra" 8 {Wczytaj losow parti z filtra}
+menuText P GameNumber "Wczytaj parti numer..." 17 \
+  {Wczytaj parti wprowadzajc jej numer}
 menuText P GameReplace "Zapisz: zastp parti..." 3 \
   {Zapisz parti, zastp poprzedni wersj}
 menuText P GameAdd "Zapisz: dodaj now parti..." 8 \
@@ -119,6 +128,7 @@ menuText P WindowsComment "Edytor komentarzy" 0 \
   {Otwrz/zamknij edytor komentarzy}
 menuText P WindowsGList "Lista partii" 0 {Otwrz/zamknij list partii}
 menuText P WindowsPGN "Okno PGN" 0 {Otwrz/zamknij (zapis partii) PGN }
+menuText P WindowsPList "Zawodnicy" 2 {Otwrz/zamknij przegldark zawodnikw}
 menuText P WindowsTmt "Turnieje" 0 {Otwrz/zamknij przegldark turniejw}
 menuText P WindowsSwitcher "Przecznik baz" 12 \
   {Otwrz/zamknij przecznik baz}
@@ -137,16 +147,21 @@ menuText P WindowsTB "Tablica kocwek" 8 \
 menuText P Tools "Narzdzia" 0
 menuText P ToolsAnalysis "Program analizujcy..." 8 \
   {Uruchom/zatrzymaj program analizujcy}
-menuText P ToolsAnalysis2 "Program analizujcy #2..." 21 \
+menuText P ToolsAnalysis2 "Program analizujcy 2..." 21 \
   {Uruchom/zatrzymaj program analizujcy}
 menuText P ToolsCross "Tabela turniejowa" 0 \
   {Poka tabel turniejow dla aktualnej partii}
 menuText P ToolsEmail "Zarzdzanie poczt e-mail" 0 \
   {Otwrz/zamknij zarzdzanie adresami e-mail}
+menuText P ToolsFilterGraph "Wykres filtra" 7 \
+  {Otwrz/zamknij wykres filtra}
 menuText P ToolsOpReport "Raport debiutowy" 0 \
   {Utwrz raport debiutowy dla aktualnej pozycji}
+menuText P ToolsTracker "ledzenie figur"  10 {Otwrz/zamknij okno ledzenia figur} 
 menuText P ToolsPInfo "Informacje o zawodniku"  0 \
   {Otwrz/odwie okno informacji o zawodniku}
+menuText P ToolsPlayerReport "Raport o graczu..." 9 \
+  {Utwrz raport o graczu} 
 menuText P ToolsRating "Wykres rankingu" 0 \
   {Wykres historii rankingu grajcych parti}
 menuText P ToolsScore "Wykres wynikw" 1 {Poka wykres wynikw}
@@ -166,19 +181,22 @@ menuText P ToolsExpFilterHTML "Do pliku HTML..." 9 \
   {Zapisz wyszukane partie do pliku HTML}
 menuText P ToolsExpFilterLaTeX "Do pliku LaTeX..." 9 \
   {Zapisz wyszukane partie do pliku LaTeX}
-menuText P ToolsImportOne "Pobierz parti z pliku PGN..." 0 \
+menuText P ToolsImportOne "Wklej parti w formacie PGN..." 0 \
   {Pobierz parti z pliku PGN}
-menuText P ToolsImportFile "Pobierz plik PGN..." 2 \
+menuText P ToolsImportFile "Importuj plik PGN..." 2 \
   {Pobierz partie z pliku PGN}
 
 menuText P Options "Opcje" 0
-menuText P OptionsSize "Wielko szachownicy" 0 {Zmie wielko szachownicy}
-menuText P OptionsPieces "Typ figur" 4 \
+menuText P OptionsBoard "Szachownica" 0 {Konfiguracja wygldu szachownicy}
+menuText P OptionsBoardSize "Wielko" 0 {Zmie wielko szachownicy}
+menuText P OptionsBoardPieces "Typ figur" 4 \
   {Zmienia typ wyswietlanych figur} 
-menuText P OptionsColors "Kolory..." 0 {Zmie kolory szachownicy}
+menuText P OptionsBoardColors "Kolory..." 0 {Zmie kolory szachownicy}
+menuText P OptionsBoardNames "Moje nazwiska" 0 {Modyfikuj list moich graczy}
 menuText P OptionsExport "Eksport" 0 {Zmie opcje eksportu tekstu}
 menuText P OptionsFonts "Czcionka" 0 {Zmie font}
 menuText P OptionsFontsRegular "Podstawowa" 0 {Zmie podstawow czcionk}
+menuText P OptionsFontsMenu "Menu" 0 {Zmie czcionk menu} 
 menuText P OptionsFontsSmall "Maa" 0 {Zmie ma czcionk}
 menuText P OptionsFontsFixed "Staa" 0 {Zmie czcionk staej szerokoci}
 menuText P OptionsGInfo "Informacje o partii" 0 {Sposb wywietlania informacji o partii}
@@ -186,6 +204,8 @@ menuText P OptionsLanguage "Jzyk" 0 {Wybierz jzyk}
 menuText P OptionsMoves "Posunicia" 0 {Wprowadzanie posuni}
 menuText P OptionsMovesAsk "Zapytaj przed zastpieniem posuni" 0 \
   {Zapytaj przed zastpieniem aktualnych posuni}
+menuText P OptionsMovesAnimate "Szybko animacji" 1 \
+  {Ustaw czas przeznaczony na animacj jednego posunicia} 
 menuText P OptionsMovesDelay "Automatyczne przegldanie..." 0 \
   {Ustaw opnienie przy automatycznym przegldaniu partii}
 menuText P OptionsMovesCoord "Posunicia w formacie \"g1f3\"" 0 \
@@ -203,19 +223,22 @@ menuText P OptionsWindowsRaise "Automatyczne uaktywnianie" 0 \
   {Automatycznie uaktywniaj niektre okna (np. pasek postpu), gdy s zasonite}
 menuText P OptionsToolbar "Pasek narzdziowy" 6 \
   {Schowaj/poka pasek narzdziowy}
-menuText P OptionsECO "Zaaduj ksik debiutow..." 16 \
-  {Zaaduj plik z klasyfikacja debiutw}
-menuText P OptionsSpell "Zaaduj plik sprawdzania pisowni..." 13 \
-  {Zaaduj plik do sprawdzania pisowni nazwisk i nazw}
+menuText P OptionsECO "Wczytaj ksik debiutow..." 16 \
+  {Wczytaj plik z klasyfikacja debiutw}
+menuText P OptionsSpell "Wczytaj plik sprawdzania pisowni..." 13 \
+  {Wczytaj plik do sprawdzania pisowni nazwisk i nazw}
 menuText P OptionsTable "Katalog z baz kocwek..." 10 \
   {Wybierz baz kocwek; uyte zostan wszystkie bazy z tego katalogu}
+menuText P OptionsRecent "Ostatnie pliki..." 0 \
+  {Zmie liczb ostatnio otwartych plikw, wywietlanych w menu Plik} 
 menuText P OptionsSave "Zapamitaj opcje" 0 \
   "Zapamitaj wszystkie ustawienia w pliku $::optionsFile"
 menuText P OptionsAutoSave "Automatycznie zapisuj opcje" 0 \
   {Automatycznie zapisz opcje przy zamykaniu programu}
 
 menuText P Help "Pomoc" 2
-menuText P HelpIndex "Spis treci" 0 {Poka spis treci pomocy}
+menuText P HelpContents "Contents" 0 {Poka spis treci pomocy} 
+menuText P HelpIndex "Spis treci" 0 {Poka indeks pomocy}
 menuText P HelpGuide "Krtki przewodnik" 0 {Poka krtki przewodnik}
 menuText P HelpHints "Podpowiedzi" 0 {Poka podpowiedzi}
 menuText P HelpContact "Informacja o autorze" 0 \
@@ -231,6 +254,7 @@ menuText P GInfoFEN "Poka pozycj w formacie FEN" 16
 menuText P GInfoMarks "Pokazuj kolorowe pola i strzaki" 5 
 menuText P GInfoWrap "Zawijaj dugie linie" 0
 menuText P GInfoFullComment "Poka cay komentarz" 6
+menuText P GInfoPhotos "Poka zdjcia" 5
 menuText P GInfoTBNothing "Tablica kocwek: nic" 0
 menuText P GInfoTBResult "Tablica kocwek: tylko wynik" 18
 menuText P GInfoTBAll "Tablica kocwek: wszystko" 18
@@ -245,15 +269,18 @@ helpMsg P .button.forward {Jedno posunicie do przodu (klawisz: strzaka w prawo)}
 helpMsg P .button.intoVar {Wejd w wariant (klawisz skrtu: v)}
 helpMsg P .button.exitVar {Opu wariant (klawisz skrtu: z)}
 helpMsg P .button.flip {Obr szachownic  (klawisz skrtu: .)}
-helpMsg P .button.coords {Wcz lub wycz opis szachownicy  (klawisz skrtu: 0)}
+helpMsg P .button.coords {Przecz wywietlanie opisu szachownicy  (klawisz skrtu: 0)}
+helpMsg P .button.stm {Przecz wywietlanie ikony koloru strony na posuniciu} 
 helpMsg P .button.autoplay \
   {Automatyczne przestawianie bierek (klawisz skrtu: Ctrl+Z)}
 
 # General buttons:
 translate P Back {Z powrotem}
+translate P Browse {Przegldaj}
 translate P Cancel {Anuluj}
 translate P Clear {Wyczy}
 translate P Close {Zamknij}
+translate P Contents {Spis treci}
 translate P Defaults {Domylne}
 translate P Delete {Usu}
 translate P Graph {Wykres}
@@ -296,12 +323,14 @@ translate P Black {Czarne}
 translate P Player {Gracz}
 translate P Rating {Ranking}
 translate P RatingDiff {Rnica rankingw}
+translate P AverageRating {redni ranking}
 translate P Event {Turniej}
 translate P Site {Miejsce}
 translate P Country {Kraj}
 translate P IgnoreColors {Ignoruj kolory}
 translate P Date {Data}
 translate P EventDate {Turniej data}
+translate P Decade {Dekada} 
 translate P Year {Rok}
 translate P Month {Miesic}
 translate P Months {Stycze Luty Marzec Kwiecie Maj Czerwiec
@@ -326,6 +355,11 @@ translate P score {punkty}
 translate P StartPos {Pozycja pocztkowa}
 translate P Total {Razem}
 
+# Standard error messages:
+translate P ErrNotOpen {To nie jest otwarta baza.} 
+translate P ErrReadOnly {Ta baza jest tylko do odczytu; nie mona jej zmieni.}
+translate P ErrSearchInterrupted {Wyszukiwanie zostao przerwane. Wyniki bd niepene.}
+
 # Game information:
 translate P twin {powtrzona}
 translate P deleted {usunita}
@@ -346,6 +380,7 @@ translate P PInfoMostWhite {Najczstsze debiuty biaymi}
 translate P PInfoMostBlack {Najczstsze debiuty czarnymi}
 translate P PInfoRating {Historia rankingu}
 translate P PInfoBio {Biografia}
+translate P PInfoEditRatings {Modyfikuj rankingi} 
 
 # Tablebase information:
 translate P Draw {remis}
@@ -360,6 +395,10 @@ translate P allOthersLose {inne posunicia przegrywaj}
 translate P matesIn {matuj w}
 translate P hasCheckmated {matuj}
 translate P longest {najlepsze}
+translate P WinningMoves {Wygrywajce posunicia}
+translate P DrawingMoves {Remisujce posunicia} 
+translate P LosingMoves {Przegrywajce posunicia} 
+translate P UnknownMoves {Posunicia o nieznanej ocenie} 
 
 # Tip of the day:
 translate P Tip {Porada}
@@ -393,6 +432,11 @@ translate P LockTree {Blokada}
 translate P TreeLocked {zablokowane}
 translate P TreeBest {Najlepsze}
 translate P TreeBestGames {Najlepsze partie}
+# Note: the next message is the tree window title row. After editing it,
+# check the tree window to make sure it lines up with the actual columns.
+translate P TreeTitleRow \
+  {    Pos.   ECO       Czsto     Wynik  Rav   Rperf Rok   %Remis}
+# {    Move   ECO       Frequency    Score  AvElo Perf AvYear %Draws}
 
 # Finder window:
 menuText P FinderFile "Plik" 0
@@ -419,6 +463,17 @@ translate P FinderDirs {Katalogi}
 translate P FinderFiles {Pliki}
 translate P FinderUpDir {wyej}
 
+# Player finder:
+menuText P PListFile "Plik" 0
+menuText P PListFileUpdate "Uaktualnij" 0
+menuText P PListFileClose "Zamknij przegldark zawodnikw" 0
+menuText P PListSort "Sortowanie" 0
+menuText P PListSortName "Nazwisko" 0
+menuText P PListSortElo "Elo" 0
+menuText P PListSortGames "Partie" 0
+menuText P PListSortOldest "Najstarsza" 0
+menuText P PListSortNewest "Najnowsza" 0
+
 # Tournament finder:
 menuText P TmtFile "Plik" 0
 menuText P TmtFileUpdate "Uaktualnij" 0
@@ -431,7 +486,7 @@ menuText P TmtSortElo "Elo" 0
 menuText P TmtSortSite "Miejsce" 0
 menuText P TmtSortEvent "Turniej" 0
 menuText P TmtSortWinner "Zwycizca" 0
-translate P TmtLimit "Max. turniejw"
+translate P TmtLimit "Wielko listy"
 translate P TmtMeanElo "Min. rednie ELO"
 translate P TmtNone "Nie znaleziono turniejw."
 
@@ -445,6 +500,7 @@ menuText P GraphOptionsWhite "Biae" 0
 menuText P GraphOptionsBlack "Czarne" 0
 menuText P GraphOptionsBoth "Oba kolory" 1
 menuText P GraphOptionsPInfo "Gracz z Informacji o graczu" 0
+translate P GraphFilterTitle "Filtr: czsto na 1000 partii" 
 
 # Analysis window:
 translate P AddVariation {Dodaj wariant}
@@ -458,6 +514,7 @@ translate P AnnotateAll {Dla obu stron}
 translate P AnnotateWhite {Dla biaych}
 translate P AnnotateBlack {Dla czarnych}
 translate P AnnotateNotBest {Tylko dla posuni lepszych ni w partii}
+translate P LowPriority {Niski priorytet CPU} 
 
 # Analysis Engine open dialog:
 translate P EngineList {Programy szachowe}
@@ -479,6 +536,7 @@ menuText P StatsOpt "Opcje" 0
 
 # PGN window menus:
 menuText P PgnFile "Plik" 0
+menuText P PgnFileCopy "Kopiuj parti do schowka" 0
 menuText P PgnFilePrint "Zapisz do pliku..." 7
 menuText P PgnFileClose "Zamknij" 0
 menuText P PgnOpt "Wygld" 0
@@ -489,9 +547,10 @@ menuText P PgnOptIndentC "Wcinaj komentarze" 7
 menuText P PgnOptIndentV "Wcinaj warianty" 7
 menuText P PgnOptColumn "Kolumny (jedno posunicie w wierszu)" 0
 menuText P PgnOptSpace "Spacja po numerze ruchu" 0
+menuText P PgnOptStripMarks "Usu kody kolorowych pl i strzaek" 0
 menuText P PgnColor "Kolory" 0
 menuText P PgnColorHeader "Nagwek..." 0
-menuText P PgnColorAnno "Uwagi..." 0
+menuText P PgnColorAnno "Uwagi..." 3
 menuText P PgnColorComments "Komentarze..." 0
 menuText P PgnColorVars "Warianty..." 0
 menuText P PgnColorBackground "To..." 0
@@ -519,7 +578,9 @@ menuText P CrosstabOptNats "Narodowo" 0
 menuText P CrosstabOptRatings "Ranking" 0
 menuText P CrosstabOptTitles "Tytu" 0
 menuText P CrosstabOptBreaks "Punkty pomocnicze" 1
+menuText P CrosstabOptDeleted "Uwzgldniaj usunite partie" 0
 menuText P CrosstabOptColors "Kolory (tylko szwajcar)" 0
+menuText P CrosstabOptColumnNumbers "Numerowane kolumny (tylko turniej koowy)" 0
 menuText P CrosstabOptGroup "Grupuj po liczbie punktw" 0
 menuText P CrosstabSort "Sortowanie" 0
 menuText P CrosstabSortName "Nazwisko" 0
@@ -534,6 +595,7 @@ menuText P CrosstabHelpIndex "Spis treci" 0
 translate P SetFilter {Ustaw filtr}
 translate P AddToFilter {Dodaj do filtra}
 translate P Swiss {Szwajcar}
+translate P Category {Kategoria} 
 
 # Opening report window menus:
 menuText P OprepFile "Plik" 0
@@ -542,6 +604,10 @@ menuText P OprepFileHtml "Zapisz w pliku HTML..." 15
 menuText P OprepFileLaTeX "Zapisz w pliku LaTeX-a..." 15
 menuText P OprepFileOptions "Opcje" 2
 menuText P OprepFileClose "Zamknij okno raportu" 0
+menuText P OprepFavorites "Ulubione" 1 
+menuText P OprepFavoritesAdd "Dodaj raport..." 0 
+menuText P OprepFavoritesEdit "Modyfikuj ulubione..." 0
+menuText P OprepFavoritesGenerate "Twrz raporty..." 0 
 menuText P OprepHelp "Pomoc" 2
 menuText P OprepHelpReport "Pomoc raportu debiutowego" 0
 menuText P OprepHelpIndex "Spis treci" 0
@@ -642,6 +708,7 @@ translate P NumDeletedGames {Liczba usunitych partii:}
 translate P NumFilterGames {Liczba partii w filtrze:}
 translate P YearRange {Data:}
 translate P RatingRange {Ranking:}
+translate P Description {Opis} 
 translate P Flag {Oznaczenie:}
 translate P DeleteCurrent {Usu aktualn parti}
 translate P DeleteFilter {Usu partie z filtra}
@@ -667,6 +734,8 @@ translate P CompactDatabase {Uporzdkuj baz}
 translate P SortDatabase {Sortuj baz}
 translate P AddEloRatings {Dodaj rankingi ELO}
 translate P AutoloadGame {Domylna partia}
+translate P StripTags {Usu znaczniki PGN} 
+translate P StripTag {Usu znacznik}
 translate P Cleaner {Zestaw zada}
 translate P CleanerHelp {
 Zestaw zada pozwala wykona od razu kilka operacji porzdkowania bazy. Operacje wybrane z listy
@@ -686,12 +755,13 @@ Na pewno wykona wybrane zadania?
 # Comment editor:
 translate P AnnotationSymbols  {Symbole:}
 translate P Comment {Komentarz:}
+translate P InsertMark {Wstaw znak}
 
 # Board search:
 translate P BoardSearch {Wyszukiwanie wg pozycji}
 translate P FilterOperation {Operacje na aktualnym filtrze:}
 translate P FilterAnd {I (ogranicz filtr)}
-translate P FilterOr {LUB (dodaj do filtr)}
+translate P FilterOr {LUB (dodaj do filtra)}
 translate P FilterIgnore {NOWY (ignoruj poprzedni filtr)}
 translate P SearchType {Typ wyszukiwania:}
 translate P SearchBoardExact {Identyczna pozycja (bierki na tych samych polach)}
@@ -728,7 +798,7 @@ translate P InitialBoard {Pozycja pocztkowa}
 translate P SideToMove {Na posuniciu}
 translate P MoveNumber {Posunicie nr}
 translate P Castling {Roszada}
-translate P EnPassentFile {Bicie w przelocie}
+translate P EnPassantFile {Bicie w przelocie}
 translate P ClearFen {Kopiuj FEN}
 translate P PasteFen {Wklej pozycj FEN}
 
@@ -759,6 +829,8 @@ Na pewno kontynuowa, rezygnujc z wszelkich zmian?
 
 # Exit dialog:
 translate P ExitDialog {Na pewno zakoczy prac z programem?}
+translate P ExitUnsaved {Nastpujce bazy zawieraj niezapisane zmiany. 
+Jeli zamkniesz program teraz, zmiany zostan utracone.} 
 
 # Import window:
 translate P PasteCurrentGame {Wklej aktualn parti}
@@ -791,7 +863,8 @@ translate P OprepEvery {co %u partii}
 translate P OprepUp {wicej o %u%s ni w caej bazie}
 translate P OprepDown {mniej o %u%s ni w caej bazie}
 translate P OprepSame {jak w caej bazie}
-translate P OprepMostFrequent {Zawodnicy najczciej grajcy wariant}
+translate P OprepMostFrequent {Gracze najczciej stosujcy wariant}
+translate P OprepMostFrequentOpponents {Przeciwnicy} 
 translate P OprepRatingsPerf {Rankingi i wyniki}
 translate P OprepAvgPerf {rednie rankingi i wyniki}
 translate P OprepWRating {Ranking biaych}
@@ -817,14 +890,16 @@ translate P OprepMoveOrdersAll \
 translate P OprepMoveOrdersMany \
   {Badana pozycja powstawaa na %u sposobw. Najczstsze %u to:}
 translate P OprepMovesFrom {Posunicia w badanej pozycji}
+translate P OprepMostFrequentEcoCodes {Najczstsze kody ECO} 
 translate P OprepThemes {Motywy pozycyjne}
-translate P OprepThemeDescription {Czsto wystpowania motyww w ruchu %u}
+translate P OprepThemeDescription {Czsto motyww w pierwszych %u posuniciach partii} 
 translate P OprepThemeSameCastling {Jednostronne roszady}
 translate P OprepThemeOppCastling {Rnostronne roszady}
 translate P OprepThemeNoCastling {Obie strony bez roszady}
 translate P OprepThemeKPawnStorm {Atak pionowy na skrzydle krlewskim}
 translate P OprepThemeQueenswap {Wymiana hetmanw}
-translate P OprepThemeIQP {Izolowany pion d}
+translate P OprepThemeWIQP {Izolowany pion biaych} 
+translate P OprepThemeBIQP {Izolowany pion czarnych}
 translate P OprepThemeWP567 {Biay pion na 5/6/7 linii}
 translate P OprepThemeBP234 {Czarny pion na 2/3/4 linii}
 translate P OprepThemeOpenCDE {Otwarta kolumna c/d/e}
@@ -837,6 +912,27 @@ translate P OprepTheoryTable {Teoria}
 translate P OprepTableComment {Utworzono z %u partii o najwyszym rednim rankingu.}
 translate P OprepExtraMoves {Dodatkowe posunicia w przypisach}
 translate P OprepMaxGames {Maksymalna liczba partii w teorii}
+translate P OprepViewHTML {rdo HTML} 
+translate P OprepViewLaTeX {rdo LaTeX} 
+
+# Player Report:
+translate P PReportTitle {Raport o graczu}
+translate P PReportColorWhite {with the White pieces} ;# ***
+translate P PReportColorBlack {with the Black pieces} ;# ***
+translate P PReportMoves {po %s}
+translate P PReportOpenings {Debiuty}
+translate P PReportClipbase {Wyczy schowek i skopiuj do niego wybrane partie}
+
+# Piece Tracker window:
+translate P TrackerSelectSingle {Lewy przycisk wybiera t figur.}
+translate P TrackerSelectPair {Lewy przycisk wybiera t figur; prawy obie takie figury.}
+translate P TrackerSelectPawn {Lewy przycisk wybiera tego piona; prawy wszystkie 8 pionw.}
+translate P TrackerStat {Statystyka}
+translate P TrackerGames {% partie z posuniciem na tym pole}
+translate P TrackerTime {% czasu na tym polu}
+translate P TrackerMoves {Posunicia}
+translate P TrackerMovesStart {Podaj numer posunicia, od ktrego zacz ledzenie.}
+translate P TrackerMovesStop {Podaj numer posunicia, na ktrym skoczy ledzenie.}
 
 # Game selection dialogs:
 translate P SelectAllGames {Wszystkie partie w bazie}
@@ -869,6 +965,10 @@ translate P TwinsUndelete {Odzyska wszystkie partie przed poszukiwaniem?}
 translate P TwinsSetFilter {Wstawi wszystkie usunite partie do filtra?}
 translate P TwinsComments {Zawsze zachowywa partie komentowane?}
 translate P TwinsVars {Zawsze zachowywa partie z wariantami?}
+translate P TwinsDeleteWhich {Ktr parti usun:} 
+translate P TwinsDeleteShorter {Krtsz} 
+translate P TwinsDeleteOlder {O niszym numerze}
+translate P TwinsDeleteNewer {O wyszym numerze}
 translate P TwinsDelete {Usu partie}
 
 # Name editor window:
@@ -914,6 +1014,7 @@ translate P IndentComments {Wcinaj komentarze?}
 translate P IndentVariations {Wcinaj warianty?}
 translate P ExportColumnStyle {Kolumny (jedno posunicie w wierszu)?}
 translate P ExportSymbolStyle {Styl znakw komentarza:}
+translate P ExportStripMarks {Usuwa z komentarzy kody kolorowania pl/strzaek?} 
 
 # Goto game/move dialogs:
 translate P LoadGameNumber {Podaj numer partii do wczytania:}
@@ -971,6 +1072,17 @@ Moe to zaj troch czasu, ale jest to operacja jednorazowa. Moesz j przerwa, jeli
 Przekonwertowa baz?
 }
 
+# Recent files options:
+translate P RecentFilesMenu {Liczba ostatnich plikw w menu Plik} 
+translate P RecentFilesExtra {Liczba ostatnich plikw w dodatkowym podmenu} 
+
+# My Player Names options:
+translate P MyPlayerNamesDescription {
+Podaj list preferowanych nazwisk graczy, po jednym w wierszu. W nazwiskach mona stosowa znaki specjalne (np. "?" - dowolny znak, "*" - dowolna sekwencja znakw).
+
+Wszystkie partie grane przez jednego z graczy z listy bd wywietlane z jego perspektywy.
+}
+
 }
 
 ### Tips of the day in Polish:
