@@ -49,6 +49,8 @@ menuText B FileMaintNameRound "Verificacao Ortografica de Rodadas..." 11 \
   {Verificacao dos nomes de rodadas usando o arquivo de correcao ortografica}
 menuText B FileReadOnly "Apenas Leitura..." 7 \
   {Trata a base de dados corrente como arquivo de leitura, impedindo mudancas}
+menuText B FileSwitch "Switch to database" 0 \
+  {Switch to a different opened database} ;# ***
 menuText B FileExit "Sair" 0 {Encerrar o Scid}
 
 # Edit menu:
@@ -67,6 +69,10 @@ menuText B EditStripComments "Limpar Comentarios" 0 \
   {Limpa comentarios e anotacoes no jogo atual}
 menuText B EditStripVars "Limpar Variantes" 0 \
   {Limpa todas as variantes no jogo atual}
+menuText B EditStripBegin "Moves from the beginning" 1 \
+  {Strip moves from the beginning of the game} ;# ***
+menuText B EditStripEnd "Moves to the end" 0 \
+  {Strip moves to the end of the game} ;# ***
 menuText B EditReset "Limpar a base de trabalho" 0 \
   {Limpa completamente a base de trabalho}
 menuText B EditCopy "Copiar jogo para a base de trabalho" 0 \
@@ -75,6 +81,8 @@ menuText B EditPaste "Colar jogo da base de trabalho" 1 \
   {Cola o jogo ativo da base de trabalho}
 menuText B EditSetup "Configura posicao inicial..." 12 \
   {Configura a posicao inicial para o jogo}
+menuText B EditCopyBoard "Copy position" 6 \
+  {Copy the current board in FEN notation to the text selection (clipboard)} ;# ***
 menuText B EditPasteBoard "Colar Posicao" 12 \
   {Configura a posicao inicial a partir da area de transferencia}
 
@@ -88,6 +96,7 @@ menuText B GameReload "Recarrega o Jogo atual" 3 \
   {Recarrega o jogo, descartando qualquer alteracao}
 menuText B GameNext "Proximo Jogo" 5 {Carrega o proximo jogo}
 menuText B GameLast "Ultimo Jogo" 8 {Carrega o ultimo jogo}
+menuText B GameRandom "Load Random Game" 8 {Load a random filtered game} ;# ***
 menuText B GameNumber "Carrega Jogo Numero..." 5 \
   {Carrega um jogo pelo seu numero}
 menuText B GameReplace "Salvar: Substituir Jogo..." 8 \
@@ -116,6 +125,7 @@ menuText B WindowsComment "Editor de Comentarios" 0 {Abre/fecha o editor de come
 menuText B WindowsGList "Lista de Jogos" 0 {Abre/fecha a janela com a lista de jogos}
 menuText B WindowsPGN "Notacao PGN" 0 \
   {Abre/fecha a janela com a notacao PGN do jogo}
+menuText B WindowsPList "Player Finder" 2 {Open/close the player finder} ;# ***
 menuText B WindowsTmt "Buscador de Torneio" 2 {Abre/Fecha o buscador de torneio}
 menuText B WindowsSwitcher "Intercambio de bases de dados" 0 \
   {Abre/fecha a janela de intercambio de bases de dados}
@@ -139,10 +149,15 @@ menuText B ToolsAnalysis2 "Analisador #2..." 17 \
 menuText B ToolsCross "Tabela de Cruzamento" 0 {Mostra a tabela de cruzamentos do torneio para o jogo corrente}
 menuText B ToolsEmail "Gerenciador de e-mails" 0 \
   {Abre/fecha a janela do gerenciador de e-mails}
+menuText B ToolsFilterGraph "Filter graph" 7 \
+  {Open/close the filter graph window} ;# ***
 menuText B ToolsOpReport "Relatorio de abertura" 0 \
   {Gera um relatorio de abertura para a posicao corrente}
+menuText B ToolsTracker "Piece Tracker"  0 {Open the Piece Tracker window} ;# ***
 menuText B ToolsPInfo "Informacao do Jogador"  0 \
   {Abre/atualiza a janela de informacao do jogador}
+menuText B ToolsPlayerReport "Player Report..." 3 \
+  {Generate a player report} ;# ***
 menuText B ToolsRating "Grafico de Rating" 0 \
   {Mostra, em um grafico, a evolucao do rating de um jogador}
 menuText B ToolsScore "Grafico de Resultados" 0 {Mostra a janela com o grafico dos resultados}
@@ -169,13 +184,16 @@ menuText B ToolsImportFile "Importa arquivo de jogos PGN..." 7 \
 
 # Options menu:
 menuText B Options "Opcoes" 0
-menuText B OptionsSize "Tamanho do Tabuleiro" 0 {Muda o tamanho do tabuleiro}
-menuText B OptionsPieces "Estilo de Pecas no Tabuleiro" 10 \
+menuText B OptionsBoard "Chessboard" 0 {Chess board appearance options} ;# ***
+menuText B OptionsBoardSize "Tamanho do Tabuleiro" 0 {Muda o tamanho do tabuleiro}
+menuText B OptionsBoardPieces "Estilo de Pecas no Tabuleiro" 10 \
   {Muda o estilo das pecas mostradas no tabuleiro}
-menuText B OptionsColors "Cores..." 0 {Muda as cores do tabuleiro}
+menuText B OptionsBoardColors "Cores..." 0 {Muda as cores do tabuleiro}
+menuText B OptionsBoardNames "My Player Names..." 0 {Edit my player names} ;# ***
 menuText B OptionsExport "Exportacao" 0 {Muda as opcoes de exportacao de texto}
 menuText B OptionsFonts "Fontes" 0 {Muda os fontes}
 menuText B OptionsFontsRegular "Normal" 0 {Fonte Normal}
+menuText B OptionsFontsMenu "Menu" 0 {Change the menu font} ;# ***
 menuText B OptionsFontsSmall "Pequeno" 0 {Fonte pequeno}
 menuText B OptionsFontsFixed "Fixo" 0 {Fonte de largura fixa}
 menuText B OptionsGInfo "Informacoes do Jogo" 0 {Opcoes de informacao do jogo}
@@ -183,6 +201,8 @@ menuText B OptionsLanguage "Linguagem" 0 {Menu de selecao de linguagem}
 menuText B OptionsMoves "Movimentos" 0 {Opcoes para entrada dos movimentos}
 menuText B OptionsMovesAsk "Perguntar antes de substituir movimentos" 0 \
   {Pergunta antes de substituir movimentos existentes}
+menuText B OptionsMovesAnimate "Animation time" 1 \
+  {Set the amount of time used to animate moves} ;# ***
 menuText B OptionsMovesDelay "Tempo de atraso p/ Jogo automatico..." 1 \
   {Define o tempo de espera antes de entrar no modo de jogo automatico}
 menuText B OptionsMovesCoord "Entrada de movimentos por coordenadas" 0 \
@@ -206,6 +226,8 @@ menuText B OptionsSpell "Carregar arquivo de verificacao ortografica..." 6 \
   {Carrega o arquivo de verificacao ortografica do Scid}
 menuText B OptionsTable "Diretorio de tabelas de base..." 0 \
   {Selecione um arquivo de tabela de base; todas as tabelas nesse diretorio serao usadas}
+menuText B OptionsRecent "Recent files..." 0 \
+  {Change the number of recent files displayed in the File menu} ;# ***
 menuText B OptionsSave "Salvar Configuracao" 0 \
   "Salva a configuracao no arquivo $::optionsFile"
 menuText B OptionsAutoSave "Salva Opcoes ao sair" 0 \
@@ -213,6 +235,7 @@ menuText B OptionsAutoSave "Salva Opcoes ao sair" 0 \
 
 # Help menu:
 menuText B Help "Ajuda" 0
+menuText B HelpContents "Contents" 0 {Show the help contents page} ;# ***
 menuText B HelpIndex "Indice" 0 {Indice da Ajuda}
 menuText B HelpGuide "Consulta Rapida" 0 {Mostra a pagina de consulta rapida}
 menuText B HelpHints "Dicas" 0 {Mostra a pagina de dicas}
@@ -228,6 +251,7 @@ menuText B GInfoFEN "Mostra Diagrama FEN" 16
 menuText B GInfoMarks "Mostra setas e casas coloridas" 7
 menuText B GInfoWrap "Quebra de linhas longas" 0
 menuText B GInfoFullComment "Mostrar comentario completo" 8
+menuText B GInfoPhotos "Show Photos" 5 ;# ***
 menuText B GInfoTBNothing "Tabelas de Base: nada" 12
 menuText B GInfoTBResult "Tabelas de Base: apenas resultado" 12
 menuText B GInfoTBAll "Tabelas de Base: resultado e melhores movimentos" 19
@@ -243,13 +267,16 @@ helpMsg B .button.intoVar {Entrar na variante  (tecla de atalho: v)}
 helpMsg B .button.exitVar {Sair da variante  (tecla de atalho: z)}
 helpMsg B .button.flip {Girar tabuleiro  (tecla de atalho: .)}
 helpMsg B .button.coords {Liga/desliga coordenadas  (tecla de atalho: 0)}
+helpMsg B .button.stm {Turn the side-to-move icon on or off} ;# ***
 helpMsg B .button.autoplay {Jogo automatico  (tecla: Ctrl+Z)}
 
 # General buttons:
 translate B Back {Voltar}
+translate B Browse {Browse} ;# ***
 translate B Cancel {Cancelar}
 translate B Clear {Limpar}
 translate B Close {Fechar}
+translate B Contents {Contents} ;# ***
 translate B Defaults {Defaults}
 translate B Delete {Deletar}
 translate B Graph {Grafico}
@@ -292,12 +319,14 @@ translate B Black {Preto}
 translate B Player {Jogador}
 translate B Rating {Rating}
 translate B RatingDiff {Diferenca de Rating (Brancas - Pretas)}
+translate B AverageRating {Average Rating} ;# ***
 translate B Event {Evento}
 translate B Site {Lugar}
 translate B Country {Pais}
 translate B IgnoreColors {Ignorar cores}
 translate B Date {Data}
 translate B EventDate {Evento data}
+translate B Decade {Decade} ;# ***
 translate B Year {Ano}
 translate B Month {Mes}
 translate B Months {Janeiro Fevereiro Marco Abril Maio Junho
@@ -322,6 +351,11 @@ translate B score {Pontuacao}
 translate B StartPos {Posicao Inicial}
 translate B Total {Total}
 
+# Standard error messages:
+translate B ErrNotOpen {This is not an open database.} ;# ***
+translate B ErrReadOnly {This database is read-only; it cannot be altered.}
+translate B ErrSearchInterrupted {Search was interrupted; results are incomplete.}
+
 # Game information:
 translate B twin {duplicata}
 translate B deleted {apagado}
@@ -342,6 +376,7 @@ translate B PInfoMostWhite {Aberturas mais comuns com as Brancas}
 translate B PInfoMostBlack {Aberturas mais comuns com as Pretas}
 translate B PInfoRating {Historico de Rating}
 translate B PInfoBio {Biografia}
+translate B PInfoEditRatings {Edit Ratings} ;# ***
 
 # Tablebase information:
 translate B Draw {Empate}
@@ -356,6 +391,10 @@ translate B allOthersLose {qualquer outro perde}
 translate B matesIn {mate em}
 translate B hasCheckmated {recebeu xeque-mate}
 translate B longest {mais longo}
+translate B WinningMoves {Winning moves} ;# ***
+translate B DrawingMoves {Drawing moves} ;# ***
+translate B LosingMoves {Losing moves} ;# ***
+translate B UnknownMoves {Unknown-result moves} ;# ***
 
 # Tip of the day:
 translate B Tip {Dica}
@@ -394,6 +433,10 @@ translate B LockTree {Travamento}
 translate B TreeLocked {Travada} ;# ***
 translate B TreeBest {Melhor}
 translate B TreeBestGames {Melhores jogos da arvore}
+# Note: the next message is the tree window title row. After editing it,
+# check the tree window to make sure it lines up with the actual columns.
+translate B TreeTitleRow \
+  {    Move   ECO       Frequency    Score  AvElo Perf AvYear %Draws} ;# ***
 
 # Finder window:
 menuText B FinderFile "Arquivo" 0
@@ -420,6 +463,17 @@ translate B FinderDirs {Diretorios}
 translate B FinderFiles {Arquivos}
 translate B FinderUpDir {Acima}
 
+# Player finder:
+menuText B PListFile "Arquivo" 0
+menuText B PListFileUpdate "Atualizar" 0
+menuText B PListFileClose "Close Player Finder" 0 ;# ***
+menuText B PListSort "Ordenar" 0
+menuText B PListSortName "Name" 0 ;# ***
+menuText B PListSortElo "Elo" 0
+menuText B PListSortGames "Jogos" 0
+menuText B PListSortOldest "Oldest" 0 ;# ***
+menuText B PListSortNewest "Newest" 0 ;# ***
+
 # Tournament finder:
 menuText B TmtFile "Arquivo" 0
 menuText B TmtFileUpdate "Atualizar" 0
@@ -446,6 +500,7 @@ menuText B GraphOptionsWhite "Branco" 0
 menuText B GraphOptionsBlack "Preto" 0
 menuText B GraphOptionsBoth "Ambos" 0
 menuText B GraphOptionsPInfo "Informacao do Jogador" 0
+translate B GraphFilterTitle "Filter graph: frequency per 1000 games" ;# ***
 
 # Analysis window:
 translate B AddVariation {Adicionar variante}
@@ -459,6 +514,7 @@ translate B AnnotateAll {Para movimentos de ambos os lados}
 translate B AnnotateWhite {Apenas para movimentos das Brancas}
 translate B AnnotateBlack {Apenas para movimentos das Pretas}
 translate B AnnotateNotBest {Quando o movimento do jogo nao for o melhor movimento}
+translate B LowPriority {Low CPU priority} ;# ***
 
 # Analysis Engine open dialog:
 translate B EngineList {Lista de Programas de Analise}
@@ -480,6 +536,7 @@ menuText B StatsOpt "Opcoes" 0
 
 # PGN window menus:
 menuText B PgnFile "Arquivo" 0
+menuText B PgnFileCopy "Copy Game to Clipboard" 0 ;# ***
 menuText B PgnFilePrint "Imprimir para arquivo..." 0
 menuText B PgnFileClose "Fechar janela PGN" 0
 menuText B PgnOpt "Monitor" 0
@@ -490,6 +547,7 @@ menuText B PgnOptIndentC "Identar comentarios" 0
 menuText B PgnOptIndentV "Identar variantes" 7
 menuText B PgnOptColumn "Estilo Coluna (um movimento por linha)" 0
 menuText B PgnOptSpace "Espaco apos o numero do movimento" 0
+menuText B PgnOptStripMarks "Strip out colored square/arrow codes" 1 ;# ***
 menuText B PgnColor "Cores" 0
 menuText B PgnColorHeader "Cabecalho..." 0
 menuText B PgnColorAnno "Anotacoes..." 0
@@ -520,7 +578,9 @@ menuText B CrosstabOptNats "Nacionalidades" 0
 menuText B CrosstabOptRatings "Ratings" 0
 menuText B CrosstabOptTitles "Titulos" 0
 menuText B CrosstabOptBreaks "Scores de desempate" 0
+menuText B CrosstabOptDeleted "Include deleted games" 8 ;# ***
 menuText B CrosstabOptColors "Cores (apenas para tabela Swiss)" 0
+menuText B CrosstabOptColumnNumbers "Numbered columns (All-play-all table only)" 2 ;# ***
 menuText B CrosstabOptGroup "Pontuacao do Grupo" 0
 menuText B CrosstabSort "Ordenar" 0
 menuText B CrosstabSortName "Nome" 0
@@ -535,6 +595,7 @@ menuText B CrosstabHelpIndex "Indice da Ajuda" 0
 translate B SetFilter {Setar filtro}
 translate B AddToFilter {Adicionar ao filtro}
 translate B Swiss {Swiss}
+translate B Category {Category} ;# ***
 
 # Opening report window menus:
 menuText B OprepFile "Arquivo" 0
@@ -543,6 +604,10 @@ menuText B OprepFileHtml "Imprimir para arquivo HTML..." 9
 menuText B OprepFileLaTeX "Imprimir para arquivo LaTex..." 9
 menuText B OprepFileOptions "Opcoes..." 0
 menuText B OprepFileClose "Fechar janela de relatorio" 0
+menuText B OprepFavorites "Favorites" 1 ;# ***
+menuText B OprepFavoritesAdd "Add Report..." 0 ;# ***
+menuText B OprepFavoritesEdit "Edit Report Favorites..." 0 ;# ***
+menuText B OprepFavoritesGenerate "Generate Reports..." 0 ;# ***
 menuText B OprepHelp "Ajuda" 0
 menuText B OprepHelpReport "Ajuda para Relatorio de abertura" 0
 menuText B OprepHelpIndex "Indice da Ajuda" 0
@@ -643,6 +708,7 @@ translate B NumDeletedGames {Jogos deletados:}
 translate B NumFilterGames {Jogos no filtro:}
 translate B YearRange {Faixa de Anos:}
 translate B RatingRange {Faixa de Rating:}
+translate B Description {Description} ;# ***
 translate B Flag {Sinalizador}
 translate B DeleteCurrent {Deletar jogo corrente}
 translate B DeleteFilter {Deletar jogos filtrados}
@@ -668,6 +734,8 @@ translate B CompactDatabase {Compactar base de dados}
 translate B SortDatabase {Ordenar base de dados}
 translate B AddEloRatings {Adicionar ratings}
 translate B AutoloadGame {Carregar autom. o jogo numero}
+translate B StripTags {Strip PGN tags} ;# ***
+translate B StripTag {Strip tag} ;# ***
 translate B Cleaner {Limpador}
 translate B CleanerHelp {
 O Limpador do Scid executara todas as acoes de manutencao selecionadas da lista abaixo, no banco corrente.
@@ -685,6 +753,7 @@ Voce esta certo de que quer iniciar as acoes de manutencao selecionadas?
 # Comment editor:
 translate B AnnotationSymbols  {Simbolos de Anotacao:}
 translate B Comment {Comentario:}
+translate B InsertMark {Insert mark} ;# ***
 
 # Board search:
 translate B BoardSearch {Pesquisa Tabuleiro}
@@ -727,7 +796,7 @@ translate B InitialBoard {Tabuleiro Inicial}
 translate B SideToMove {Lado que move}
 translate B MoveNumber {No. do Movimento}
 translate B Castling {Roque}
-translate B EnPassentFile {coluna En Passant}
+translate B EnPassantFile {coluna En Passant}
 translate B ClearFen {Limpar FEN}
 translate B PasteFen {Colar FEN}
 
@@ -757,6 +826,7 @@ Voce realmente quer continuar e descartar as mudancas feitas?
 
 # Exit dialog:
 translate B ExitDialog {Voce quer realmente sair do Scid?}
+translate B ExitUnsaved {The following databases have unsaved game changes. If you exit now, these changes will be lost.} ;# ***
 
 # Import window:
 translate B PasteCurrentGame {Colar jogo corrente}
@@ -790,6 +860,7 @@ translate B OprepUp {ate %u%s de todos os anos}
 translate B OprepDown {menos que %u%s de todos os anos}
 translate B OprepSame {nenhuma mudanca em todos os anos}
 translate B OprepMostFrequent {Jogadores mais frequentes}
+translate B OprepMostFrequentOpponents {Most frequent opponents} ;# ***
 translate B OprepRatingsPerf {Ratings e Desempenho}
 translate B OprepAvgPerf {Ratings e desempenho medios}
 translate B OprepWRating {Rating Brancas}
@@ -815,14 +886,16 @@ translate B OprepMoveOrdersAll \
 translate B OprepMoveOrdersMany \
   {Houve %u ordens de movimentos que atingem esta posicao. As %u primeiras sao:}
 translate B OprepMovesFrom {Movimentos da posicao do relatorio}
+translate B OprepMostFrequentEcoCodes {Most frequent ECO codes} ;# ***
 translate B OprepThemes {Temas Posicionais}
-translate B OprepThemeDescription {Frequencia de temas no movimento %u}
+translate B OprepThemeDescription {Frequency of themes in the first %u moves of each game} ;# ***
 translate B OprepThemeSameCastling {Roque do mesmo lado}
 translate B OprepThemeOppCastling {Roques opostos}
 translate B OprepThemeNoCastling {Ninguem efetuou o roque}
 translate B OprepThemeKPawnStorm {Tempestade de Peoes no lado do Rei}
 translate B OprepThemeQueenswap {Damas ja trocadas}
-translate B OprepThemeIQP {Peao da Dama isolado}
+translate B OprepThemeWIQP {White Isolated Queen Pawn} ;# ***
+translate B OprepThemeBIQP {Black Isolated Queen Pawn} ;# ***
 translate B OprepThemeWP567 {Peao Branco na 5/6/7a fila}
 translate B OprepThemeBP234 {Peao Preto na 2/3/4a fila}
 translate B OprepThemeOpenCDE {Colunas c/d/e abertas}
@@ -835,6 +908,27 @@ translate B OprepTheoryTable {Tabela de Teoria}
 translate B OprepTableComment {Gerada a partir dos %u jogos com rating mais alto.}
 translate B OprepExtraMoves {Movimentos com nota extra na Tabela de Teoria}
 translate B OprepMaxGames {Qtde. Maxima de jogos na tabela de teoria}
+translate B OprepViewHTML {View HTML} ;# ***
+translate B OprepViewLaTeX {View LaTeX} ;# ***
+
+# Player Report:
+translate B PReportTitle {Player Report} ;# ***
+translate B PReportColorWhite {with the White pieces} ;# ***
+translate B PReportColorBlack {with the Black pieces} ;# ***
+translate B PReportMoves {after %s} ;# ***
+translate B PReportOpenings {Openings} ;# ***
+translate B PReportClipbase {Empty clipbase and copy matching games to it} ;# ***
+
+# Piece Tracker window:
+translate B TrackerSelectSingle {Left mouse button selects this piece.} ;# ***
+translate B TrackerSelectPair {Left mouse button selects this piece; right button also selects its sibling.}
+translate B TrackerSelectPawn {Left mouse button selects this pawn; right button selects all 8 pawns.}
+translate B TrackerStat {Statistic}
+translate B TrackerGames {% games with move to square}
+translate B TrackerTime {% time on each square}
+translate B TrackerMoves {Moves}
+translate B TrackerMovesStart {Enter the move number where tracking should begin.}
+translate B TrackerMovesStop {Enter the move number where tracking should stop.}
 
 # Game selection dialogs:
 translate B SelectAllGames {Todos os jogos na base de dados}
@@ -866,6 +960,10 @@ translate B TwinsUndelete {Recuperar todos os jogos antes?}
 translate B TwinsSetFilter {Definir filtro para todas as duplicatas deletadas?}
 translate B TwinsComments {Manter sempre os jogos com comentarios?}
 translate B TwinsVars {Manter sempre os jogos com variantes?}
+translate B TwinsDeleteWhich {Delete which game:} ;# ***
+translate B TwinsDeleteShorter {Shorter game} ;# ***
+translate B TwinsDeleteOlder {Smaller game number} ;# ***
+translate B TwinsDeleteNewer {Larger game number} ;# ***
 translate B TwinsDelete {Deletar jogos}
 
 # Name editor window:
@@ -911,6 +1009,7 @@ translate B IndentComments {Identar Comentarios?}
 translate B IndentVariations {Identar Variantes?}
 translate B ExportColumnStyle {Estilo Coluna (um movimento por linha)?}
 translate B ExportSymbolStyle {Estilo de anotacao simbolica:}
+translate B ExportStripMarks {Strip square/arrow mark codes from comments?} ;# ***
 
 # Goto game/move dialogs:
 translate B LoadGameNumber {Entre o numero do jogo a ser carregado:}
@@ -967,6 +1066,17 @@ Este processo pode levar algum tempo, mas so precisa ser feito uma vez e pode se
 Voce quer atualizar esta base agora?
 }
 
+# Recent files options:
+translate B RecentFilesMenu {Number of recent files in File menu} ;# ***
+translate B RecentFilesExtra {Number of recent files in extra submenu} ;# ***
+
+# My Player Names options:
+translate B MyPlayerNamesDescription {
+Enter a list of preferred player names below, one name per line. Wildcards (e.g. "?" for any single character, "*" for any sequence of characters) are permitted.
+
+Every time a game with a player in the list is loaded, the main window chessboard will be rotated if necessary to show the game from that players perspective.
+} ;# ***
+
 }
 
 # end of portbr.tcl
