@@ -27,11 +27,11 @@ proc search_addFilterOpFrame {w {small 0}} {
   }
   label $f.title -font $bold -textvar ::tr(FilterOperation)
   radiobutton $f.and -textvar ::tr(FilterAnd) -variable filterOp \
-    -value 0 -indicatoron 0 -pady 5 -padx 5 -font $regular
+    -value 0 -pady 5 -padx 5 -font $regular
   radiobutton $f.or -textvar ::tr(FilterOr) -variable filterOp \
-    -value 1 -indicatoron 0 -pady 5 -padx 5 -font $regular
+    -value 1 -pady 5 -padx 5 -font $regular
   radiobutton $f.ignore -textvar ::tr(FilterIgnore) -variable filterOp \
-    -value 2 -indicatoron 0 -pady 5 -padx 5 -font $regular
+    -value 2 -pady 5 -padx 5 -font $regular
   pack $f.title -side top
   pack $f.and $f.or $f.ignore -side left
 }
@@ -95,9 +95,9 @@ proc searchBoard {} {
   frame $w.b
   pack $w.b -side top -ipady 5 -fill x
   checkbutton $w.b.vars -textvar ::tr(LookInVars) -padx 10 -pady 5 \
-    -onvalue 1 -offvalue 0 -variable searchInVars -relief raised
+    -onvalue 1 -offvalue 0 -variable searchInVars
   checkbutton $w.b.flip -textvar ::tr(IgnoreColors) -padx 10 -pady 5 \
-    -onvalue 1 -offvalue 0 -variable sBoardIgnoreCols -relief raised
+    -onvalue 1 -offvalue 0 -variable sBoardIgnoreCols
 
   button $w.b.stop -textvar ::tr(Stop) -command sc_progressBar
   $w.b.stop configure -state disabled
@@ -159,10 +159,10 @@ proc checkPieceCounts {name el op} {
   global pMin pMax
   forceInt 9 0 $name $el $op
   # Now make sure minor piece counts fit with bishop/knight counts:
-  set wmMin [expr $pMin(wn) + $pMin(wb)]
-  set wmMax [expr $pMax(wn) + $pMax(wb)]
-  set bmMin [expr $pMin(bn) + $pMin(bb)]
-  set bmMax [expr $pMax(bn) + $pMax(bb)]
+  set wmMin [expr {$pMin(wn) + $pMin(wb)} ]
+  set wmMax [expr {$pMax(wn) + $pMax(wb)} ]
+  set bmMin [expr {$pMin(bn) + $pMin(bb)} ]
+  set bmMax [expr {$pMax(bn) + $pMax(bb)} ]
   if {$pMin(wm) < $wmMin} { set pMin(wm) $wmMin }
   if {$pMax(wm) > $wmMax} { set pMax(wm) $wmMax }
   if {$pMin(bm) < $bmMin} { set pMin(bm) $bmMin }
@@ -336,6 +336,11 @@ proc searchMaterial {} {
   $w.p.b1p configure -command "set pMin(bp) 1; set pMax(bp) 8"
   $w.p.ba configure -command "set pMin(bp) 0; set pMax(bp) 8"
 
+  $w.m.w1p configure -command "set pMin(wp) 1; set pMax(wp) 4"
+  $w.m.wa configure -command "set pMin(wp) 0; set pMax(wp) 4"
+  $w.m.b1p configure -command "set pMin(bp) 1; set pMax(bp) 4"
+  $w.m.ba configure -command "set pMin(bp) 0; set pMax(bp) 4"
+
   # Buttons that manipulate material settings:
   set f $w.b1
   pack [frame $f] -side top -ipady 2
@@ -479,8 +484,8 @@ proc searchMaterial {} {
     $f.b$i configure -indicatoron 0 -width 4
     $f.f$i configure -indicatoron 0 -width 2
     $f.r$i configure -indicatoron 0 -width 2
-    set column [expr 5 * (($i - 1) / 3)]
-    set row [expr ($i - 1) % 3]
+    set column [expr {5 * (($i - 1) / 3)} ]
+    set row [expr {($i - 1) % 3} ]
     grid $f.b$i -row $row -column $column; incr column
     grid $f.p$i -row $row -column $column; incr column
     grid $f.f$i -row $row -column $column; incr column
@@ -498,8 +503,8 @@ proc searchMaterial {} {
   frame $f
   button $f.clearPat -textvar ::tr(Clear) -command clearPatterns
   menubutton $f.common -textvar ::tr(CommonPatterns) \
-    -menu $f.common.m -relief raised
-  menu $f.common.m
+    -menu $f.common.m -relief raised -font $small
+  menu $f.common.m -font $small
   $f.common.m add command -label "White IQP" -command {
     if {$pMin(wp) < 1} { set pMin(wp) 1 }
     setPatterns {{wp d ? Yes} {wp c ? No} {wp e ? No}}
@@ -574,11 +579,11 @@ proc searchMaterial {} {
   label $f.t4 -image bb20
   label $f.t5 -textvar ::tr(squares:)
   radiobutton $f.same -textvar ::tr(SameColor) -variable oppBishops \
-    -value "Same" -indicatoron 0 -pady 5 -padx 5
+    -value "Same" -padx 5 -pady 4
   radiobutton $f.opp -textvar ::tr(OppColor) -variable oppBishops \
-    -value "Opposite" -indicatoron 0 -pady 5 -padx 5
+    -value "Opposite" -padx 5 -pady 4
   radiobutton $f.either -textvar ::tr(Either) -variable oppBishops \
-    -value "Either" -indicatoron 0 -pady 5 -padx 5
+    -value "Either" -padx 5 -pady 4
   foreach i {t1 t2 t3 t4 t5 same opp either} { pack $f.$i -side left }
 
   set f $w.move
@@ -613,7 +618,7 @@ proc searchMaterial {} {
   set f $w.b3
   pack [frame $f] -side top -ipady 5 -fill x
   checkbutton $f.ignorecol -textvar ::tr(IgnoreColors) \
-    -variable ignoreColors -relief raised -padx 8 -pady 5
+    -variable ignoreColors -padx 8 -pady 5 -relief raised
 
   button $f.save -textvar ::tr(Save...) -padx 10 -command saveMaterialSearch
 
@@ -717,9 +722,9 @@ proc saveMaterialSearch {} {
 ### HEADER Searching (Name, etc).
 
 set sWhite "";  set sBlack "";  set sEvent ""; set sSite "";  set sRound ""
-set sWhiteEloMin 0; set sWhiteEloMax 4000
-set sBlackEloMin 0; set sBlackEloMax 4000
-set sEloDiffMin -4000; set sEloDiffMax +4000
+set sWhiteEloMin 0; set sWhiteEloMax [sc_info limit elo]
+set sBlackEloMin 0; set sBlackEloMax [sc_info limit elo]
+set sEloDiffMin "-[sc_info limit elo]"; set sEloDiffMax "+[sc_info limit elo]"
 set sTitleList [list gm im fm none wgm wim wfm w]
 foreach i $sTitleList {
   set sTitles(w:$i) 1
@@ -747,10 +752,10 @@ trace variable sDateMin w forceDate
 trace variable sDateMax w forceDate
 
 foreach i {sWhiteEloMin sWhiteEloMax sBlackEloMin sBlackEloMax} {
-  trace variable $i w {forceInt 4000 0}
+  trace variable $i w [list forceInt [sc_info limit elo] 0]
 }
-trace variable sEloDiffMin w {forceInt -4000 0}
-trace variable sEloDiffMax w {forceInt -4000 0}
+trace variable sEloDiffMin w [list forceInt "-[sc_info limit elo]" 0]
+trace variable sEloDiffMax w [list forceInt "-[sc_info limit elo]" 0]
 
 trace variable sGlMin w {forceInt 9999 0}
 trace variable sGlMax w {forceInt 9999 0}
@@ -801,9 +806,10 @@ proc searchHeaderDefaults {} {
 
   set sWhite "";  set sBlack ""
   set sEvent ""; set sSite "";  set sRound ""
-  set sWhiteEloMin 0; set sWhiteEloMax 4000
-  set sBlackEloMin 0; set sBlackEloMax 4000
-  set sEloDiffMin  -4000; set sEloDiffMax +4000
+  set sWhiteEloMin 0; set sWhiteEloMax [sc_info limit elo]
+  set sBlackEloMin 0; set sBlackEloMax [sc_info limit elo]
+  set sEloDiffMin "-[sc_info limit elo]"
+  set sEloDiffMax "+[sc_info limit elo]"
   set sGlMin 0; set sGlMax 999
   set sEcoMin "A00";  set sEcoMax "E99"; set sEco Yes
   set sGnumMin 1; set sGnumMax -1
@@ -1181,7 +1187,7 @@ proc searchHeader {} {
   pack $w.progress -side top -pady 2
   label $w.status -text "" -width 1 -font font_Small -relief sunken -anchor w
   pack $w.status -side bottom -fill x
-  update
+  # update
   wm resizable $w 0 0
   standardShortcuts $w
   configSearchState
@@ -1191,7 +1197,7 @@ proc searchHeader {} {
 proc saveHeaderSearch {} {
   global sWhite sBlack sEvent sSite sRound sDateMin sDateMax sIgnoreCol
   global sWhiteEloMin sWhiteEloMax sBlackEloMin sBlackEloMax
-  global sEloDiffMin sEloDiffMax
+  global sEloDiffMin sEloDiffMax sGlMin sGlMax
   global sEco sEcoMin sEcoMax sHeaderFlags
   global sResWin sResLoss sResDraw sResOther glstart filterOp sPgntext
 
@@ -1215,7 +1221,7 @@ proc saveHeaderSearch {} {
   foreach i {sWhite sBlack sEvent sSite sRound sDateMin sDateMax sResWin
      sResLoss sResDraw sResOther sWhiteEloMin sWhiteEloMax sBlackEloMin
      sBlackEloMax sEcoMin sEcoMax filterOp sEloDiffMin sEloDiffMax
-     sIgnoreCol} {
+     sIgnoreCol sGlMin sGlMax} {
     puts $searchF "set $i [list [set $i]]"
   }
 
@@ -1313,7 +1319,7 @@ proc chooseEcoRange {} {
   wm minsize $w 30 5
 
   listbox $w.list -yscrollcommand "$w.ybar set" -height 20 -width 60 \
-    -background white -selectbackground lightBlue -setgrid 1
+    -background white -setgrid 1
   foreach i $ecoCommonRanges { $w.list insert end $i }
   scrollbar $w.ybar -command "$w.list yview" -takefocus 0
   pack [frame $w.b] -side bottom -fill x
