@@ -49,6 +49,8 @@ menuText Y FileMaintNameRound "Provera pravopisa kola..." 11 \
   {Provera pravopisa kola pomou spellcheck fajla}
 menuText Y FileReadOnly "Read-only..." 0 \
   {Sprei izmene u tekuoj bazi}
+menuText Y FileSwitch "Switch to database" 0 \
+  {Switch to a different opened database} ;# ***
 menuText Y FileExit "Izai" 1 {Izlazak iz Scid-a}
 
 # Edit menu:
@@ -65,6 +67,10 @@ menuText Y EditStrip "Ukloni" 2 {Ukloni komentare ili varijante iz ove partije}
 menuText Y EditStripComments "Komentare" 0 \
   {Ukloni sve komentare i napomene iz ove partije}
 menuText Y EditStripVars "Varijante" 0 {Ukloni sve varijante iz ove partije}
+menuText Y EditStripBegin "Moves from the beginning" 1 \
+  {Strip moves from the beginning of the game} ;# ***
+menuText Y EditStripEnd "Moves to the end" 0 \
+  {Strip moves to the end of the game} ;# ***
 menuText Y EditReset "Isprazni Clipbase" 0 \
   {Resetuje clipbase da bude potpuno prazan}
 menuText Y EditCopy "Kopiraj ovu partiju na Clipbase" 0 \
@@ -73,6 +79,8 @@ menuText Y EditPaste "Prenesi poslednju clipbase partiju" 0 \
   {Prenesi aktivnu clipbase partiju ovde}
 menuText Y EditSetup "Namesti poetnu poziciju..." 0 \
   {Namesti poetnu poziciju za ovu partiju}
+menuText Y EditCopyBoard "Copy position" 6 \
+  {Copy the current board in FEN notation to the text selection (klipbord)} ;# ***
 menuText Y EditPasteBoard "Prenesi poetnu poziciju" 9 \
   {Postavi poetnu poziciju na osnovu trenutno izabranog teksta (klipbord)}
 
@@ -86,6 +94,7 @@ menuText Y GameReload "Osvei trenutnu partiju" 3 \
   {Osvei ovu partiju, sa gubljenjem svih izmena}
 menuText Y GameNext "Uitaj sledeu partiju" 5 {Uitaj sledeu filtriranu partiju}
 menuText Y GameLast "Uitaj poslednju partiju" 8 {Uitaj poslednju filtriranu partiju}
+menuText Y GameRandom "Load Random Game" 8 {Load a random filtered game} ;# ***
 menuText Y GameNumber "Uitaj partiju broj..." 5 \
   {Uitaj partiju, unosei njen broj}
 menuText Y GameReplace "Sauvaj: Zameni partiju..." 6 \
@@ -114,6 +123,7 @@ menuText Y WindowsComment "Editor komentara" 0 {Otvori/zatvori editor komentara}
 menuText Y WindowsGList "Lista partija" 0 {Otvori/zatvori listu partija}
 menuText Y WindowsPGN "PGN prozor" 0 \
   {Otvori/zatvori PGN prozor (sa podacima o partiji)}
+menuText Y WindowsPList "Player Finder" 2 {Open/close the player finder} ;# ***
 menuText Y WindowsTmt "Turnir traga" 2 {Otvori/zatvori turnir traga}
 menuText Y WindowsSwitcher "Bira baza" 0 \
   {Otvori/zatvori bira baza}
@@ -137,10 +147,15 @@ menuText Y ToolsAnalysis2 "Program za analizu #2..." 17 \
 menuText Y ToolsCross "Tabela turnira" 0 {Pokai tabelu turnira za ovu partiju}
 menuText Y ToolsEmail "Email menader" 0 \
   {Otvori/zatvori menader za korespodentske partije preko email-a}
+menuText Y ToolsFilterGraph "Filter graph" 7 \
+  {Open/close the filter graph window} ;# ***
 menuText Y ToolsOpReport "Izvetaj o otvaranjima" 0 \
   {Napravi izvetaj o otvaranjima za trenutnu poziciju}
+menuText Y ToolsTracker "Piece Tracker"  0 {Open the Piece Tracker window} ;# ***
 menuText Y ToolsPInfo "Informacije o igrau"  0 \
   {Otvori/osvei informacije o igrau}
+menuText Y ToolsPlayerReport "Player Report..." 3 \
+  {Generate a player report} ;# ***
 menuText Y ToolsRating "Grafikon rejtinga" 0 \
   {Iscrtava grafik istorije rejtinga igraa u tekuoj partiji}
 menuText Y ToolsScore "Grafikon skora" 0 {Prikai grafikon skora}
@@ -167,13 +182,16 @@ menuText Y ToolsImportFile "Uvezi vie PGN partija..." 6 \
 
 # Options menu:
 menuText Y Options "Opcije" 0
-menuText Y OptionsSize "Veliina table" 0 {Promeni veliinu table}
-menuText Y OptionsPieces "Board Piece Style" 6 \
+menuText Y OptionsBoard "Chessboard" 0 {Chess board appearance options} ;# ***
+menuText Y OptionsBoardSize "Veliina table" 0 {Promeni veliinu table}
+menuText Y OptionsBoardPieces "Board Piece Style" 6 \
   {Change the board piece style} ;# ***
-menuText Y OptionsColors "Boje" 0 {Promeni boje table}
+menuText Y OptionsBoardColors "Boje" 0 {Promeni boje table}
+menuText Y OptionsBoardNames "My Player Names..." 0 {Edit my player names} ;# ***
 menuText Y OptionsExport "Izvoz" 0 {Promeni opcije tekstualnog izvoza}
 menuText Y OptionsFonts "Fontovi" 0 {Promeni fontove}
 menuText Y OptionsFontsRegular "Obian" 0 {Promeni obian font}
+menuText Y OptionsFontsMenu "Menu" 0 {Change the menu font} ;# ***
 menuText Y OptionsFontsSmall "Mali" 0 {Promeni mali font}
 menuText Y OptionsFontsFixed "Neproporcionalni" 0 {Promeni neproporcionalni font}
 menuText Y OptionsGInfo "Informacije o Partiji" 0 {Opcije informacija o partiji}
@@ -181,6 +199,8 @@ menuText Y OptionsLanguage "Jezik" 0 {Izaberi jezik}
 menuText Y OptionsMoves "Potezi" 0 {Opcije unoenja poteza}
 menuText Y OptionsMovesAsk "Pitaj pre zamene poteza" 0 \
   {Pitaj, da li se moe postojei zameniti novim potezom}
+menuText Y OptionsMovesAnimate "Animation time" 1 \
+  {Set the amount of time used to animate moves} ;# ***
 menuText Y OptionsMovesDelay "Odlaganje izmeu poteza..." 1 \
   {Podesi vreme odlaganja pri automatskom pregledanju poteza}
 menuText Y OptionsMovesCoord "Unoenje koordinata poteza" 0 \
@@ -203,6 +223,8 @@ menuText Y OptionsSpell "Uitaj fajl za kontrolu pravopisa..." 13 \
   {Uitaj fajl za kontrolu pravopisa}
 menuText Y OptionsTable "Direktorijum baza zavrnica..." 0 \
   {Izaberi fajl baze zavrnica; sve baze u direktorijumu e biti koriene}
+menuText Y OptionsRecent "Recent files..." 0 \
+  {Change the number of recent files displayed in the File menu} ;# ***
 menuText Y OptionsSave "Sauvaj opcije" 0 \
   "Sauvaj sve opcije u fajl $::optionsFile"
 menuText Y OptionsAutoSave "Auto-sauvaj opcije na izlasku" 0 \
@@ -210,6 +232,7 @@ menuText Y OptionsAutoSave "Auto-sauvaj opcije na izlasku" 0 \
 
 # Help menu:
 menuText Y Help "Pomo" 2
+menuText Y HelpContents "Contents" 0 {Show the help contents page} ;# ***
 menuText Y HelpIndex "Sadraj" 0 {Prikai glavnu stranu pomoi}
 menuText Y HelpGuide "Brzi vodi" 0 {Prikai brzi vodi}
 menuText Y HelpHints "Saveti" 0 {Prikai savete}
@@ -225,6 +248,7 @@ menuText Y GInfoFEN "Prikai FEN" 8
 menuText Y GInfoMarks "Show colored squares and arrows" 5 ;# ***
 menuText Y GInfoWrap "Prelomi dugake linije" 0
 menuText Y GInfoFullComment "Show Full Comment" 10 ;# ***
+menuText Y GInfoPhotos "Show Photos" 5 ;# ***
 menuText Y GInfoTBNothing "Baza zavrnica: nita" 16
 menuText Y GInfoTBResult "Baza zavrnica: samo rezultati" 16
 menuText Y GInfoTBAll "Baza zavrnica: rezultat i najbolji potezi" 16
@@ -240,13 +264,16 @@ helpMsg Y .button.intoVar {Prei na varijantu  (taster preica: v)}
 helpMsg Y .button.exitVar {Ostavi tekuu varijantu  (taster preica: z)}
 helpMsg Y .button.flip {Rotiraj tablu  (taster preica: .)}
 helpMsg Y .button.coords {Ukljui/iskljui koordinate table  (taster preica: 0)}
+helpMsg Y .button.stm {Turn the side-to-move icon on or off} ;# ***
 helpMsg Y .button.autoplay {Automatski menjaj poteze  (taster: Ctrl+Z)}
 
 # General buttons:
 translate Y Back {Nazad}
+translate Y Browse {Browse} ;# ***
 translate Y Cancel {Poniti}
 translate Y Clear {Oisti}
 translate Y Close {Zatvori}
+translate Y Contents {Contents} ;# ***
 translate Y Defaults {Podrazumevano}
 translate Y Delete {Obrii}
 translate Y Graph {Grafikon}
@@ -289,12 +316,14 @@ translate Y Black {Crni}
 translate Y Player {Igra}
 translate Y Rating {Rejting}
 translate Y RatingDiff {Razlika u rejtingu (Beli - Crni)}
+translate Y AverageRating {Average Rating} ;# ***
 translate Y Event {Turnir}
 translate Y Site {Mesto}
 translate Y Country {Zemlja}
 translate Y IgnoreColors {Ignorii boje}
 translate Y Date {Datum}
 translate Y EventDate {Datum turnira}
+translate Y Decade {Decade} ;# ***
 translate Y Year {Godina}
 translate Y Month {Mesec}
 translate Y Months {Januar Februar Mart April Maj Jun
@@ -319,6 +348,11 @@ translate Y score {skor}
 translate Y StartPos {Poetna pozicija}
 translate Y Total {Ukupno}
 
+# Standard error messages:
+translate Y ErrNotOpen {This is not an open database.} ;# ***
+translate Y ErrReadOnly {This database is read-only; it cannot be altered.}
+translate Y ErrSearchInterrupted {Search was interrupted; results are incomplete.}
+
 # Game information:
 translate Y twin {udvojena}
 translate Y deleted {izbrisana}
@@ -339,6 +373,7 @@ translate Y PInfoMostWhite {Najee igrana otvaranja sa belim figurama}
 translate Y PInfoMostBlack {Najee igrana otvaranja sa crnim figurama}
 translate Y PInfoRating {Istorija rejtinga}
 translate Y PInfoBio {Biography} ;# ***
+translate Y PInfoEditRatings {Edit Ratings} ;# ***
 
 # Tablebase information:
 translate Y Draw {Remi}
@@ -353,6 +388,10 @@ translate Y allOthersLose {svi ostali gube}
 translate Y matesIn {matira u}
 translate Y hasCheckmated {je matirao}
 translate Y longest {najdui}
+translate Y WinningMoves {Winning moves} ;# ***
+translate Y DrawingMoves {Drawing moves} ;# ***
+translate Y LosingMoves {Losing moves} ;# ***
+translate Y UnknownMoves {Unknown-result moves} ;# ***
 
 # Tip of the day:
 translate Y Tip {Tip} ;# ***
@@ -387,6 +426,10 @@ translate Y LockTree {Zakljuaj}
 translate Y TreeLocked {zakljuano}
 translate Y TreeBest {Najbolje}
 translate Y TreeBestGames {Najbolje partije stabla}
+# Note: the next message is the tree window title row. After editing it,
+# check the tree window to make sure it lines up with the actual columns.
+translate Y TreeTitleRow \
+  {    Move   ECO       Frequency    Score  AvElo Perf AvYear %Draws} ;# ***
 
 # Finder window:
 menuText Y FinderFile "Fajl" 0
@@ -413,6 +456,17 @@ translate Y FinderDirs {Direktorijumi}
 translate Y FinderFiles {Fajlovi}
 translate Y FinderUpDir {gore}
 
+# Player finder:
+menuText Y PListFile "Fajl" 0
+menuText Y PListFileUpdate "Osvei" 0
+menuText Y PListFileClose "Close Player Finder" 0 ;# ***
+menuText Y PListSort "Sortiraj" 0
+menuText Y PListSortName "Name" 0 ;# ***
+menuText Y PListSortElo "Elo" 0
+menuText Y PListSortGames "Partije" 0
+menuText Y PListSortOldest "Oldest" 0 ;# ***
+menuText Y PListSortNewest "Newest" 0 ;# ***
+
 # Tournament finder:
 menuText Y TmtFile "Fajl" 0
 menuText Y TmtFileUpdate "Osvei" 0
@@ -439,6 +493,7 @@ menuText Y GraphOptionsWhite "Beli" 0
 menuText Y GraphOptionsBlack "Crni" 0
 menuText Y GraphOptionsBoth "Oba" 1
 menuText Y GraphOptionsPInfo "Informacije o igrau" 0
+translate Y GraphFilterTitle "Filter graph: frequency per 1000 games" ;# ***
 
 # Analysis window:
 translate Y AddVariation {Dodaj varijantu}
@@ -452,6 +507,7 @@ translate Y AnnotateAll {For moves by both sides} ;# ***
 translate Y AnnotateWhite {For White moves only} ;# ***
 translate Y AnnotateBlack {For Black moves only} ;# ***
 translate Y AnnotateNotBest {When game move is not best move} ;# ***
+translate Y LowPriority {Low CPU priority} ;# ***
 
 # Analysis Engine open dialog:
 translate Y EngineList {Analysis Engine List} ;# ***
@@ -473,6 +529,7 @@ menuText Y StatsOpt "Opcije" 0
 
 # PGN window menus:
 menuText Y PgnFile "Fajl" 0
+menuText Y PgnFileCopy "Copy Game to Clipboard" 0 ;# ***
 menuText Y PgnFilePrint "tampaj u fajl..." 1
 menuText Y PgnFileClose "Zatvori PGN prozor" 0
 menuText Y PgnOpt "Prikaz" 0
@@ -483,6 +540,7 @@ menuText Y PgnOptIndentC "Uvuci pasus kod komentara" 0
 menuText Y PgnOptIndentV "Uvuci pasus kod varijanata" 16
 menuText Y PgnOptColumn "Pasus stil (jedan potez po liniji)" 1
 menuText Y PgnOptSpace "Blanko posle broja poteza" 0
+menuText Y PgnOptStripMarks "Strip out colored square/arrow codes" 1 ;# ***
 menuText Y PgnColor "Boje" 0
 menuText Y PgnColorHeader "Zaglavlje..." 0
 menuText Y PgnColorAnno "Napomene..." 0
@@ -513,7 +571,9 @@ menuText Y CrosstabOptNats "Narodnost" 0
 menuText Y CrosstabOptRatings "Rejtinzi" 0
 menuText Y CrosstabOptTitles "Titule" 0
 menuText Y CrosstabOptBreaks "Tie-break rezultati" 4
+menuText Y CrosstabOptDeleted "Include deleted games" 8 ;# ***
 menuText Y CrosstabOptColors "Boje (samo za vajcarski sistem)" 0
+menuText Y CrosstabOptColumnNumbers "Numbered columns (All-play-all table only)" 2 ;# ***
 menuText Y CrosstabOptGroup "Grupii rezultate" 0
 menuText Y CrosstabSort "Sortiraj" 0
 menuText Y CrosstabSortName "Ime" 0
@@ -528,6 +588,7 @@ menuText Y CrosstabHelpIndex "Sadraj pomoi" 0
 translate Y SetFilter {Postavi filter}
 translate Y AddToFilter {Dodaj u filter}
 translate Y Swiss {vajcarski sistem}
+translate Y Category {Category} ;# ***
 
 # Opening report window menus:
 menuText Y OprepFile "Fajl" 0
@@ -536,6 +597,10 @@ menuText Y OprepFileHtml "tampaj u HTML fajl..." 10
 menuText Y OprepFileLaTeX "tampaj u LaTeX fajl..." 10
 menuText Y OprepFileOptions "Opcije..." 0
 menuText Y OprepFileClose "Zatvori izvetaj o otvaranjima" 0
+menuText Y OprepFavorites "Favorites" 1 ;# ***
+menuText Y OprepFavoritesAdd "Add Report..." 0 ;# ***
+menuText Y OprepFavoritesEdit "Edit Report Favorites..." 0 ;# ***
+menuText Y OprepFavoritesGenerate "Generate Reports..." 0 ;# ***
 menuText Y OprepHelp "Pomo" 0
 menuText Y OprepHelpReport "Pomo - Izvetaj o otvaranjima" 0
 menuText Y OprepHelpIndex "Sadraj pomoi" 0
@@ -636,6 +701,7 @@ translate Y NumDeletedGames {Obrisanih partija:}
 translate Y NumFilterGames {Partija u filteru:}
 translate Y YearRange {Raspon godina:}
 translate Y RatingRange {Raspon rejtinga:}
+translate Y Description {Description} ;# ***
 translate Y Flag {Oznaka}
 translate Y DeleteCurrent {Obrii tekuu partiju}
 translate Y DeleteFilter {Obrii filtrirane partije}
@@ -661,6 +727,8 @@ translate Y CompactDatabase {Komprimuj bazu}
 translate Y SortDatabase {Sortiraj bazu}
 translate Y AddEloRatings {Dodaj Elo rejtinge}
 translate Y AutoloadGame {Autoload game number} ;# ***
+translate Y StripTags {Strip PGN tags} ;# ***
+translate Y StripTag {Strip tag} ;# ***
 translate Y Cleaner {ista}
 translate Y CleanerHelp {
 Scid ista e da primeni sve akcije odravanja koje izaberete iz donje liste, na tekuu bazu.
@@ -678,6 +746,7 @@ Da li ste sigurni da elite da ponete funkcije odravanja koje ste izabrali?
 # Comment editor:
 translate Y AnnotationSymbols  {Simboli napomena:}
 translate Y Comment {Komentari:}
+translate Y InsertMark {Insert mark} ;# ***
 
 # Board search:
 translate Y BoardSearch {Pretraga po poziciji}
@@ -720,7 +789,7 @@ translate Y InitialBoard {Poetna pozicija}
 translate Y SideToMove {Na potezu je}
 translate Y MoveNumber {Broj poteza}
 translate Y Castling {Rokada}
-translate Y EnPassentFile {En Passent linija}
+translate Y EnPassantFile {En Passant linija}
 translate Y ClearFen {Oisti FEN}
 translate Y PasteFen {Prenesi FEN}
 
@@ -750,6 +819,7 @@ Da li zaista elite da nastavite i odbacite sve uinjene promene?
 
 # Exit dialog:
 translate Y ExitDialog {Da li zaista elite da napustite Scid?}
+translate Y ExitUnsaved {The following databases have unsaved game changes. If you exit now, these changes will be lost.} ;# ***
 
 # Import window:
 translate Y PasteCurrentGame {Prenesi tekuu partiju}
@@ -783,6 +853,7 @@ translate Y OprepUp {vie za %u%s tokom svih godina}
 translate Y OprepDown {manje za %u%s tokom svih godina}
 translate Y OprepSame {bez promena tokom svih godina}
 translate Y OprepMostFrequent {Najei igrai}
+translate Y OprepMostFrequentOpponents {Most frequent opponents} ;# ***
 translate Y OprepRatingsPerf {Rejtinzi i umenost}
 translate Y OprepAvgPerf {Proseni rejtinzi i umenost}
 translate Y OprepWRating {Rejting belog}
@@ -810,14 +881,16 @@ translate Y OprepMoveOrdersAll \
 translate Y OprepMoveOrdersMany \
   {Bilo je %u redosleda poteza koji su dostigli ovu poziciju. Prvih %u su:}
 translate Y OprepMovesFrom {Potezi iz pozicije iz izvetaja}
+translate Y OprepMostFrequentEcoCodes {Most frequent ECO codes} ;# ***
 translate Y OprepThemes {Pozicione teme}
-translate Y OprepThemeDescription {Uestanost tema na potezu br. %u}
+translate Y OprepThemeDescription {Frequency of themes in the first %u moves of each game} ;# ***
 translate Y OprepThemeSameCastling {Rokade sa iste strane}
 translate Y OprepThemeOppCastling {Rokade sa suprotne strane}
 translate Y OprepThemeNoCastling {Obe strane bez rokada}
 translate Y OprepThemeKPawnStorm {Prodor peaka na kraljevom krilu}
 translate Y OprepThemeQueenswap {Zamena dama}
-translate Y OprepThemeIQP {Izolovan damin peak}
+translate Y OprepThemeWIQP {White Isolated Queen Pawn} ;# ***
+translate Y OprepThemeBIQP {Black Isolated Queen Pawn} ;# ***
 translate Y OprepThemeWP567 {Beli peak na 5., 6. ili 7. redu}
 translate Y OprepThemeBP234 {Crni peak na 2., 3. ili 4. redu}
 translate Y OprepThemeOpenCDE {Otvorena c, d ili e linija}
@@ -830,6 +903,27 @@ translate Y OprepTheoryTable {Tabela teorije}
 translate Y OprepTableComment {Generisano iz %u najbolje rejtiranih partija.}
 translate Y OprepExtraMoves {Posebno notirani potezi u tabeli teorije}
 translate Y OprepMaxGames {Maksimum partija u tabeli teorije}
+translate Y OprepViewHTML {View HTML} ;# ***
+translate Y OprepViewLaTeX {View LaTeX} ;# ***
+
+# Player Report:
+translate Y PReportTitle {Player Report} ;# ***
+translate Y PReportColorWhite {with the White pieces} ;# ***
+translate Y PReportColorBlack {with the Black pieces} ;# ***
+translate Y PReportMoves {after %s} ;# ***
+translate Y PReportOpenings {Openings} ;# ***
+translate Y PReportClipbase {Empty clipbase and copy matching games to it} ;# ***
+
+# Piece Tracker window:
+translate Y TrackerSelectSingle {Left mouse button selects this piece.} ;# ***
+translate Y TrackerSelectPair {Left mouse button selects this piece; right button also selects its sibling.}
+translate Y TrackerSelectPawn {Left mouse button selects this pawn; right button selects all 8 pawns.}
+translate Y TrackerStat {Statistic}
+translate Y TrackerGames {% games with move to square}
+translate Y TrackerTime {% time on each square}
+translate Y TrackerMoves {Moves}
+translate Y TrackerMovesStart {Enter the move number where tracking should begin.}
+translate Y TrackerMovesStop {Enter the move number where tracking should stop.}
 
 # Game selection dialogs:
 translate Y SelectAllGames {Sve partije u bazi}
@@ -861,6 +955,10 @@ translate Y TwinsUndelete {Obnovi prvo sve partije?}
 translate Y TwinsSetFilter {Postavi filter na sve obrisane udvojene partije?}
 translate Y TwinsComments {Uvek sauvaj partije sa komentarima?}
 translate Y TwinsVars {Uvek sauvaj partije sa varijantama?}
+translate Y TwinsDeleteWhich {Delete which game:} ;# ***
+translate Y TwinsDeleteShorter {Shorter game} ;# ***
+translate Y TwinsDeleteOlder {Smaller game number} ;# ***
+translate Y TwinsDeleteNewer {Larger game number} ;# ***
 translate Y TwinsDelete {Obrii partije}
 
 # Name editor window:
@@ -906,6 +1004,7 @@ translate Y IndentComments {Uvuci pasus kod komentara?}
 translate Y IndentVariations {Uvuci pasus kod varijanata?}
 translate Y ExportColumnStyle {Pasus stil (jedan potez po liniji)?}
 translate Y ExportSymbolStyle {Stil simbolikih napomena:}
+translate Y ExportStripMarks {Strip square/arrow mark codes from comments?} ;# ***
 
 # Goto game/move dialogs:
 translate Y LoadGameNumber {Unesi broj partije za uitavanje:}
@@ -962,5 +1061,16 @@ Ovo moe potrajati, ali treba da se uradi samo jednom. Moete prekinuti ukoliko bu
 Da li elite da sada unapredite ovu bazu?
 }
 
+# Recent files options:
+translate Y RecentFilesMenu {Number of recent files in File menu} ;# ***
+translate Y RecentFilesExtra {Number of recent files in extra submenu} ;# ***
+
+# My Player Names options:
+translate Y MyPlayerNamesDescription {
+Enter a list of preferred player names below, one name per line. Wildcards (e.g. "?" for any single character, "*" for any sequence of characters) are permitted.
+
+Every time a game with a player in the list is loaded, the main window chessboard will be rotated if necessary to show the game from that players perspective.
+} ;# ***
+
 }
 # end of serbian.tcl
