@@ -2,12 +2,14 @@
 
 # Scid (Shane's Chess Information Database)
 #
-# Copyright (C) 1999--2001  Shane Hudson. All rights reserved.
+# Copyright (C) 1999--2003  Shane Hudson. All rights reserved.
 # This is freely redistributable software; see the file named COPYING
 # that came with this program.
-# To contact the author: email me at:  shane@cosc.canterbury.ac.nz
+# To contact the author, email Shane at: sgh@users.sourceforge.net
 
-# The following comments are only for Unix versions of Scid:
+#
+# The following few comments are only for Unix versions of Scid:
+#
 
 # The "\" at the end of the comment line below is necessary! It means
 #   that the "exec" line is a comment to Tcl/Tk, but not to /bin/sh.
@@ -21,18 +23,37 @@ exec tkscid "$0" "$@"
 
 ############################################################
 
-set scidVersion "3.2"
+set scidVersion "3.5"
 
 # Determine operating system platform: unix or windows
+#
 set windowsOS 0
 if {$tcl_platform(platform) == "windows"} { set windowsOS 1 }
+set unixOS 0
+if {$tcl_platform(platform) == "unix"} { set unixOS 1 }
 
-# Check that the version of tkscid matches the version of this script:
+# A lot of code assumes tcl_platform is either windows or unix, so
+# lotsa stuff may break if this is not the case.
+#
+if {(! $windowsOS)  &&  (! $unixOS)} {
+  # What to do here? Warn the user...?
+}
 
+
+# Check that on Unix, the version of tkscid matches the version of this
+# script or on Windows, that the scid.exe and scid.gui versions are identical.
+#
 if {[string compare [sc_info version] $scidVersion]} {
   wm withdraw .
-  tk_messageBox -type ok -icon error -title "Scid: Version Error" \
-    -message "This program,\n\"$argv0\",\nhas version $scidVersion,\nbut the tkscid program \nit uses has version [sc_info version].\nCheck that the path to tkscid is correct."
+  if {$windowsOS} {
+    set msg "This is Scid version [sc_info version], but the scid.gui data\n"
+    append msg "file has the version number $scidVersion.\n"
+  } else {
+    set msg "This program,\n\"$argv0\",\nhas version $scidVersion,\nbut the "
+    append msg "tkscid program \nit uses has version [sc_info version].\n"
+    append msg "Check that the path to tkscid is correct." 
+  }
+  tk_messageBox -type ok -icon error -title "Scid: Version Error" -message $msg
   exit 1
 }
 
@@ -53,6 +74,12 @@ if {$windowsOS} {
   set scidUserDir [file nativename "~/.scid"]
 }
 
+# scidConfigDir, scidDataDir, scidLogDir:
+#   Location of Scid configuration, data and log files.
+set scidConfigDir [file nativename [file join $scidUserDir "config"]]
+set scidDataDir [file nativename [file join $scidUserDir "data"]]
+set scidLogDir [file nativename [file join $scidUserDir "log"]]
+
 # ecoFile: the ECO file for opening classification. Scid will try to load
 # this first, and if that fails, it will try to load  "scid.eco" in the
 # current directory.
@@ -70,29 +97,61 @@ set boardSizesOLD [list 21 25 29 33 37 40 45 49 54 58 64 72]
 set boardSize 45
 
 # boardStyle: Default board piece set. See bitmaps.tcl for styles.
-set boardStyle Merida
+set boardStyle Alpha
 
 # language for help pages and messages:
 set language E
 set oldLang X
 
-# showToolbar: 1 to show toolbar, 0 to hide it.
-set showToolbar 1
+# Toolbar configuration:
+foreach {tbicon status}  {
+  new 1 open 1 save 1 close 1
+  finder 1 bkm 1 gprev 1 gnext 1
+  cut 0 copy 0 paste 0
+  rfilter 1 bsearch 1 hsearch 1 msearch 1
+  switcher 1 glist 1 pgn 1 tmt 1 maint 1 eco 1 tree 1 crosst 1 engine 1
+} {
+  set toolbar($tbicon) $status
+}
 
 # boardCoords: 1 to show board Coordinates, 0 to hide them.
 set boardCoords 0
 
+# boardSTM: 1 to show side-to-move icon, 0 to hide it.
+set boardSTM 1
+
 # Default values for fonts:
-if {$windowsOS} {
-  font create font_Regular    -family arial     -size 11
-  font create font_Small      -family arial     -size 10
-  font create font_Fixed      -family courier   -size 11
-} else {
-  font create font_Regular    -family helvetica -size 11
-  font create font_Small      -family helvetica -size 10
-  font create font_Fixed      -family fixed     -size 11
+proc createFont {name} {
+  set opts $::fontOptions($name)
+  font create font_$name \
+    -family [lindex $opts 0] -size [lindex $opts 1] \
+    -weight [lindex $opts 2] -slant [lindex $opts 3]
 }
 
+proc configureFont {name} {
+  set opts $::fontOptions($name)
+  font configure font_$name \
+    -family [lindex $opts 0] -size [lindex $opts 1] \
+    -weight [lindex $opts 2] -slant [lindex $opts 3]
+}
+
+if {$windowsOS} {
+  set fontOptions(Regular) [list Arial           10 normal roman]
+  set fontOptions(Menu)    [list {MS Sans Serif}  9 normal roman]
+  set fontOptions(Small)   [list Arial            9 normal roman]
+  set fontOptions(Fixed)   [list Courier          9 normal roman]
+} else {
+  set fontOptions(Regular) [list helvetica 11 normal roman]
+  set fontOptions(Menu)    [list helvetica 10 normal roman]
+  set fontOptions(Small)   [list helvetica 10 normal roman]
+  set fontOptions(Fixed)   [list fixed     10 normal roman]
+}
+
+createFont Regular
+createFont Menu
+createFont Small
+createFont Fixed
+
 # Analysis command: to start chess analysis engine.
 set analysisCommand ""
 if {$windowsOS} {
@@ -105,8 +164,8 @@ if {$windowsOS} {
 #     whitecolor/blackcolor are piece colors
 #     highcolor is the color when something is selected.
 #     bestcolor is used to indicate a suggested move square.
-set dark        "\#a08050"
-set lite        "\#d0c0a0"
+set dark        "\#70a070"
+set lite        "\#e0d070"
 set whitecolor  "\#ffffff"
 set blackcolor  "\#000000"
 set whiteborder "\#000000"
@@ -114,7 +173,7 @@ set blackborder "\#ffffff"
 set highcolor   "\#b0d0e0"
 set bestcolor   "\#bebebe"
 set buttoncolor "\#b0c0d0"
-
+set borderwidth 1
 
 # Defaults for the PGN window:
 # if doColorPgn is 1, the PGN text will be colorized.
@@ -124,7 +183,9 @@ set pgnIndentComments 1
 set pgnSymbolicNags 1
 set pgnMoveNumSpace 0
 set pgnShortHeader 0
+set pgnMoveFont 1
 set pgnColumn 0
+set pgnStripMarks 0
 set pgnColor(Header) "\#00008b"
 set pgnColor(Main) "\#000000"
 set pgnColor(Var) "\#0000ee"
@@ -138,8 +199,10 @@ set pgnColor(Background) "\#ffffff"
 # Defaults for initial directories:
 set initialDir(base) "."
 set initialDir(book) "."
+set initialDir(epd) "."
 set initialDir(html) "."
 set initialDir(tex)  "."
+set initialDir(report) "."
 set initialDir(tablebase1) ""
 set initialDir(tablebase2) ""
 set initialDir(tablebase3) ""
@@ -161,7 +224,7 @@ set glistSelectPly 80
 # Default window locations:
 foreach i {. .pgnWin .helpWin .crosstabWin .treeWin .commentWin .glist \
              .playerInfoWin .baseWin .treeBest .treeGraph .tourney .finder \
-             .ecograph .statsWin .glistWin .maintWin .nedit offset} {
+             .ecograph .statsWin .glistWin .maintWin .nedit} {
   set winX($i) -1
   set winY($i) -1
 }
@@ -235,7 +298,7 @@ set tree(order) frequency
 set tree(autoSave) 0
 
 # Auto-save options when exiting:
-set optionsAutoSave 0
+set optionsAutoSave 1
 
 #  Numeric locale: first char is decimal, second is thousands.
 #  Example: ".," for "1,234.5" format; ",." for "1.234,5" format.
@@ -252,7 +315,9 @@ set moveEntry(On) 1
 set moveEntry(AutoExpand) 0
 set moveEntry(Coord) 1
 
+# Autoplay and animation delays in milliseconds:
 set autoplayDelay 5000
+set animateDelay 200
 
 # Geometry of windows:
 array set geometry {}
@@ -264,6 +329,9 @@ set startup(switcher) 0
 set startup(tip) 1
 set startup(tree) 0
 set startup(finder) 0
+set startup(crosstable) 0
+set startup(gamelist) 0
+set startup(stats) 0
 
 # glistFields: Layout of the GameList window fields.
 #    element 0: code (e.g. g for gameNumber, w for White name)
@@ -305,8 +373,16 @@ lappend glistAllFields { c  3 left  black      0 }
 lappend glistAllFields { E  7 left  darkRed    0 }
 lappend glistAllFields { F  7 left  darkBlue   0 }
 
+# myPlayerNames:
+#   List of player name patterns for which the chessboard should be
+#   flipped each time a game is loaded to show the board from that
+#   players perspective.
+#
+set myPlayerNames {}
+
 
 # Game information area options:
+set gameInfo(photos) 1
 set gameInfo(hideNextMove) 0
 set gameInfo(showMaterial) 0
 set gameInfo(showFEN) 0
@@ -336,6 +412,7 @@ array set twinSettings {
   comments   Yes
   variations Yes
   usefilter  No
+  delete     Shorter
 }
 array set twinSettingsDefaults [array get twinSettings]
 
@@ -363,6 +440,23 @@ array set optable {
 }
 array set optableDefaults [array get optable]
 
+# Player report options
+array set preport {
+  Stats 1
+  Oldest 5
+  Newest 5
+  MostFrequentOpponents 6
+  AvgPerf 1
+  HighRating 8
+  Results 1
+  MostFrequentEcoCodes 6
+  Themes 1
+  Endgames 1
+  MaxGames 500
+  ExtraMoves 1
+}
+array set preportDefaults [array get preport]
+
 # Export file options:
 set exportFlags(comments) 1
 set exportFlags(indentc) 0
@@ -372,6 +466,8 @@ set exportFlags(column) 0
 set exportFlags(append) 0
 set exportFlags(symbols) 1
 set exportFlags(htmldiag) 0
+set exportFlags(stripMarks) 0
+set exportFlags(convertNullMoves) 1
 set default_exportStartFile(PGN) {}
 set default_exportEndFile(PGN) {}
 
@@ -442,7 +538,8 @@ set autoIconify 1
 
 
 # Email configuration:
-set email(logfile) [file join $scidUserDir "scidmail.log"]
+set email(logfile) [file join $scidLogDir "scidmail.log"]
+set email(oldlogfile) [file join $scidUserDir "scidmail.log"]
 set email(smtp) 1
 set email(smproc) "/usr/lib/sendmail"
 set email(server) localhost
@@ -452,23 +549,41 @@ set email(bcc) ""
 
 # Spell-checking file: default is "spelling.ssp".
 if {$windowsOS} {
-  set spellCheckFile [file join $scidExeDir "spelling.ssp"]
+  set spellCheckFile [file join $scidDataDir "spelling.ssp"]
 } else {
   set spellCheckFile "/usr/local/share/scid/spelling.ssp"
 }
 
-# Engines list file:
-set engines(file) [file join $scidUserDir "engines.lis"]
-set engines(backup) [file join $scidUserDir "engines.bak"]
+# Engines list file: -- OLD NAMES, NO LONGER USED
+#set engines(file) [file join $scidUserDir "engines.lis"]
+#set engines(backup) [file join $scidUserDir "engines.bak"]
 
 # Engines data:
 set engines(list) {}
 set engines(sort) Time
 
+# Set up Scid icon in Windows:
+if {$::windowsOS} {
+  # Look in each of the following directories for a file named scid.ico:
+  set iconFileDirs [list \
+    $scidExeDir $scidUserDir $scidConfigDir [file join $scidExeDir "src"]]
+
+  foreach iconFileDir $iconFileDirs {
+    set scidIconFile [file join $iconFileDir "scid.ico"]
+    if {[file readable $scidIconFile]} {
+      catch {wm iconbitmap . -default $scidIconFile}
+    }
+  }
+}
+
+# Add empty updateStatusBar proc to avoid errors caused by early
+# closing of the splash window:
+#
+proc updateStatusBar {} {}
 
 # Start up splash screen:
 
-set autoCloseSplash 0
+set autoCloseSplash 1
 wm withdraw .
 toplevel .splash
 wm protocol .splash WM_DELETE_WINDOW { wm withdraw .splash }
@@ -480,9 +595,9 @@ text .splash.t -height 14 -width 50 -cursor top_left_arrow \
     -yscrollcommand {.splash.ybar set} -setgrid 1
 scrollbar .splash.ybar -command {.splash.t yview}
 checkbutton .splash.auto -text "Auto-close after startup" \
-  -variable autoCloseSplash -font font_Regular -relief raised -pady 5 -padx 5
+  -variable autoCloseSplash -font font_Small -pady 5 -padx 5
 button .splash.dismiss -text " Close " -command {wm withdraw .splash} \
-  -font font_Regular
+  -font font_Small
 pack .splash.f -side top -expand yes -fill both
 pack .splash.b -side top -fill x
 pack .splash.auto -side left -in .splash.b -pady 2 -ipadx 10 -padx 10
@@ -604,21 +719,45 @@ eoGp4WkYkYCVQ6MQF/MBwZAr3xkQADs=
 
 .splash.t image create end -image splash
 .splash.t insert end "Shane's Chess Information Database"
-addSplash "Copyright (C) 1999-2001 Shane Hudson  (shane@cosc.canterbury.ac.nz)"
+addSplash "Copyright (C) 1999-2003 Shane Hudson  (sgh@users.sourceforge.net)"
 addSplash "This is Scid [sc_info version], released [sc_info version date]."
 addSplash "Website: scid.sourceforge.net\n"
 
+# Remember old font settings before loading options file:
+set fontOptions(oldRegular) $fontOptions(Regular)
+set fontOptions(oldMenu) $fontOptions(Menu)
+set fontOptions(oldSmall) $fontOptions(Small)
+set fontOptions(oldFixed) $fontOptions(Fixed)
+
+# New configuration file names:
+set scidConfigFiles(options) "options.dat"
+set scidConfigFiles(engines) "engines.dat"
+set scidConfigFiles(engines.bak) "engines.dat"
+set scidConfigFiles(recentfiles) "recent.dat"
+set scidConfigFiles(bookmarks) "bookmarks.dat"
+set scidConfigFiles(reports) "reports.dat"
+
+# scidConfigFile:
+#   Returns the full path and name of a Scid configuration file,
+#   given its configuration type.
+#
+proc scidConfigFile {type} {
+  global scidConfigDir scidConfigFiles
+  if {! [info exists scidConfigFiles($type)]} {
+    return -code error "No such config file type: $type"
+  }
+  return [file nativename [file join $scidConfigDir $scidConfigFiles($type)]]
+}
+
 
 # Try to load saved options:
-# The options file is ".scid" in the users home directory on Unix systems,
-# or "scid.opt" in the directory of the Scid program on Windows.
-if {! $windowsOS} {
-  set optionsFile [file join $scidUserDir "scidrc"]
-  set optionsFileBak [file join $scidUserDir "scidrc.bak"]
-} else {
-  set optionsFile [file join $scidExeDir "scid.opt"]
-  set optionsFileBak [file join $scidExeDir "scidopt.bak"]
-}
+#if {$unixOS} {
+#  set optionsFile [file join $scidUserDir "scidrc"]
+#  set optionsFileBak [file join $scidUserDir "scidrc.bak"]
+#} else {
+#  set optionsFile [file join $scidExeDir "scid.opt"]
+#  set optionsFileBak [file join $scidExeDir "scidopt.bak"]
+#}
 
 # Create user ".scid" directory in Unix if necessary:
 # Since the options file used to be ".scid", rename it:
@@ -637,12 +776,76 @@ if {! [file isdirectory $scidUserDir]} {
   }
 }
 
+# Create the config, data and log directories if they do not exist:
+proc makeScidDir {dir} {
+  if {! [file isdirectory $dir]} {
+    if {[catch {file mkdir $dir} err]} {
+      addSplash "Error creating directory $dir: $err"
+    } else {
+      addSplash "Created directory: $dir"
+    }
+  }
+}
+
+makeScidDir $scidConfigDir
+makeScidDir $scidDataDir
+makeScidDir $scidLogDir
+
+# Rename old email log file if necessary:
+if {[file readable $email(oldlogfile)]  &&  ![file readable $email(logfile)]} {
+  catch {file rename $email(oldlogfile) $email(logfile)}
+}
+
+# moveOldConfigFiles
+#   Moves configuration files from the old (3.4 and earlier) names
+#   to the new file names used since Scid 3.5.
+#
+proc moveOldConfigFiles {} {
+  global scidUserDir scidConfigDir
+  foreach {oldname newname} {
+    scidrc options.dat
+    scid.opt options.dat
+    scid.bkm bookmarks.dat
+    scid.rfl recentfiles.dat
+    engines.lis engines.dat
+  } {
+    set oldpath [file nativename [file join $scidUserDir $oldname]]
+    set newpath [file nativename [file join $scidConfigDir $newname]]
+    if {[file readable $oldpath]  &&  ![file readable $newpath]} {
+      if {[catch {file rename $oldpath $newpath} err]} {
+        addSplash "Error moving $oldpath to $newpath: $err"
+      } else {
+        addSplash "Moved old config file $oldname to $newpath"
+      }
+    }
+  }
+}
+
+moveOldConfigFiles
+
+set optionsFile [scidConfigFile options]
+
 if {[catch {source $optionsFile} ]} {
   #addSplash "Unable to find the options file: [file tail $optionsFile]"
 } else {
   addSplash "Your options file \"[file tail $optionsFile]\" was found and loaded."
 }
 
+# Reconfigure fonts if necessary:
+foreach i {Regular Menu Small Fixed} {
+  if {$fontOptions($i) == $fontOptions(old$i)} {
+    # Old font format in options file, or no file. Extract new options:
+    set fontOptions($i) {}
+    lappend fontOptions($i) [font actual font_$i -family]
+    lappend fontOptions($i) [font actual font_$i -size]
+    lappend fontOptions($i) [font actual font_$i -weight]
+    lappend fontOptions($i) [font actual font_$i -slant]
+  } else {
+    # New font format in options file:
+    configureFont $i
+  }
+}
+
 # Check board size is valid:
 set newSize [lindex $boardSizes 0]
 foreach sz $boardSizes {
@@ -658,9 +861,17 @@ if {[info exists initialDir(tablebase)]} {
 # font_Regular is the default font for widgets:
 option add *Font font_Regular
 
+# Use font_Menu for menu entries:
+option add *Menu*Font font_Menu
+# option add *Menubutton*Font font_Menu
+
+if {$unixOS} {
+  option add Scrollbar*borderWidth 1
+}
+
 # Set the radiobutton and checkbutton background color if desired.
 # I find the maroon color on Unix ugly!
-if {! $windowsOS} {
+if {$unixOS} {
   option add *Radiobutton*selectColor $buttoncolor
   option add *Checkbutton*selectColor $buttoncolor
   option add *Menu*selectColor $buttoncolor
@@ -673,31 +884,17 @@ font create font_Bold -family $font -size $fontsize -weight bold
 font create font_BoldItalic -family $font -size $fontsize -weight bold \
   -slant italic
 font create font_Italic -family $font -size $fontsize -slant italic
-font create font_H1 -family $font -size [expr $fontsize + 8] -weight bold
-font create font_H2 -family $font -size [expr $fontsize + 6] -weight bold
-font create font_H3 -family $font -size [expr $fontsize + 4] -weight bold
-font create font_H4 -family $font -size [expr $fontsize + 2] -weight bold
-font create font_H5 -family $font -size [expr $fontsize + 0] -weight bold
+font create font_H1 -family $font -size [expr {$fontsize + 8} ] -weight bold
+font create font_H2 -family $font -size [expr {$fontsize + 6} ] -weight bold
+font create font_H3 -family $font -size [expr {$fontsize + 4} ] -weight bold
+font create font_H4 -family $font -size [expr {$fontsize + 2} ] -weight bold
+font create font_H5 -family $font -size [expr {$fontsize + 0} ] -weight bold
 
 set fontsize [font configure font_Small -size]
 set font [font configure font_Small -family]
 font create font_SmallBold -family $font -size $fontsize -weight bold
 font create font_SmallItalic -family $font -size $fontsize -slant italic
 
-# Check window offset of window manager frame:
-# This is done by creating a window, positioning it at +0+0
-# (the top left corner), and then reading its actual position.
-# If the values are already set from the options file, this
-# does not need to be done.
-
-if {$winX(offset) == -1  ||  $winY(offset) == -1} {
-  toplevel .testWin
-  wm geometry .testWin +0+0
-  update idletasks
-  set winX(offset) [winfo rootx .testWin]
-  set winY(offset) [winfo rooty .testWin]
-  destroy .testWin
-}
 
 ###
 ### End of file: start.tcl
